@@ -43,6 +43,7 @@ typedef struct jrb_node {
   struct jrb_chain *jval_chain; 	/* added for rtlbrowse */
   Jval key;
   Jval val;
+  Jval val2;				/* added for rtlbrowse */
 } *JRB;
 
 
@@ -112,8 +113,11 @@ int jrb_plength(JRB n);       /* returns the # of nodes in path from
 #endif
 
 /*
- * $Id: jrb.h,v 1.1.1.1 2007/05/30 04:25:41 gtkwave Exp $
+ * $Id: jrb.h,v 1.2 2009/06/12 19:50:08 gtkwave Exp $
  * $Log: jrb.h,v $
+ * Revision 1.2  2009/06/12 19:50:08  gtkwave
+ * optimize out duplicate fac finding by adding a field to jrb tree
+ *
  * Revision 1.1.1.1  2007/05/30 04:25:41  gtkwave
  * Imported sources
  *
