@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2008.
+ * Copyright (c) Tony Bybell 1999-2009.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -52,6 +52,9 @@ ds_Tree *which;
 char *title;
 int display_mode;
 int width;
+
+JRB varnames;
+int resolved;
 };
 
 struct text_find_t
@@ -689,12 +692,12 @@ if(len < 4)
 
 		if(isx)
 			{
-			*(pnt++) = (isx==4) ? 'X' : 'x';	
+			*(pnt++) = (isx==4) ? 'x' : 'X';	
 			}
 		else
 		if(isz)
 			{
-			*(pnt++) = (isz==4) ? 'Z' : 'z';	
+			*(pnt++) = (isz==4) ? 'z' : 'Z';	
 			}
 		else
 			{
@@ -708,6 +711,45 @@ if(len < 4)
 }
 
 
+int fst_alpha_strcmpeq(const char *s1, const char *s2)
+{
+for(;;)
+	{
+	char c1 = *s1;
+	char c2 = *s2;
+
+	switch(c1)
+		{
+		case ' ':
+		case '\t':
+		case '[':
+			c1 = 0;
+
+		default:
+			break;
+		}
+
+	switch(c2)
+		{
+		case ' ':
+		case '\t':
+		case '[':
+			c2 = 0;
+
+		default:
+			break;
+		}
+
+	if(c1 != c2) { return(1); } 
+	if(!c1) break;
+
+	s1++; s2++;
+	}
+
+return(0);
+}
+
+
 /* for dnd */
 #define WAVE_DRAG_TAR_NAME_0         "text/plain"
 #define WAVE_DRAG_TAR_INFO_0         0
@@ -1307,6 +1349,12 @@ gboolean update_ctx_when_idle(gpointer textview_or_dummy)
 {
 struct text_find_t *t;
 
+if(anno_ctx->cygwin_remote_kill)
+	{
+	anno_ctx->cygwin_remote_kill = 0;
+	exit(0); /* remote kill command from gtkwave */
+	}
+
 if(textview_or_dummy == NULL)
 	{
 	if(anno_ctx)
@@ -1433,7 +1481,31 @@ if(matched) gtk_widget_destroy(matched);
 
 if(ctx)
 	{
+	JRB node;
+	JRB varnames = ctx->varnames;
+
 	if(ctx->title) free(ctx->title);
+
+        /* free up variables list */
+        jrb_traverse(node, varnames)
+		{
+                if(node->val2.v) free(node->val2.v);
+                free(node->key.s);
+                }
+
+        jrb_traverse(node, varnames)
+                {
+                struct jrb_chain *jvc = node->jval_chain;
+                while(jvc)
+                        {
+                        struct jrb_chain *jvcn = jvc->next;
+                        free(jvc);
+                        jvc = jvcn;
+                        }
+                }
+
+        jrb_free_tree(varnames);
+
 	free(ctx);
 	}
 }
@@ -1474,7 +1546,7 @@ void bwlogbox(char *title, int width, ds_Tree *t, int display_mode)
     handle = fopen(default_text, "rb");
     if(!handle)
 	{
-	fprintf(stderr, "Could not open logfile '%s'\n", default_text);
+	fprintf(stderr, "Could not open sourcefile '%s'\n", default_text);
 	return;
 	}
     fclose(handle);
@@ -1520,11 +1592,13 @@ void bwlogbox(char *title, int width, ds_Tree *t, int display_mode)
 #ifdef WAVE_USE_GTK2
 	else
 	{
-	window = gtk_hpaned_new();
-	GtkWidget *tbox = gtk_hbox_new(FALSE, 0);
+	GtkWidget *tbox;
 	GtkWidget *l1;
 	GtkWidget *image;
 	GtkRcStyle *rcstyle;
+
+	window = gtk_hpaned_new();
+	tbox = gtk_hbox_new(FALSE, 0);
 	
 	l1 = gtk_label_new(title);
 
@@ -1696,7 +1770,7 @@ void bwlogbox_2(struct logfile_context_t *ctx, GtkWidget *window, GtkWidget *but
     handle = fopen(default_text, "rb");
     if(!handle)
 	{
-	fprintf(stderr, "Could not open logfile '%s'\n", default_text);
+	fprintf(stderr, "Could not open sourcefile '%s'\n", default_text);
 	return;
 	}
     fclose(handle);
@@ -1773,46 +1847,240 @@ void bwlogbox_2(struct logfile_context_t *ctx, GtkWidget *window, GtkWidget *but
 	struct wave_logfile_lines_t *wt;
 	char *pnt = malloc(wlog_size + 1);
 	char *pnt2 = pnt;
-	JRB varnames = make_jrb();
+	JRB varnames = NULL;
 	JRB node;
 	int numvars = 0;
 
 	/* build up list of potential variables in this module */
-	if(!display_mode)
-	while(w)
+	if(!display_mode && !ctx->varnames) 
 		{
-		if(w->tok == V_ID)
+		varnames = make_jrb();
+		while(w)
 			{
-			if((w->line_no >= s_line) && (w->line_no <= e_line))
+			if(w->tok == V_ID)
 				{
-				if(strcmp(w->text, design_unit)) /* filter out design unit name */
+				if((w->line_no >= s_line) && (w->line_no <= e_line))
 					{
-					node = jrb_find_str(varnames, w->text);
-
-					if(!node)
+					if(strcmp(w->text, design_unit)) /* filter out design unit name */
 						{
-						Jval dummy;
-						dummy.v = NULL;
-						jrb_insert_str(varnames, strdup(w->text), dummy);
-						numvars++;
+						node = jrb_find_str(varnames, w->text);
+	
+						if(!node)
+							{
+							Jval dummy;
+							dummy.v = NULL;
+							jrb_insert_str(varnames, strdup(w->text), dummy);
+							numvars++;
+							}
 						}
 					}
 				}
+			w = w->next;
 			}
-		w = w->next;
 		}
 
 	if((anno_ctx)&&(anno_ctx->marker_set))
 		{
 		int resolved = 0;
 
-		if(vzt)
+/*************************/
+		if(fst)
+			{
+			int numfacs=fstReaderGetVarCount(fst);
+			int i;
+			const char *scp_nam = NULL;
+			fstHandle fh = 0;
+			int new_scope_encountered = 1;
+			int good_scope = 0;
+
+			if(ctx->varnames) goto skip_resolved_fst;
+
+			jrb_traverse(node, varnames) { node->val.i = -1; }
+			fstReaderIterateHierRewind(fst);
+			fstReaderResetScope(fst);
+
+			for(i=0;i<numfacs;i++)
+				{
+				struct fstHier *h;
+
+				new_scope_encountered = 0;
+				while((h = fstReaderIterateHier(fst)))
+				        {
+					int do_brk = 0;
+				        switch(h->htyp)
+				                {
+				                case FST_HT_SCOPE:
+				                        scp_nam = fstReaderPushScope(fst, h->u.scope.name, NULL);
+							new_scope_encountered = 1;
+				                        break;
+				                case FST_HT_UPSCOPE:
+				                        scp_nam = fstReaderPopScope(fst);
+							new_scope_encountered = 1;
+				                        break;   
+				                case FST_HT_VAR:
+				                        scp_nam = fstReaderGetCurrentFlatScope(fst);
+							fh++;
+							do_brk = 1;
+							break;
+						default: 
+							break;
+						}
+					if(do_brk) break;
+					}
+				if(!h) break;
+
+				if(!new_scope_encountered)
+					{
+					if(!good_scope)
+						{
+						continue;
+						}
+					}
+					else
+					{
+					good_scope = !strcmp(scp_nam, title);
+					}
+
+				if(!good_scope)
+					{
+					if(resolved == numvars)
+						{
+						break;
+						}
+					}
+					else
+					{
+					jrb_traverse(node, varnames)
+						{
+						if(node->val.i < 0)
+							{
+							if(!fst_alpha_strcmpeq(h->u.var.name, node->key.s))
+								{
+								resolved++;
+								if(h->u.var.is_alias)
+									{
+									node->val.i = h->u.var.handle;
+									}
+									else
+									{
+									node->val.i = fh;
+									}
+								}
+							}
+							else /* bitblasted */
+							{
+							if(!fst_alpha_strcmpeq(h->u.var.name, node->key.s))
+								{
+								struct jrb_chain *jvc = node->jval_chain;
+								if(jvc) { 
+									while(jvc->next) jvc = jvc->next;
+									jvc->next = calloc(1, sizeof(struct jrb_chain));
+									jvc = jvc->next;
+									}
+									else
+									{ 
+									jvc = calloc(1, sizeof(struct jrb_chain));
+									node->jval_chain = jvc;
+									}
+
+								if(h->u.var.is_alias)
+									{
+									jvc->val.i = h->u.var.is_alias;
+									}
+									else
+									{
+									jvc->val.i = fh;
+									}
+								}
+							}
+						}
+					}
+				}
+/* resolved_fst: */
+			ctx->varnames = varnames;
+			ctx->resolved = resolved;
+skip_resolved_fst:
+			varnames = ctx->varnames;
+			resolved = ctx->resolved;
+
+			jrb_traverse(node, varnames)
+				{
+				if(node->val.i >= 0)
+					{
+					char rcb[65537];
+					char *rc;
+					struct jrb_chain *jvc = node->jval_chain;
+					char first_char;
+
+					rc = fstReaderGetValueFromHandleAtTime(fst, anno_ctx->marker, node->val.i, rcb);
+					first_char = rc ? rc[0] : '?';
+
+					if(!jvc)
+						{
+						if(rc)
+							{
+							node->val2.v = hexify(strdup(rc));
+							}
+							else
+							{
+							node->val2.v = NULL;
+							}
+						}
+						else
+						{
+						char *rc2;
+						int len = rc ? strlen(rc) : 0;
+						int iter = 1;
+
+						while(jvc)
+							{
+							fstReaderGetValueFromHandleAtTime(fst, anno_ctx->marker, jvc->val.i, rc);
+							len+= strlen(rc);
+							iter++;
+							jvc = jvc->next;
+							}
+
+						if(iter==len)
+							{
+							int pos = 1;
+							jvc = node->jval_chain;
+							rc2 = calloc(1, len+1);
+							rc2[0] = first_char;
+	
+							while(jvc)
+								{
+								char rcv[65537];
+								fstReaderGetValueFromHandleAtTime(fst, anno_ctx->marker, jvc->val.i, rcv);
+								rc2[pos++] = *rcv;
+								jvc = jvc->next;
+								}		
+
+							node->val2.v = hexify(strdup(rc2));
+							free(rc2);
+							}
+							else
+							{
+							node->val2.v = NULL;
+							}
+						}
+					}
+					else
+					{
+					node->val2.v = NULL;
+					}
+				}
+			}
+/*************************/
+		else if(vzt)
 			{
 			int numfacs=vzt_rd_get_num_facs(vzt);
 			int i;
 			int tlen;
-			char *pfx = malloc((tlen=strlen(title))+1+1);
-			
+			char *pfx = NULL;
+
+			if(ctx->varnames) goto skip_resolved_vzt;
+
+			pfx = malloc((tlen=strlen(title))+1+1);
 			strcpy(pfx, title);
 			strcat(pfx+tlen, ".");
 			tlen++;
@@ -1899,6 +2167,11 @@ void bwlogbox_2(struct logfile_context_t *ctx, GtkWidget *window, GtkWidget *but
 					}
 				}
 resolved_vzt:		free(pfx);
+			ctx->varnames = varnames;
+			ctx->resolved = resolved;
+skip_resolved_vzt:
+			varnames = ctx->varnames;
+			resolved = ctx->resolved;
 
 			jrb_traverse(node, varnames)
 				{
@@ -1912,11 +2185,11 @@ resolved_vzt:		free(pfx);
 						{
 						if(rc)
 							{
-							node->val.v = hexify(strdup(rc));
+							node->val2.v = hexify(strdup(rc));
 							}
 							else
 							{
-							node->val.v = NULL;
+							node->val2.v = NULL;
 							}
 						}
 						else
@@ -1947,18 +2220,18 @@ resolved_vzt:		free(pfx);
 								jvc = jvc->next;
 								}		
 
-							node->val.v = hexify(strdup(rc2));
+							node->val2.v = hexify(strdup(rc2));
 							free(rc2);
 							}
 							else
 							{
-							node->val.v = NULL;
+							node->val2.v = NULL;
 							}
 						}
 					}
 					else
 					{
-					node->val.v = NULL;
+					node->val2.v = NULL;
 					}
 				}
 			}
@@ -1968,8 +2241,11 @@ resolved_vzt:		free(pfx);
 			int numfacs=lxt2_rd_get_num_facs(lx2);
 			int i;
 			int tlen;
-			char *pfx = malloc((tlen=strlen(title))+1+1);
-			
+			char *pfx = NULL;
+
+			if(ctx->varnames) goto skip_resolved_lxt2;
+
+			pfx = malloc((tlen=strlen(title))+1+1);
 			strcpy(pfx, title);
 			strcat(pfx+tlen, ".");
 			tlen++;
@@ -2060,6 +2336,11 @@ resolved_vzt:		free(pfx);
 					}
 				}
 resolved_lxt2:		free(pfx);
+			ctx->varnames = varnames;
+			ctx->resolved = resolved;
+skip_resolved_lxt2:
+			varnames = ctx->varnames;
+			resolved = ctx->resolved;
 
 			lx2vals = make_jrb();
 			lxt2_rd_unlimit_time_range(lx2);
@@ -2080,11 +2361,11 @@ resolved_lxt2:		free(pfx);
 						{
 						if(rc)
 							{
-							node->val.v = hexify(strdup(rc));
+							node->val2.v = hexify(strdup(rc));
 							}
 							else
 							{
-							node->val.v = NULL;
+							node->val2.v = NULL;
 							}
 						}
 						else
@@ -2117,18 +2398,18 @@ resolved_lxt2:		free(pfx);
                                                                 jvc = jvc->next; 
                                                                 }
     
-                                                        node->val.v = hexify(strdup(rc2));
+                                                        node->val2.v = hexify(strdup(rc2));
                                                         free(rc2);               
                                                         }
                                                         else
                                                         {               
-                                                        node->val.v = NULL;
+                                                        node->val2.v = NULL;
 							}						
 						}
 					}
 					else
 					{
-					node->val.v = NULL;
+					node->val2.v = NULL;
 					}
 				}
 
@@ -2146,10 +2427,13 @@ resolved_lxt2:		free(pfx);
 			int numfacs=ae2_read_num_symbols(ae2);
 			int i;
 			int tlen;
-			char *pfx = malloc((tlen=strlen(title))+1+1);
+			char *pfx = NULL;
 			char *tstr;
 			int attempt = 0;
+
+			if(ctx->varnames) goto skip_resolved_ae2;
 			
+			pfx = malloc((tlen=strlen(title))+1+1);
 			strcpy(pfx, title);
 			strcat(pfx+tlen, ".");
 			tlen++;
@@ -2232,6 +2516,11 @@ retry_ae2:		for(i=0;i<numfacs;i++)
 				}
 
 resolved_ae2:		free(pfx);
+			ctx->varnames = varnames;
+			ctx->resolved = resolved;
+skip_resolved_ae2:
+			varnames = ctx->varnames;
+			resolved = ctx->resolved;
 
 			jrb_traverse(node, varnames)
 				{
@@ -2247,11 +2536,11 @@ resolved_ae2:		free(pfx);
 					fr.length = ae2_read_symbol_length(ae2, fr.s);
 					ae2_read_value(ae2, &fr, anno_ctx->marker, rc);
 
-					node->val.v = rc[0] ? hexify(strdup(rc)) : NULL;
+					node->val2.v = rc[0] ? hexify(strdup(rc)) : NULL;
 					}
 					else
 					{
-					node->val.v = NULL;
+					node->val2.v = NULL;
 					}
 				}
 			}
@@ -2274,11 +2563,11 @@ resolved_ae2:		free(pfx);
 						if(strcmp(w->text, design_unit)) /* filter out design unit name */
 							{
 							node = jrb_find_str(varnames, w->text);
-							if((node)&&(node->val.v))
+							if((node)&&(node->val2.v))
 								{
 								log_text(text, fontx, w->text);
 								log_text_bold(text, fontx, "[");
-								log_text_bold(text, fontx, node->val.v);
+								log_text_bold(text, fontx, node->val2.v);
 								log_text_bold(text, fontx, "]");
 								goto iter_free;
 								}
@@ -2298,7 +2587,7 @@ resolved_ae2:		free(pfx);
 						}
 					}
 
-iter_free:			free(w->text);
+iter_free: 			free(w->text);
 				wt = w;
 				w = w->next;
 				free(wt);
@@ -2336,12 +2625,13 @@ iter_free:			free(w->text);
 	free(pnt);
 
 free_vars:
+#if 0
 	/* free up variables list */
 	if(!display_mode)
 		{
 		jrb_traverse(node, varnames)
 			{
-			if(node->val.v) free(node->val.v);
+			if(node->val2.v) free(node->val2.v);
 			free(node->key.s);
 			}
 		}
@@ -2359,6 +2649,7 @@ free_vars:
 
 	jrb_free_tree(varnames);
 	varnames = NULL;
+#endif
 
 	/* insert context for destroy */
 	if(window)
@@ -2385,8 +2676,32 @@ free_vars:
 }
 
 /*
- * $Id: logfile.c,v 1.24 2008/12/26 22:15:42 gtkwave Exp $
+ * $Id: logfile.c,v 1.32 2009/12/24 21:03:32 gtkwave Exp $
  * $Log: logfile.c,v $
+ * Revision 1.32  2009/12/24 21:03:32  gtkwave
+ * warnings fixes
+ *
+ * Revision 1.31  2009/07/07 20:22:52  gtkwave
+ * use standard verilog capitalization for x/X z/Z values in hexify()
+ *
+ * Revision 1.30  2009/06/29 18:16:23  gtkwave
+ * adding framework for module type annotation on inner tree nodes
+ *
+ * Revision 1.29  2009/06/14 15:44:29  gtkwave
+ * fix fst alias handling, reduce number of hier searches for fst
+ *
+ * Revision 1.28  2009/06/14 01:11:11  gtkwave
+ * previous match optimization fix
+ *
+ * Revision 1.27  2009/06/13 22:02:18  gtkwave
+ * beginning to add FST support to rtlbrowse
+ *
+ * Revision 1.26  2009/06/12 19:50:08  gtkwave
+ * optimize out duplicate fac finding by adding a field to jrb tree
+ *
+ * Revision 1.25  2009/04/24 04:24:22  gtkwave
+ * reload and cygwin fixes for rtlbrowse
+ *
  * Revision 1.24  2008/12/26 22:15:42  gtkwave
  * compile fixes for gtk+-2.0 (old versions of gtk2)
  *
