@@ -58,19 +58,47 @@ while(!feof(f))
 	len = strlen(srt);
 	if(!len) continue;
 
-	if(!head)
+	if((srt[0]=='+')||((srt[0]=='-')&&(srt[1]=='D'))) /* do not parse spaces out of front/back of plusargs and defines */
 		{
-		head = curr = calloc(1, sizeof(struct arglines_t));
-		head->s = strdup(srt);
-		head->count = 1;
+		if(!head)
+			{
+			head = curr = calloc(1, sizeof(struct arglines_t));
+			head->s = strdup(srt);
+			head->count = 1;
+			}
+			else
+			{
+			struct arglines_t *l = calloc(1, sizeof(struct arglines_t));
+			l->s = strdup(srt);
+			curr->next = l;
+			curr = l;
+			head->count++;
+			}
 		}
 		else
 		{
-		struct arglines_t *l = calloc(1, sizeof(struct arglines_t));
-		l->s = strdup(srt);
-		curr->next = l;
-		curr = l;
-		head->count++;
+		char *srt_new = srt;
+		int first = 1;
+
+		while((srt_new = strtok(first ? srt : NULL, " \t")))
+			{
+			first = 0;
+
+			if(!head)
+				{
+				head = curr = calloc(1, sizeof(struct arglines_t));
+				head->s = strdup(srt_new);
+				head->count = 1;
+				}
+				else
+				{
+				struct arglines_t *l = calloc(1, sizeof(struct arglines_t));
+				l->s = strdup(srt_new);
+				curr->next = l;
+				curr = l;
+				head->count++;
+				}
+			}
 		}
 	}
 
@@ -155,8 +183,11 @@ for(i=0;i<argc;i++)
 }
 
 /*
- * $Id: args.c,v 1.1.1.1 2007/05/30 04:25:41 gtkwave Exp $
+ * $Id: args.c,v 1.2 2008/11/08 15:39:11 gtkwave Exp $
  * $Log: args.c,v $
+ * Revision 1.2  2008/11/08 15:39:11  gtkwave
+ * updated -f argument file handling in vermin
+ *
  * Revision 1.1.1.1  2007/05/30 04:25:41  gtkwave
  * Imported sources
  *
