@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 2004-2008.
+ * Copyright (c) Tony Bybell 2004-2009.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -562,7 +562,7 @@ if(GLOBALS->fast_tree_sort)
 		build_tree_from_name(GLOBALS->facs[i]->name, i);
 		}
 /* SPLASH */                            splash_sync(4, 5);
-	treegraft(GLOBALS->treeroot);
+	treegraft(&GLOBALS->treeroot);
 
 	fprintf(stderr, AET2_RDLOAD"Sorting facility hierarchy tree.\n");
 	treesort(GLOBALS->treeroot, NULL);
@@ -616,7 +616,7 @@ if(GLOBALS->fast_tree_sort)
 		build_tree_from_name(GLOBALS->facs[i]->name, i);
 		}
 /* SPLASH */                            splash_sync(5, 5);
-	treegraft(GLOBALS->treeroot);
+	treegraft(&GLOBALS->treeroot);
 	treesort(GLOBALS->treeroot, NULL);
 	}
 
@@ -1264,8 +1264,11 @@ for(txidx=0;txidx<GLOBALS->numfacs;txidx++)
 /* ...of AET2_IS_PRESENT */
 
 /*
- * $Id: ae2.c,v 1.9 2008/12/25 03:21:57 gtkwave Exp $
+ * $Id: ae2.c,v 1.10 2009/07/01 07:39:12 gtkwave Exp $
  * $Log: ae2.c,v $
+ * Revision 1.10  2009/07/01 07:39:12  gtkwave
+ * decorating hierarchy tree with module type info
+ *
  * Revision 1.9  2008/12/25 03:21:57  gtkwave
  * -Wshadow warning fixes
  *
