@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2008.
+ * Copyright (c) Tony Bybell 1999-2009.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -39,6 +39,8 @@ typedef struct BitAttributes *baptr;
 typedef unsigned long  Ulong;
 typedef unsigned int   Uint;
 
+enum TraceReorderMode  { TR_SORT_INS, TR_SORT_NORM, TR_SORT_LEX, TR_SORT_RVS };
+
 
 /* vvv   Bit representation   vvv */
 
@@ -49,11 +51,18 @@ enum AnalyzerBits  { AN_0, AN_X, AN_Z, AN_1, AN_H, AN_U, AN_W, AN_L, AN_DASH, AN
 #define AN_MSK     (AN_COUNT-1) /* max index into AN_STR, AN_COUNT *must* be a power of two unless logic AND with AN_MSK is changed */
 
 /* positional ascii 0123456789ABCDEF, question marks should not happen unless something slips through the cracks as AN_RSVA to AN_RSVF are reserved */
-#define AN_STR     "0XZ1HUWL-???????"
-#define AN_STR_INV "1XZ0LUWH-???????"
+#define AN_STR      "0xz1huwl-???????"
+#define AN_STR_INV  "1xz0luwh-???????"
+
+#define AN_USTR     "0XZ1HUWL-???????"
+#define AN_USTR_INV "1XZ0LUWH-???????"
 
 /* for writing out 4 state formats (read GHW, write LXT) */
-#define AN_STR4ST  "0XZ11XZ0XXXXXXXX"
+#define AN_USTR4ST  "0XZ11XZ0XXXXXXXX"
+
+/* for hex/oct conversion in baseconvert.c */
+#define AN_HEX_STR  "0123456789ABCDEFxzwu-XZWU"
+#define AN_OCT_STR  "01234567xzwu-"
 
 /* now the recoded "extra" values... */
 #define RCV_X (1 | (0<<1))
@@ -64,7 +73,7 @@ enum AnalyzerBits  { AN_0, AN_X, AN_Z, AN_1, AN_H, AN_U, AN_W, AN_L, AN_DASH, AN
 #define RCV_L (1 | (5<<1))
 #define RCV_D (1 | (6<<1))
 
-#define RCV_STR "XZHUWL-?"
+#define RCV_STR "xzhuwl-?"
 /*               01234567 */
 
 /* ^^^   Bit representation   ^^^ */
@@ -148,8 +157,74 @@ struct Node
 
     int      numhist;	/* number of elements in the harray */
     unsigned int array_height, this_row;
+    unsigned char vartype; /* see nodeVarType, this is an internal value */
+    unsigned char vardir; /* see nodeVarDir, this is an internal value */
   };
 
+
+#define WAVE_NODEVARTYPE_STR \
+static const char *vartype_strings[] = { \
+    "", \
+    "event", \
+    "int", \
+    "parm", \
+    "real", \
+    "real_parm", \
+    "reg", \
+    "supply0", \
+    "supply1", \
+    "time", \
+    "tri", \
+    "triand", \
+    "trior", \
+    "trireg", \
+    "tri0", \
+    "tri1", \
+    "wand", \
+    "wire", \
+    "wor", \
+    "array", \
+    "port" \
+};
+
+
+enum nodeVarType {
+    ND_UNSPECIFIED_DEFAULT = 0,
+
+    ND_VCD_EVENT           = 1,
+    ND_VCD_INTEGER         = 2,
+    ND_VCD_PARAMETER       = 3,
+    ND_VCD_REAL            = 4,
+    ND_VCD_REAL_PARAMETER  = 5,
+    ND_VCD_REG             = 6,
+    ND_VCD_SUPPLY0         = 7,
+    ND_VCD_SUPPLY1         = 8,
+    ND_VCD_TIME            = 9,
+    ND_VCD_TRI             = 10,  
+    ND_VCD_TRIAND          = 11,
+    ND_VCD_TRIOR           = 12,
+    ND_VCD_TRIREG          = 13,
+    ND_VCD_TRI0            = 14,  
+    ND_VCD_TRI1            = 15,
+    ND_VCD_WAND            = 16,
+    ND_VCD_WIRE            = 17,
+    ND_VCD_WOR             = 18,
+    ND_VCD_ARRAY           = 19,    /* used to define the rownum (index) port on the array */
+
+    ND_VCD_PORT		   = 20,
+    ND_VARTYPE_MAX	   = 20,
+                
+    ND_GEN_STRING          = 254,   /* generic string type */
+    ND_GEN_MEMBLOCK        = 255    /* generic memblock type */
+};
+
+enum nodeVarDir {
+    ND_DIR_IMPLICIT        = 0,
+    ND_DIR_IN              = 1,
+    ND_DIR_OUT             = 2,
+    ND_DIR_INOUT           = 3
+};
+
 typedef struct BitAttributes
   {
   TimeType  shift;
@@ -220,11 +295,11 @@ typedef struct TraceEnt
   {
     Trptr    t_next;		/* doubly linked list of traces */
     Trptr    t_prev;
+    Trptr    t_grp;             /* pointer to group I'm in */
+    Trptr    t_match;           /* If group begin pointer to group end and visa versa */
 
-    Trptr    t_group;
-    char     *t_group_name;
-
-    char     *name;		/* name stripped of path */
+    char     *name;		/* current name */
+    char     *name_full;   	/* full name */
     char     *asciivalue;	/* value that marker points to */
     TimeType asciitime;		/* time this value corresponds with */
     TimeType shift;		/* offset added to all entries in the trace */
@@ -241,6 +316,7 @@ typedef struct TraceEnt
     unsigned shift_drag_valid : 1; /* qualifies shift_drag above */
     unsigned interactive_vector_needs_regeneration : 1; /* for interactive VCDs */
     unsigned minmax_valid : 1;	/* for d_minval, d_maxval */
+    unsigned is_sort_group : 1; /* only used for sorting purposes */
 
     unsigned int flags;		/* see def below in TraceEntFlagBits */
     unsigned int cached_flags;	/* used for tcl for saving flags during cut and paste */
@@ -254,11 +330,14 @@ typedef struct TraceEnt
 
 
 enum TraceEntFlagBits
-{ TR_HIGHLIGHT_B, TR_HEX_B, TR_DEC_B, TR_BIN_B, TR_OCT_B, 
-  TR_RJUSTIFY_B, TR_INVERT_B, TR_REVERSE_B, TR_EXCLUDE_B,
-  TR_BLANK_B, TR_SIGNED_B, TR_ASCII_B, TR_COLLAPSED_B, TR_FTRANSLATED_B, TR_PTRANSLATED_B,
-  TR_ANALOG_STEP_B, TR_ANALOG_INTERPOLATED_B, TR_ANALOG_BLANK_STRETCH_B, TR_REAL_B,
-  TR_ANALOG_FULLSCALE_B, TR_ZEROFILL_B, TR_ONEFILL_B
+{ TR_HIGHLIGHT_B, TR_HEX_B, TR_DEC_B, TR_BIN_B, 
+  TR_OCT_B, TR_RJUSTIFY_B, TR_INVERT_B, TR_REVERSE_B,
+  TR_EXCLUDE_B, TR_BLANK_B, TR_SIGNED_B, TR_ASCII_B, 
+  TR_COLLAPSED_B, TR_FTRANSLATED_B, TR_PTRANSLATED_B, TR_ANALOG_STEP_B, 
+  TR_ANALOG_INTERPOLATED_B, TR_ANALOG_BLANK_STRETCH_B, TR_REAL_B, TR_ANALOG_FULLSCALE_B, 
+  TR_ZEROFILL_B, TR_ONEFILL_B, TR_CLOSED_B, TR_GRP_BEGIN_B, 
+  TR_GRP_END_B,
+  TR_BINGRAY_B, TR_GRAYBIN_B
 };
  
 #define TR_HIGHLIGHT 		(1<<TR_HIGHLIGHT_B)
@@ -280,6 +359,15 @@ enum TraceEntFlagBits
 #define TR_ANALOG_FULLSCALE	(1<<TR_ANALOG_FULLSCALE_B)
 #define TR_ZEROFILL		(1<<TR_ZEROFILL_B)
 #define TR_ONEFILL		(1<<TR_ONEFILL_B)
+#define TR_CLOSED		(1<<TR_CLOSED_B)
+
+#define TR_GRP_BEGIN		(1<<TR_GRP_BEGIN_B)
+#define TR_GRP_END		(1<<TR_GRP_END_B)
+#define TR_GRP_MASK		(TR_GRP_BEGIN|TR_GRP_END)
+
+#define TR_BINGRAY		(1<<TR_BINGRAY_B)
+#define TR_GRAYBIN		(1<<TR_GRAYBIN_B)
+#define TR_GRAYMASK		(TR_BINGRAY|TR_GRAYBIN)
 
 #define TR_NUMMASK	(TR_ASCII|TR_HEX|TR_DEC|TR_BIN|TR_OCT|TR_SIGNED|TR_REAL)
 
@@ -293,16 +381,13 @@ enum TraceEntFlagBits
 
 Trptr GiveNextTrace(Trptr t);
 Trptr GivePrevTrace(Trptr t);
-int CollapseTrace(Trptr t);
 int UpdateTracesVisible(void);
-void CollapseAllGroups(void);
-void ExpandAllGroups(void);
 
 void DisplayTraces(int val);
 int AddNodeTraceReturn(nptr nd, char *aliasname, Trptr *tret);
 int AddNode(nptr nd, char *aliasname);
 int AddNodeUnroll(nptr nd, char *aliasname);
-int AddVector(bvptr vec);
+int AddVector(bvptr vec, char *aliasname);
 int AddBlankTrace(char *commentname);
 int InsertBlankTrace(char *comment, int different_flags);
 void RemoveNode(nptr n);
@@ -312,8 +397,7 @@ Trptr CutBuffer(void);
 void FreeCutBuffer(void);
 Trptr PasteBuffer(void);
 Trptr PrependBuffer(void);
-int TracesAlphabetize(int mode);
-int TracesReverse(void);
+int TracesReorder(int mode);
 
 void import_trace(nptr np);
 
@@ -329,11 +413,68 @@ char *hier_extract(char *pnt, int levels);
 /* vector matching */
 char *attempt_vecmatch(char *s1, char *s2);
 
+void updateTraceGroup(Trptr t);
+int GetTraceNumber(Trptr t);
+void EnsureGroupsMatch(void);
+
+#define IsSelected(t)   (t->flags&TR_HIGHLIGHT) 
+#define IsGroupBegin(t) (t->flags&TR_GRP_BEGIN)
+#define IsGroupEnd(t)   (t->flags&TR_GRP_END)
+#define IsClosed(t)     (t->flags&TR_CLOSED)
+#define HasWave(t)      (!(t->flags&(TR_BLANK|TR_ANALOG_BLANK_STRETCH)))
+#define CanAlias(t)     HasWave(t)
+#define HasAlias(t)     (t->name_full&&HasWave(t))
+#define IsCollapsed(t)  (t->flags&TR_COLLAPSED)
+
+unsigned IsShadowed(Trptr t);
+char*    GetFullName(Trptr t);
+
+void OpenTrace(Trptr t);
+void CloseTrace(Trptr t);
+void ClearTraces();
+void ClearGroupTraces(Trptr t);
+
 #endif
 
 /*
- * $Id: analyzer.h,v 1.10 2008/12/31 22:20:12 gtkwave Exp $
+ * $Id: analyzer.h,v 1.22 2009/12/24 20:55:27 gtkwave Exp $
  * $Log: analyzer.h,v $
+ * Revision 1.22  2009/12/24 20:55:27  gtkwave
+ * warnings cleanups
+ *
+ * Revision 1.21  2009/11/25 09:49:28  gtkwave
+ * added gray code support
+ *
+ * Revision 1.20  2009/11/05 23:11:09  gtkwave
+ * added EnsureGroupsMatch()
+ *
+ * Revision 1.19  2009/11/03 07:08:21  gtkwave
+ * enabled reverse when groups present
+ *
+ * Revision 1.18  2009/11/02 22:43:44  gtkwave
+ * enable sorting on groups (need to do reverse yet)
+ *
+ * Revision 1.17  2009/11/02 05:45:14  gtkwave
+ * temporarily disable sort when groups present
+ *
+ * Revision 1.16  2009/09/14 03:00:08  gtkwave
+ * bluespec code integration
+ *
+ * Revision 1.15  2009/07/23 20:00:55  gtkwave
+ * added type info to signal window mouseover
+ *
+ * Revision 1.14  2009/07/07 20:12:53  gtkwave
+ * convert hex capitalization to match verilog
+ *
+ * Revision 1.13  2009/07/06 21:41:36  gtkwave
+ * evcd support issues
+ *
+ * Revision 1.12  2009/06/29 18:16:23  gtkwave
+ * adding framework for module type annotation on inner tree nodes
+ *
+ * Revision 1.11  2009/06/25 18:31:19  gtkwave
+ * added event types for VCD+FST and impulse arrows on event types
+ *
  * Revision 1.10  2008/12/31 22:20:12  gtkwave
  * adding more tcl commands
  *
