@@ -7,6 +7,7 @@
  * of the License, or (at your option) any later version.
  */
 
+#include "globals.h"
 #include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -85,8 +86,21 @@ return(!msk1 && !msk2); /* see if points are really inside */
 }
 
 /*
- * $Id: clipping.c,v 1.2 2007/04/20 02:08:11 gtkwave Exp $
+ * $Id: clipping.c,v 1.2 2007/08/26 21:35:39 gtkwave Exp $
  * $Log: clipping.c,v $
+ * Revision 1.2  2007/08/26 21:35:39  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.2  2007/08/06 03:50:45  gtkwave
+ * globals support for ae2, gtk1, cygwin, mingw.  also cleaned up some machine
+ * generated structs, etc.
+ *
+ * Revision 1.1.1.1.2.1  2007/08/05 02:27:19  kermin
+ * Semi working global struct
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:24  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:11  gtkwave
  * initial release
  *
