@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2009
+ * Copyright (c) Tony Bybell 1999-2010
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
 #include "regex_wave.h"
 #include "translate.h"
 
-#define WAVE_VERSION_INFO "GTKWave Analyzer v3.2.0 (w)1999-2009 BSI"
+#define WAVE_VERSION_INFO "GTKWave Analyzer v3.3.2 (w)1999-2010 BSI"
 
 #define WAVE_INF_SCALING (0.5)
 #define WAVE_SI_UNITS " munpfaz"
@@ -94,7 +94,7 @@ void force_normal_gcs(void);
 void draw_signalarea_focus(void);
 gint signalarea_configure_event(GtkWidget *widget, GdkEventConfigure *event);
 gint wavearea_configure_event(GtkWidget *widget, GdkEventConfigure *event);
-void entrybox(char *title, int width, char *default_text, int maxch, GtkSignalFunc func);
+void entrybox(char *title, int width, char *dflt_text, char *comment, int maxch, GtkSignalFunc func);
 void fileselbox_old(char *title, char **filesel_path, GtkSignalFunc ok_func, GtkSignalFunc notok_func, char *pattn);
 void fileselbox(char *title, char **filesel_path, GtkSignalFunc ok_func, GtkSignalFunc notok_func, char *pattn, int is_writemode);
 void status_text(char *str);
@@ -107,7 +107,7 @@ void treebox(char *title, GtkSignalFunc func, GtkWidget *old_window);
 GtkWidget* treeboxframe(char *title, GtkSignalFunc func);
 void mkmenu_treesearch_cleanup(GtkWidget *widget, gpointer data);
 void dump_open_tree_nodes(FILE *wave, xl_Tree *t);
-void force_open_tree_node(char *name);
+int force_open_tree_node(char *name);
 void select_tree_node(char *name);
 
 void dnd_setup(GtkWidget *src, GtkWidget *widget, int enable_receive); /* dnd from gtk2 tree to signalwindow */
@@ -174,8 +174,41 @@ void do_popup_menu (GtkWidget *my_widget, GdkEventButton *event);
 #endif
 
 /*
- * $Id: currenttime.h,v 1.54 2009/02/17 03:20:35 gtkwave Exp $
+ * $Id: currenttime.h,v 1.65 2010/01/05 06:18:33 gtkwave Exp $
  * $Log: currenttime.h,v $
+ * Revision 1.65  2010/01/05 06:18:33  gtkwave
+ * emergency fix on missing comment causing bad code
+ *
+ * Revision 1.64  2010/01/04 04:04:38  gtkwave
+ * copyright date updates
+ *
+ * Revision 1.63  2009/11/05 18:48:22  gtkwave
+ * promote to 3.3.0
+ *
+ * Revision 1.62  2009/09/20 21:45:50  gtkwave
+ * tree force open node handling changed for tcl
+ *
+ * Revision 1.61  2009/09/14 03:00:08  gtkwave
+ * bluespec code integration
+ *
+ * Revision 1.60  2009/09/08 15:31:48  gtkwave
+ * handle floating-point numbers in unformat_time()
+ *
+ * Revision 1.59  2009/08/11 22:08:58  gtkwave
+ * added iconify for gtkwave
+ *
+ * Revision 1.58  2009/08/04 18:01:56  gtkwave
+ * version bump to 3.2.2
+ *
+ * Revision 1.57  2009/04/11 21:57:53  gtkwave
+ * changed exit() to vcd_exit() in some instances for tab loader hardening
+ *
+ * Revision 1.56  2009/04/09 20:38:41  gtkwave
+ * promote to 3.2.1
+ *
+ * Revision 1.55  2009/02/23 18:29:49  gtkwave
+ * add more information on init failure for mac users
+ *
  * Revision 1.54  2009/02/17 03:20:35  gtkwave
  * promote to 3.2.0
  *
@@ -392,4 +425,3 @@ void do_popup_menu (GtkWidget *my_widget, GdkEventButton *event);
  * initial release
  *
  */
-
