@@ -39,6 +39,9 @@ while(t)
 	ctr++;
 	}
 
+GLOBALS->alloc2_chain = NULL;
+GLOBALS->outstanding = 0;
+
 #ifdef DEBUG_PRINTF
 printf("Freed %d chunks\n", ctr);
 system("date");
@@ -351,8 +354,11 @@ return(tmpspace);
 }
 
 /*
- * $Id: debug.c,v 1.8 2009/01/20 06:11:48 gtkwave Exp $
+ * $Id: debug.c,v 1.9 2009/03/25 09:20:26 gtkwave Exp $
  * $Log: debug.c,v $
+ * Revision 1.9  2009/03/25 09:20:26  gtkwave
+ * fixing reloader crashes in vcd_build_symbols if times is zero
+ *
  * Revision 1.8  2009/01/20 06:11:48  gtkwave
  * added gtkwave::getDisplayedSignals command
  *
