@@ -18,6 +18,8 @@
 #ifndef _MSC_VER
 #ifndef __MINGW32__
 #include <stdint.h>
+#else
+#include <windows.h>
 #endif
 #endif
 
@@ -37,9 +39,6 @@ size_t size;
  * types...
  */
 #ifdef G_HAVE_GINT64
-	/* typedef long long int          TimeType; */
-	/* typedef unsigned long long int UTimeType; */
-
 	typedef gint64          TimeType; 
 	typedef guint64         UTimeType;
 
@@ -136,7 +135,7 @@ GtkTooltips* gtk_tooltips_new_2(void);
 #endif
 
 #define WAVE_MATCHWORD "WAVE"
-enum AnnotateAetType { WAVE_ANNO_NONE, WAVE_ANNO_AE2, WAVE_ANNO_VZT, WAVE_ANNO_LXT2, WAVE_ANNO_MAX };
+enum AnnotateAetType { WAVE_ANNO_NONE, WAVE_ANNO_AE2, WAVE_ANNO_VZT, WAVE_ANNO_LXT2, WAVE_ANNO_FST, WAVE_ANNO_MAX };
 
 
 #if !defined _MSC_VER && !defined __MINGW32__
@@ -154,6 +153,7 @@ pid_t browser_process;
 
 TimeType marker;
 unsigned marker_set : 1;
+unsigned cygwin_remote_kill : 1;
 
 int aet_type;
 char aet_name[PATH_MAX+1];
@@ -167,8 +167,13 @@ struct gtkwave_annotate_ipc_t
 char matchword[4];			/* match against WAVE_MATCHWORD string */
 char time_string[40];			/* formatted marker time */
 
+#ifdef __MINGW32__
+HANDLE browser_process;
+#endif
+
 TimeType marker;
 unsigned marker_set : 1;
+unsigned cygwin_remote_kill : 1;
 
 int aet_type;
 char aet_name[PATH_MAX+1];
@@ -195,8 +200,20 @@ unsigned viewer_is_initialized : 1;
 #endif
 
 /*
- * $Id: debug.h,v 1.6 2009/01/20 06:11:48 gtkwave Exp $
+ * $Id: debug.h,v 1.10 2009/10/08 15:32:53 gtkwave Exp $
  * $Log: debug.h,v $
+ * Revision 1.10  2009/10/08 15:32:53  gtkwave
+ * remove all instances of "long long"
+ *
+ * Revision 1.9  2009/06/07 08:40:44  gtkwave
+ * adding FST support
+ *
+ * Revision 1.8  2009/04/24 04:24:22  gtkwave
+ * reload and cygwin fixes for rtlbrowse
+ *
+ * Revision 1.7  2009/04/23 21:57:53  gtkwave
+ * added mingw support for rtlbrowse
+ *
  * Revision 1.6  2009/01/20 06:11:48  gtkwave
  * added gtkwave::getDisplayedSignals command
  *
