@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 2008.
+ * Copyright (c) Tony Bybell 2008-2009.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -354,7 +354,7 @@ while(s)
 				if((chval2=chval))
 				while((ch=*(chval2++)))
 					{
-					if(((ch>='1')&&(ch<='9'))||(ch=='H')||((ch>='A')&&(ch<='F')))
+					if(((ch>='1')&&(ch<='9'))||(ch=='h')||(ch=='H')||((ch>='A')&&(ch<='F')))
 						{
 						s->search_result=1;
 						break;
@@ -369,7 +369,7 @@ while(s)
 				s->search_result=1;
 				while((ch=*(chval2++)))
 					{
-					if((ch!='0')&&(ch!='L'))
+					if((ch!='0')&&(ch!='l')&&(ch!='L'))
 						{
 						s->search_result=0;
 						break;
@@ -385,7 +385,7 @@ while(s)
 				s->search_result=1;
 				while((ch=*(chval2++)))
 					{
-					if(ch!='Z')
+					if((ch!='z')&&(ch!='Z'))
 						{
 						s->search_result=0;
 						break;
@@ -401,7 +401,7 @@ while(s)
 				s->search_result=1;
 				while((ch=*(chval2++)))
 					{
-					if((ch!='X')&&(ch!='W'))
+					if((ch!='X')&&(ch!='W')&&(ch!='x')&&(ch!='w'))
 						{
 						s->search_result=0;
 						break;
@@ -573,8 +573,11 @@ return(table);
 }
    
 /*
- * $Id: edgebuttons.c,v 1.6 2008/06/11 08:01:48 gtkwave Exp $
+ * $Id: edgebuttons.c,v 1.7 2009/07/07 20:12:53 gtkwave Exp $
  * $Log: edgebuttons.c,v $
+ * Revision 1.7  2009/07/07 20:12:53  gtkwave
+ * convert hex capitalization to match verilog
+ *
  * Revision 1.6  2008/06/11 08:01:48  gtkwave
  * gcc 4.3.x compiler warning fixes
  *
