@@ -642,7 +642,7 @@ if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress))
 		build_tree_from_name(GLOBALS->facs[i]->name, i);
                 }
 /* SPLASH */                            splash_sync(4, 5);  
-        treegraft(GLOBALS->treeroot);
+        treegraft(&GLOBALS->treeroot);
                                 
         fprintf(stderr, EXTLOAD"Sorting facility hierarchy tree.\n");
         treesort(GLOBALS->treeroot, NULL);
@@ -708,7 +708,7 @@ if((GLOBALS->fast_tree_sort) && (!GLOBALS->do_hier_compress))
 		        }        
 		}
 /* SPLASH */                            splash_sync(5, 5);  
-	treegraft(GLOBALS->treeroot);
+	treegraft(&GLOBALS->treeroot);
 	treesort(GLOBALS->treeroot, NULL);
 	}
 
@@ -1018,8 +1018,11 @@ if(nold!=np)
 #endif
 
 /*
- * $Id: extload.c,v 1.4 2009/02/16 17:16:05 gtkwave Exp $
+ * $Id: extload.c,v 1.5 2009/07/01 07:39:12 gtkwave Exp $
  * $Log: extload.c,v $
+ * Revision 1.5  2009/07/01 07:39:12  gtkwave
+ * decorating hierarchy tree with module type info
+ *
  * Revision 1.4  2009/02/16 17:16:05  gtkwave
  * extload error hardening and recovery
  *
