@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2008.
+ * Copyright (c) Tony Bybell 1999-2009.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -90,15 +90,35 @@ GtkWidget *pFileChoose;
 GtkWidget *pWindowMain;
 GtkFileFilter *filter;
 #endif
+
+if(!*filesel_path) /* if no name specified, hijack loaded file name path */
+	{
+	if(GLOBALS->loaded_file_name)
+		{
+		char *tname = strdup_2(GLOBALS->loaded_file_name);
+		char *delim = strrchr(tname, '/');
+		if(!delim) delim =  strrchr(tname, '\\');
+		if(delim) 
+			{ 
+			*(delim+1) = 0; /* keep slash for gtk_file_chooser_set_filename vs gtk_file_chooser_set_current_folder test below */
+			*filesel_path = tname;
+			}
+			else
+			{
+			free_2(tname);
+			}
+		}
+	}
+
  
-if(GLOBALS->script_handle)
+if(GLOBALS->wave_script_args)
 	{
 	char *s = NULL;
 
 	GLOBALS->fileselbox_text=filesel_path;
 	GLOBALS->filesel_ok=1;
 
-	while((!s)&&(!feof(GLOBALS->script_handle))) s = fgetmalloc_stripspaces(GLOBALS->script_handle);
+	while((!s)&&(GLOBALS->wave_script_args->curr)) s = wave_script_args_fgetmalloc_stripspaces(GLOBALS->wave_script_args);
 
 	if(*GLOBALS->fileselbox_text) free_2(*GLOBALS->fileselbox_text); 
 	if(!s)
@@ -196,7 +216,18 @@ if(is_writemode)
 	        NULL);
 	}
 
-if((can_set_filename) && (*filesel_path)) gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(pFileChoose), *filesel_path);
+if((can_set_filename) && (*filesel_path)) 
+	{
+	int flen = strlen(*filesel_path);
+	if(((*filesel_path)[flen-1]=='/') || ((*filesel_path)[flen-1]=='\\'))
+		{
+		gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(pFileChoose), *filesel_path);
+		}
+		else
+		{
+		gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(pFileChoose), *filesel_path);
+		}
+	}
 
 if(pattn)
 	{
@@ -212,6 +243,7 @@ gtk_container_set_border_width(GTK_CONTAINER(pFileChoose), 10);
 gtk_window_set_position(GTK_WINDOW(pFileChoose), GTK_WIN_POS_CENTER);
 gtk_window_set_modal(GTK_WINDOW(pFileChoose), TRUE);
 gtk_window_set_policy(GTK_WINDOW(pFileChoose), FALSE, FALSE, FALSE);
+gtk_window_set_resizable(GTK_WINDOW(pFileChoose), TRUE); /* some distros need this */
 if(pWindowMain)
 	{
 	gtk_window_set_transient_for(GTK_WINDOW(pFileChoose), GTK_WINDOW(pWindowMain));
@@ -284,8 +316,17 @@ fix_suffix:                     s2 = malloc_2(strlen(s) + strlen(suffix) + 1);
 }
 
 /*
- * $Id: file.c,v 1.11 2009/01/13 22:56:47 gtkwave Exp $
+ * $Id: file.c,v 1.14 2009/12/15 23:40:59 gtkwave Exp $
  * $Log: file.c,v $
+ * Revision 1.14  2009/12/15 23:40:59  gtkwave
+ * removed old style scripts; also removed tempfiles for Tcl args
+ *
+ * Revision 1.13  2009/08/18 17:21:05  gtkwave
+ * added gtk_window_set_resizable to the file chooser mode select
+ *
+ * Revision 1.12  2009/07/16 15:36:34  gtkwave
+ * file name updates...derive unspecified names from loaded file name directory
+ *
  * Revision 1.11  2009/01/13 22:56:47  gtkwave
  * revert to old file chooser in mingw as new one can't be resized
  *
