@@ -1,5 +1,5 @@
 /*  GHDL Wavefile reader interface.
-    Copyright (C) 2005-2006 Tristan Gingold and Tony Bybell
+    Copyright (C) 2005-2010 Tristan Gingold and Tony Bybell
 
     GHDL is free software; you can redistribute it and/or modify it under
     the terms of the GNU General Public License as published by the Free
@@ -20,6 +20,7 @@
 #include "globals.h"
 #include <config.h>
 #include "ghw.h"
+#include "ghwlib.h"
 
 /************************ splay ************************/
 
@@ -152,7 +153,7 @@ if(s[len] == ']')
 	{
 	for(i=len-1;i>0;i--)
 		{
-		if((s[i]>='0') && (s[i]<='9')) continue;
+		if(((s[i]>='0') && (s[i]<='9')) || (s[i] == '-')) continue;
 		if(s[i] != '[') break;
 		return(i);	/* position right before left bracket for strncmp */
 		}
@@ -288,8 +289,14 @@ for(i=0;i<GLOBALS->numfacs;i++)
 	}
 
 recurse_tree_fix_from_whichcache(GLOBALS->treeroot);
-incinerate_whichcache_tree(GLOBALS->gwt_ghw_c_1); GLOBALS->gwt_ghw_c_1 = NULL;
-incinerate_whichcache_tree(GLOBALS->gwt_corr_ghw_c_1); GLOBALS->gwt_corr_ghw_c_1 = NULL;
+if(GLOBALS->gwt_ghw_c_1)
+	{
+	incinerate_whichcache_tree(GLOBALS->gwt_ghw_c_1); GLOBALS->gwt_ghw_c_1 = NULL;
+	}
+if(GLOBALS->gwt_corr_ghw_c_1)
+	{
+	incinerate_whichcache_tree(GLOBALS->gwt_corr_ghw_c_1); GLOBALS->gwt_corr_ghw_c_1 = NULL;
+	}
  
 for(i=0;i<GLOBALS->numfacs;i++)
         {
@@ -345,13 +352,17 @@ build_hierarchy_array (struct ghw_handler *h, union ghw_type *arr, int dim,
 	char *nam;
 	struct ghw_range_i32 *r;
 	struct tree *last;
+	int len;
 	
 	last = NULL;
 	r = &arr->sa.rngs[dim]->i32;
+	len = ghw_get_range_length ((union ghw_range *)r);
+	if (len <= 0)
+	  break;
 	v = r->left;
 	while (1)
 	  {
-	    sprintf(GLOBALS->asbuf, "%s%c%d", pfx, dim == 0 ? '[' : ',', v);
+	    sprintf(GLOBALS->asbuf, "%s%c"GHWLD, pfx, dim == 0 ? '[' : ',', v);
             nam = strdup_2(GLOBALS->asbuf);
 	    build_hierarchy_array (h, arr, dim + 1, nam, res, sig);
 	    free_2(nam);
@@ -371,13 +382,17 @@ build_hierarchy_array (struct ghw_handler *h, union ghw_type *arr, int dim,
 	char *nam;
 	struct ghw_range_e8 *r;
 	struct tree *last;
+	int len;
 	
 	last = NULL;
 	r = &arr->sa.rngs[dim]->e8;
+	len = ghw_get_range_length ((union ghw_range *)r);
+	if (len <= 0)
+	  break;
 	v = r->left;
 	while (1)
 	  {
-	    sprintf(GLOBALS->asbuf, "%s%c%d", pfx, dim == 0 ? '[' : ',', v);
+	    sprintf(GLOBALS->asbuf, "%s%c"GHWLD, pfx, dim == 0 ? '[' : ',', v);
             nam = strdup_2(GLOBALS->asbuf);
 	    build_hierarchy_array (h, arr, dim + 1, nam, res, sig);
 	    free_2(nam);
@@ -476,6 +491,8 @@ build_hierarchy_type (struct ghw_handler *h, union ghw_type *t,
     }
 }
 
+/* Create the gtkwave tree from the GHW hierarchy.  */
+
 static struct tree *
 build_hierarchy (struct ghw_handler *h, struct ghw_hie *hie)
 {
@@ -483,6 +500,7 @@ build_hierarchy (struct ghw_handler *h, struct ghw_hie *hie)
   struct tree *t_ch;
   struct tree *prev;
   struct ghw_hie *ch;
+  unsigned char ttype;
 
   switch (hie->kind)
     {
@@ -492,6 +510,21 @@ build_hierarchy (struct ghw_handler *h, struct ghw_hie *hie)
     case ghw_hie_generate_for:
     case ghw_hie_generate_if:
     case ghw_hie_package:
+
+      /* Convert kind.  */
+      switch(hie->kind)
+		{
+	    	case ghw_hie_design:		ttype = TREE_VHDL_ST_DESIGN; break;
+    		case ghw_hie_block:		ttype = TREE_VHDL_ST_BLOCK; break;
+    		case ghw_hie_instance:		ttype = TREE_VHDL_ST_INSTANCE; break;
+    		case ghw_hie_generate_for:	ttype = TREE_VHDL_ST_GENFOR; break;
+    		case ghw_hie_generate_if:	ttype = TREE_VHDL_ST_GENIF; break;
+    		case ghw_hie_package:		
+		default:
+						ttype = TREE_VHDL_ST_PACKAGE; break;
+		}
+
+      /* For iterative generate, add the index.  */
       if (hie->kind == ghw_hie_generate_for)
 	{
 	  char buf[128];
@@ -504,6 +537,7 @@ build_hierarchy (struct ghw_handler *h, struct ghw_hie *hie)
 	  buf_len = strlen (buf);
 
           t = (struct tree *) calloc_2(1, sizeof (struct tree) + (2 + buf_len + name_len));
+	  t->kind = ttype;
 	  n = t->name;
 
 	  memcpy (n, hie->name, name_len);
@@ -519,15 +553,19 @@ build_hierarchy (struct ghw_handler *h, struct ghw_hie *hie)
           if(hie->name)
 		{
           	t = (struct tree *) calloc_2(1, sizeof (struct tree) + strlen(hie->name));
+	  	t->kind = ttype;
           	strcpy(t->name, (char *)hie->name);
 		}
 		else
 		{
           	t = (struct tree *) calloc_2(1, sizeof (struct tree));
+	  	t->kind = ttype;
 		}
         }
 
       t->which = -1;
+
+      /* Recurse.  */
       prev = NULL;
       for (ch = hie->u.blk.child; ch != NULL; ch = ch->brother)
 	{
@@ -552,9 +590,25 @@ build_hierarchy (struct ghw_handler *h, struct ghw_hie *hie)
     case ghw_hie_port_linkage:
       {
 	unsigned int *ptr = hie->u.sig.sigs;
+
+        /* Convert kind.  */
+        switch(hie->kind)
+		{
+		case ghw_hie_signal:		ttype = TREE_VHDL_ST_SIGNAL; break;
+		case ghw_hie_port_in:		ttype = TREE_VHDL_ST_PORTIN; break;
+		case ghw_hie_port_out:		ttype = TREE_VHDL_ST_PORTOUT; break;
+		case ghw_hie_port_inout:	ttype = TREE_VHDL_ST_PORTINOUT; break;
+		case ghw_hie_port_buffer:	ttype = TREE_VHDL_ST_BUFFER; break;
+		case ghw_hie_port_linkage:	
+		default:
+						ttype = TREE_VHDL_ST_LINKAGE; break;
+		}
+
+        /* Convert type.  */
 	t = build_hierarchy_type (h, hie->u.sig.type, hie->name, &ptr);
 	if (*ptr != 0)
 	  abort ();
+	if(t) { t->kind = ttype; }
 	return t;
       }
     default:
@@ -579,7 +633,7 @@ facs_debug (void)
       if (n->ext)
 	printf ("  ext: %d - %d\n", n->ext->msi, n->ext->lsi);
       for (h = &n->head; h; h = h->next)
-	printf ("  time:"TTFormat" flags:%02x vect:%p\n",
+	printf ("  time:"GHWLLD" flags:%02x vect:%p\n",
 		h->time, h->flags, h->v.h_vector);
     }
 }
@@ -819,13 +873,13 @@ add_history (struct ghw_handler *h, struct Node *n, int sig_num)
       break;
     case ghdl_rtik_type_i32:
     case ghdl_rtik_type_p32:
-      sprintf (GLOBALS->asbuf, "%d", sig->val->i32);
+      sprintf (GLOBALS->asbuf, GHWLD, sig->val->i32);
       he->v.h_vector = strdup_2(GLOBALS->asbuf);    
       is_vector = 1;
       break;
     case ghdl_rtik_type_i64:
     case ghdl_rtik_type_p64:
-      sprintf (GLOBALS->asbuf, TTFormat, sig->val->i64);
+      sprintf (GLOBALS->asbuf, GHWLLD, sig->val->i64);
       he->v.h_vector = strdup_2(GLOBALS->asbuf);    
       is_vector = 1;
       break;
@@ -925,7 +979,7 @@ read_traces (struct ghw_handler *h)
 	case ghw_res_snapshot:
 	  if (h->snap_time > GLOBALS->max_time)
 	    GLOBALS->max_time = h->snap_time;
-	  /* printf ("Time is "TTFormat"\n", h->snap_time); */
+	  /* printf ("Time is "GHWLLD"\n", h->snap_time); */
 
 	  for (i = 0; i < h->nbr_sigs; i++)
 	    add_history (h, GLOBALS->nxp_ghw_c_1[i], i);
@@ -935,7 +989,7 @@ read_traces (struct ghw_handler *h)
 	    {
 	      int sig;
 
-	      /* printf ("Time is "TTFormat"\n", h->snap_time); */
+	      /* printf ("Time is "GHWLLD"\n", h->snap_time); */
 	      if (h->snap_time < LLDescriptor(9223372036854775807))
 		{
 		  if (h->snap_time > GLOBALS->max_time)
@@ -1051,7 +1105,7 @@ ghw_main(char *fname)
 
   GLOBALS->is_ghw = 1;
 
-  fprintf(stderr, "["TTFormat"] start time.\n["TTFormat"] end time.\n", GLOBALS->min_time*GLOBALS->time_scale, GLOBALS->max_time*GLOBALS->time_scale);
+  fprintf(stderr, "["GHWLLD"] start time.\n["GHWLLD"] end time.\n", GLOBALS->min_time*GLOBALS->time_scale, GLOBALS->max_time*GLOBALS->time_scale);
   if(GLOBALS->num_glitches_ghw_c_1) fprintf(stderr, "Warning: encountered %d glitch%s across %d glitch region%s.\n",
                 GLOBALS->num_glitches_ghw_c_1, (GLOBALS->num_glitches_ghw_c_1!=1)?"es":"",
                 GLOBALS->num_glitch_regions_ghw_c_1, (GLOBALS->num_glitch_regions_ghw_c_1!=1)?"s":"");
@@ -1062,8 +1116,26 @@ ghw_main(char *fname)
 /*******************************************************************************/
 
 /*
- * $Id: ghw.c,v 1.4 2008/12/25 03:21:57 gtkwave Exp $
+ * $Id: ghw.c,v 1.10 2010/01/05 06:18:33 gtkwave Exp $
  * $Log: ghw.c,v $
+ * Revision 1.10  2010/01/05 06:18:33  gtkwave
+ * emergency fix on missing comment causing bad code
+ *
+ * Revision 1.9  2009/12/29 07:07:49  gtkwave
+ * fixes for ghw files
+ *
+ * Revision 1.8  2009/07/01 21:58:31  gtkwave
+ * more GHW module type adds for icons in hierarchy window
+ *
+ * Revision 1.7  2009/07/01 18:22:34  gtkwave
+ * added VHDL (GHW) instance types as icons
+ *
+ * Revision 1.6  2009/06/24 19:31:44  gtkwave
+ * added capability in GHW to handle negative offsets in bitstrands
+ *
+ * Revision 1.5  2009/04/27 21:26:34  gtkwave
+ * printf format string warning fixes
+ *
  * Revision 1.4  2008/12/25 03:21:57  gtkwave
  * -Wshadow warning fixes
  *
