@@ -1,5 +1,5 @@
 /*  GHDL Wavefile reader library.
-    Copyright (C) 2005 Tristan Gingold
+    Copyright (C) 2005-2009 Tristan Gingold
 
     GHDL is free software; you can redistribute it and/or modify it under
     the terms of the GNU General Public License as published by the Free
@@ -24,25 +24,28 @@
 #include <stdio.h>
 #include <stdlib.h>
 
+
+#if HAVE_INTTYPES_H
+#include <inttypes.h>
+#define GHWLLD "%"PRId64
+#define GHWLD  "%"PRId32
+#endif
+
+
+#ifndef GHWLLD
 #if HAVE_STDINT_H
 #include <stdint.h>
 #if __WORDSIZE == 64
 	#define GHWLLD "%ld"
+	#define GHWLD "%d"
 #else
 	#define GHWLLD "%lld"
-#endif
-#endif
-#if HAVE_INTTYPES_H
-#include <inttypes.h>
-#ifndef GHWLLD
-#if __WORDSIZE == 64
 	#define GHWLLD "%ld"
-#else
-	#define GHWLLD "%lld"
 #endif
 #endif
 #endif
 
+
 enum ghdl_rtik {
   ghdl_rtik_top,		/* 0  */
   ghdl_rtik_library,
@@ -408,6 +411,8 @@ void ghw_close (struct ghw_handler *h);
 
 const char *ghw_get_dir (int is_downto);
 
+int ghw_get_range_length (union ghw_range *rng);
+
 /* Note: TYPE must be a base type (used only to display literals).  */
 void ghw_disp_range (union ghw_type *type, union ghw_range *rng);
 
@@ -417,8 +422,14 @@ void ghw_disp_types (struct ghw_handler *h);
 #endif /* _GHWLIB_H_ */
 
 /*
- * $Id: ghwlib.h,v 1.3 2008/07/01 18:51:06 gtkwave Exp $
+ * $Id: ghwlib.h,v 1.5 2009/12/29 07:07:49 gtkwave Exp $
  * $Log: ghwlib.h,v $
+ * Revision 1.5  2009/12/29 07:07:49  gtkwave
+ * fixes for ghw files
+ *
+ * Revision 1.4  2009/04/27 21:26:34  gtkwave
+ * printf format string warning fixes
+ *
  * Revision 1.3  2008/07/01 18:51:06  gtkwave
  * compiler warning fixes for amd64
  *
