@@ -43,6 +43,7 @@
 
 #include "lxt2_read.h"
 #include "vzt_read.h"
+#include "fst.h"
 
 #ifdef __MINGW32__
 #define sleep(x) Sleep(x)
@@ -94,6 +95,7 @@ TR_RJUSTIFY, /* default_flags 5 */
 0, /* hier_max_level 8 */
 0, /* timestart_from_savefile */
 0, /* timestart_from_savefile_valid */
+0, /* group_depth */
 
 
 /*
@@ -161,6 +163,9 @@ NULL, /* busycursor_busy_c_1 23 */
 -1, /* color_mdgray 53 */
 -1, /* color_dkgray 54 */
 -1, /* color_dkblue 55 */
+-1, /* color_brkred */
+-1, /* color_ltblue */
+-1, /* color_gmstrd */
 
 
 /*
@@ -254,6 +259,24 @@ NULL, /* fonts_layout */
 1, /* use_pango_fonts */
 
 
+/*
+ * fst.c
+ */
+NULL, /* fst_fst_c_1 */
+NULL, /* fst_scope_name */
+0, /* first_cycle_fst_c_3 */
+0, /* last_cycle_fst_c_3 */
+0, /* total_cycles_fst_c_3 */
+NULL, /* fst_table_fst_c_1 */
+NULL, /* mvlfacs_fst_c_3 */
+NULL, /* mvlfacs_fst_alias */
+NULL, /* mvlfacs_fst_rvs_alias */
+0, /* fst_maxhandle */
+0, /* busycnt_fst_c_2 */
+NULL, /* double_curr_fst */
+NULL, /* double_fini_fst */
+
+
 /*
  * ghw.c
  */
@@ -407,12 +430,14 @@ NULL, /* lt_buf_lxt_c_1 183 */
 /* 
  * main.c
  */
+NULL, /* missing_file_toolbar */
 NULL, /* argvlist */
 #if defined(HAVE_LIBTCL)
 NULL, /* interp */
 #endif
 NULL, /* repscript_name */
 500, /* repscript_period */
+NULL, /* tcl_init_cmd */
 0, /* tcl_running */
 0, /* block_xy_update */
 NULL, /* winname */
@@ -428,7 +453,8 @@ NULL, /* unoptimized_vcd_file_name  */
 NULL, /* skip_start */
 NULL, /* skip_end */
 NULL, /* indirect_fname */
-NO_FILE, /* loaded_file_type */
+MISSING_FILE, /* loaded_file_type */
+0, /* is_optimized_stdin_vcd */
 NULL, /* whoami 190 */
 NULL, /* logfile 191 */
 NULL, /* stems_name 192 */
@@ -446,6 +472,7 @@ NULL, /* toppanedwindow 203 */
 NULL, /* sstpane 204 */
 NULL, /* expanderwindow 205 */
 0, /* disable_window_manager 206 */
+0, /* disable_empty_gui */
 1, /* paned_pack_semantics 207 */
 0, /* zoom_was_explicitly_set 208 */
 1000, /* initial_window_x 209 */
@@ -469,7 +496,9 @@ NULL, /* expanderwindow 205 */
 0, /* force_toolbars 221 */
 0, /* hide_sst 222 */
 1, /* sst_expanded 223 */
+#ifdef WAVE_USE_GTK2
 0, /* socket_xid 224 */
+#endif
 0, /* disable_menus 225 */
 NULL, /* ftext_main_main_c_1 226 */
 #ifdef WAVE_USE_GTK2
@@ -495,7 +524,7 @@ NULL, /* cleanup_markerbox_c_4 233 */
  */ 
 NULL, /* cutcopylist */
 0, /* enable_fast_exit 236 */
-NULL, /* script_handle 237 */
+NULL, /* wave_script_args 237 */
 0, /* ignore_savefile_pos 238 */
 0, /* ignore_savefile_size 239 */
 NULL, /* item_factory_menu_c_1 241 */
@@ -563,6 +592,40 @@ NULL, /* wave_info_pixmap 293 */
 NULL, /* wave_info_mask 294 */
 NULL, /* wave_alert_pixmap 296 */
 NULL, /* wave_alert_mask 297 */
+NULL, /* hiericon_module_pixmap */
+NULL, /* hiericon_module_mask */
+NULL, /* hiericon_task_pixmap */
+NULL, /* hiericon_task_mask */
+NULL, /* hiericon_function_pixmap */
+NULL, /* hiericon_function_mask */
+NULL, /* hiericon_begin_pixmap */
+NULL, /* hiericon_begin_mask */
+NULL, /* hiericon_fork_pixmap */
+NULL, /* hiericon_fork_mask */
+NULL, /* hiericon_design_pixmap */
+NULL, /* hiericon_design_mask */
+NULL, /* hiericon_block_pixmap */
+NULL, /* hiericon_block_mask */
+NULL, /* hiericon_generateif_pixmap */
+NULL, /* hiericon_generateif_mask */
+NULL, /* hiericon_generatefor_pixmap */
+NULL, /* hiericon_generatefor_mask */
+NULL, /* hiericon_instance_pixmap */
+NULL, /* hiericon_instance_mask */
+NULL, /* hiericon_package_pixmap */
+NULL, /* hiericon_package_mask */
+NULL, /* hiericon_signal_pixmap */
+NULL, /* hiericon_signal_mask */
+NULL, /* hiericon_portin_pixmap */
+NULL, /* hiericon_portin_mask */
+NULL, /* hiericon_portout_pixmap */
+NULL, /* hiericon_portout_mask */
+NULL, /* hiericon_portinout_pixmap */
+NULL, /* hiericon_portinout_mask */
+NULL, /* hiericon_buffer_pixmap */
+NULL, /* hiericon_buffer_mask */
+NULL, /* hiericon_linkage_pixmap */
+NULL, /* hiericon_linkage_mask */
 
 
 /*
@@ -611,9 +674,10 @@ NULL, /* regex_ok_regex_c_1 322 */
  */
 0, /* is_active_renderopt_c_3 323 */
 0, /* window_renderopt_c_6 324 */
+NULL, /* filesel_print_pdf_renderopt_c_1 */
 NULL, /* filesel_print_ps_renderopt_c_1 325 */
 NULL, /* filesel_print_mif_renderopt_c_1 326 */
-{0,0}, /* target_mutex_renderopt_c_1 328 */
+{0,0,0}, /* target_mutex_renderopt_c_1 328 */
 {0,0,0,0,0}, /* page_mutex_renderopt_c_1 330 */
 {0,0}, /* render_mutex_renderopt_c_1 332 */
 0, /* page_size_type_renderopt_c_1 333 */
@@ -793,6 +857,7 @@ NULL, /* clist_translate_c_4 442 */
  * tree.c
  */
 NULL, /* treeroot 443 */
+NULL, /* mod_tree_parent */
 NULL, /* module_tree_c_1 444 */
 0, /* module_len_tree_c_1 445 */
 NULL, /* terminals_tchain_tree_c_1 446 */
@@ -911,7 +976,6 @@ NULL, /* indexed_vcd_c_1 504 */
 0, /* numsyms_vcd_c_1 505 */
 NULL, /* he_curr_vcd_c_1 506 */
 NULL, /* he_fini */
-NULL, /* queuedevents_vcd_c_1 507 */
 ~0, /* vcd_minid_vcd_c_1 508 */
 0, /* vcd_maxid_vcd_c_1 509 */
 0, /* err_vcd_c_1 510 */
@@ -950,7 +1014,6 @@ NULL, /* vcdsymcurr */
 NULL, /* sorted_vcd_partial_c_2 535 */
 NULL, /* indexed_vcd_partial_c_2 536 */
 0, /* numsyms_vcd_partial_c_2 538 */
-NULL, /* queuedevents_vcd_partial_c_2 539 */
 ~0, /* vcd_minid_vcd_partial_c_2 540 */
 0, /* vcd_maxid_vcd_partial_c_2 541 */
 0, /* err_vcd_partial_c_2 542 */
@@ -964,9 +1027,13 @@ NULL, /* vsplitcurr */
  * vcd_recoder.c
  */
 NULL, /* time_vlist_vcd_recoder_c_1 548 */
+NULL, /* time_vlist_vcd_recoder_write */
+NULL, /* fastload_depacked */
+NULL, /* fastload_current */
 0, /* time_vlist_count_vcd_recoder_c_1 549 */
 NULL, /* vcd_handle_vcd_recoder_c_2 550 */
 0, /* vcd_is_compressed_vcd_recoder_c_2 551 */
+VCD_FSL_NONE, /* use_fastload */
 0, /* vcdbyteno_vcd_recoder_c_3 552 */
 0, /* error_count_vcd_recoder_c_3 553 */
 0, /* header_over_vcd_recoder_c_3 554 */
@@ -1111,6 +1178,9 @@ NULL, /* gc_normal 653 */
 NULL, /* gc_mdgray 654 */
 NULL, /* gc_dkgray 655 */
 NULL, /* gc_dkblue 656 */
+NULL, /* gc_brkred */
+NULL, /* gc_ltblue */
+NULL, /* gc_gmstrd */
 0, /* fill_in_smaller_rgb_areas_wavewindow_c_1 659 */
 -1, /* prev_markertime */
 NULL, /* gccache_ltgray */
@@ -1118,6 +1188,9 @@ NULL, /* gccache_normal */
 NULL, /* gccache_mdgray */
 NULL, /* gccache_dkgray */
 NULL, /* gccache_dkblue */
+NULL, /* gccache_brkred */
+NULL, /* gccache_ltblue */
+NULL, /* gccache_gmstrd */
 NULL, /* gccache_back_wavewindow_c_1 */
 NULL, /* gccache_baseline_wavewindow_c_1 */
 NULL, /* gccache_grid_wavewindow_c_1 */
@@ -1239,6 +1312,12 @@ void reload_into_new_context(void)
  char cached_ignore_savefile_size = GLOBALS->ignore_savefile_size;
  char cached_splash_disable = GLOBALS->splash_disable;
 
+ if((GLOBALS->loaded_file_type == MISSING_FILE)||(GLOBALS->is_optimized_stdin_vcd))
+	{
+	fprintf(stderr, "GTKWAVE | Nothing to reload!\n");
+	return;
+	}
+
  logbox_reload();
 
  /* let all GTK/X events spin through in order to keep menus from freezing open during reload */
@@ -1331,6 +1410,8 @@ void reload_into_new_context(void)
  new_globals->zoom = GLOBALS->zoom;
 
  /* Default colors, X contexts, pixmaps, drawables, etc from signalwindow.c and wavewindow.c */
+ new_globals->possibly_use_rc_defaults = GLOBALS->possibly_use_rc_defaults;
+
  new_globals->signalarea_event_box = GLOBALS->signalarea_event_box;
  new_globals->keypress_handler_id = GLOBALS->keypress_handler_id;
  new_globals->signalarea = GLOBALS->signalarea;
@@ -1347,6 +1428,9 @@ void reload_into_new_context(void)
  new_globals->gc_mdgray = GLOBALS->gc_mdgray;
  new_globals->gc_dkgray = GLOBALS->gc_dkgray;
  new_globals->gc_dkblue = GLOBALS->gc_dkblue;
+ new_globals->gc_brkred = GLOBALS->gc_brkred;
+ new_globals->gc_ltblue = GLOBALS->gc_ltblue;
+ new_globals->gc_gmstrd = GLOBALS->gc_gmstrd;
  new_globals->made_sgc_contexts_wavewindow_c_1 = GLOBALS->made_sgc_contexts_wavewindow_c_1;
 
  new_globals->gc_back_wavewindow_c_1 = GLOBALS->gc_back_wavewindow_c_1;
@@ -1380,6 +1464,9 @@ void reload_into_new_context(void)
  new_globals->gccache_mdgray = GLOBALS->gccache_mdgray;
  new_globals->gccache_dkgray = GLOBALS->gccache_dkgray;
  new_globals->gccache_dkblue = GLOBALS->gccache_dkblue;
+ new_globals->gccache_brkred = GLOBALS->gccache_brkred;
+ new_globals->gccache_ltblue = GLOBALS->gccache_ltblue;
+ new_globals->gccache_gmstrd = GLOBALS->gccache_gmstrd;
  new_globals->gccache_back_wavewindow_c_1 = GLOBALS->gccache_back_wavewindow_c_1;
  new_globals->gccache_baseline_wavewindow_c_1 = GLOBALS->gccache_baseline_wavewindow_c_1;
  new_globals->gccache_grid_wavewindow_c_1 = GLOBALS->gccache_grid_wavewindow_c_1;
@@ -1465,6 +1552,8 @@ void reload_into_new_context(void)
  new_globals->wave_info_pixmap = GLOBALS->wave_info_pixmap;
  new_globals->wave_alert_pixmap = GLOBALS->wave_alert_pixmap;
 
+ clone_icon_pointers_across_contexts(new_globals, GLOBALS);
+
  /* rc.c */
  new_globals->scale_to_time_dimension = GLOBALS->scale_to_time_dimension;
  new_globals->zoom_dyn = GLOBALS->zoom_dyn;
@@ -1507,6 +1596,9 @@ void reload_into_new_context(void)
  new_globals->color_mdgray = GLOBALS->color_mdgray;
  new_globals->color_dkgray = GLOBALS->color_dkgray;
  new_globals->color_dkblue = GLOBALS->color_dkblue;
+ new_globals->color_brkred = GLOBALS->color_brkred;
+ new_globals->color_ltblue = GLOBALS->color_ltblue;
+ new_globals->color_gmstrd = GLOBALS->color_gmstrd;
 
  new_globals->atomic_vectors = GLOBALS->atomic_vectors;
  new_globals->autoname_bundles = GLOBALS->autoname_bundles;
@@ -1560,6 +1652,7 @@ void reload_into_new_context(void)
  new_globals->ps_maxveclen = GLOBALS->ps_maxveclen;
  new_globals->vector_padding = GLOBALS->vector_padding;
  new_globals->zoombase = GLOBALS->zoombase;
+
  new_globals->splash_disable = 1; /* to disable splash for reload */
 
  new_globals->logfiles = GLOBALS->logfiles; /* this value is a ** chameleon!  malloc'd region is outside debug.c control! */
@@ -1569,6 +1662,7 @@ void reload_into_new_context(void)
  strcpy2_into_new_context(new_globals, &new_globals->fontname_signals, &GLOBALS->fontname_signals); 
  strcpy2_into_new_context(new_globals, &new_globals->fontname_waves, &GLOBALS->fontname_waves);
  strcpy2_into_new_context(new_globals, &new_globals->cutcopylist, &GLOBALS->cutcopylist);
+ strcpy2_into_new_context(new_globals, &new_globals->tcl_init_cmd, &GLOBALS->tcl_init_cmd);
  strcpy2_into_new_context(new_globals, &new_globals->repscript_name, &GLOBALS->repscript_name);
  new_globals->repscript_period = GLOBALS->repscript_period;
 
@@ -1580,9 +1674,7 @@ void reload_into_new_context(void)
  if(GLOBALS->vlist_handle)
 	{
 	vlist_kill_spillfile();
-	vlist_init_spillfile();
-	new_globals->vlist_handle = GLOBALS->vlist_handle;
-	new_globals->vlist_bytes_written = GLOBALS->vlist_bytes_written;
+	new_globals->use_fastload = (GLOBALS->use_fastload != VCD_FSL_NONE) ? VCD_FSL_WRITE : VCD_FSL_NONE;
 	}
 
  /* lxt2.c / vzt.c / ae2.c */
@@ -1596,7 +1688,7 @@ void reload_into_new_context(void)
  strcpy2_into_new_context(new_globals, &new_globals->winname, &GLOBALS->winname); /* for page swapping */
 
  /* menu.c */
- new_globals->script_handle = GLOBALS->script_handle;
+ new_globals->wave_script_args = GLOBALS->wave_script_args;
  new_globals->item_factory_menu_c_1 = GLOBALS->item_factory_menu_c_1;
  strcpy2_into_new_context(new_globals, &new_globals->filesel_writesave, &GLOBALS->filesel_writesave);
  new_globals->save_success_menu_c_1 = GLOBALS->save_success_menu_c_1; 
@@ -1606,6 +1698,13 @@ void reload_into_new_context(void)
  strcpy2_into_new_context(new_globals, &new_globals->filesel_lxt_writesave, &GLOBALS->filesel_lxt_writesave);
  strcpy2_into_new_context(new_globals, &new_globals->filesel_tim_writesave, &GLOBALS->filesel_tim_writesave);
 
+ strcpy2_into_new_context(new_globals, &new_globals->stems_name, &GLOBALS->stems_name); /* remaining fileselbox() vars not handled elsewhere */
+ strcpy2_into_new_context(new_globals, &new_globals->filesel_logfile_menu_c_1, &GLOBALS->filesel_logfile_menu_c_1);
+ strcpy2_into_new_context(new_globals, &new_globals->filesel_scriptfile_menu, &GLOBALS->filesel_scriptfile_menu);
+ strcpy2_into_new_context(new_globals, &new_globals->fcurr_ptranslate_c_1, &GLOBALS->fcurr_ptranslate_c_1);
+ strcpy2_into_new_context(new_globals, &new_globals->fcurr_translate_c_2, &GLOBALS->fcurr_translate_c_2);
+ 
+
  /* status.c */
  new_globals->text_status_c_2 = GLOBALS->text_status_c_2;
 #if defined(WAVE_USE_GTK2) && !defined(GTK_ENABLE_BROKEN)
@@ -1640,7 +1739,9 @@ void reload_into_new_context(void)
  /* twinwave stuff */
  new_globals->dual_attach_id_main_c_1 = GLOBALS->dual_attach_id_main_c_1;
  new_globals->dual_id = GLOBALS->dual_id;
+#ifdef WAVE_USE_GTK2
  new_globals->socket_xid = GLOBALS->socket_xid;
+#endif
  new_globals->dual_ctx = GLOBALS->dual_ctx;
   
  /* Times struct */
@@ -1667,6 +1768,7 @@ void reload_into_new_context(void)
         
    case LX2_FILE: lxt2_rd_close(GLOBALS->lx2_lx2_c_1); break;
    case VZT_FILE: vzt_rd_close(GLOBALS->vzt_vzt_c_1); break;
+   case FST_FILE: fstReaderClose(GLOBALS->fst_fst_c_1); GLOBALS->fst_fst_c_1 = NULL; break;
    case AE2_FILE: 
 #ifdef AET2_IS_PRESENT
 	ae2_read_end(GLOBALS->ae2); fclose(GLOBALS->ae2_f); 
@@ -1674,7 +1776,8 @@ void reload_into_new_context(void)
 #endif
 	break;
   
-   case NO_FILE:
+   case MISSING_FILE:
+   case DUMPLESS_FILE:
    case GHW_FILE:
    case VCD_FILE:
    case VCD_RECODER_FILE: 
@@ -1687,8 +1790,10 @@ void reload_into_new_context(void)
 
  /* window destruction (of windows that aren't the parent window) */
 
-#if !defined _MSC_VER && !defined __MINGW32__
+#if !defined _MSC_VER
  kill_stems_browser();	/* for now, need to rework the stems browser dumpfile access routines to support this properly */
+ new_globals->stems_type = GLOBALS->stems_type;
+ strcpy2_into_new_context(new_globals, &new_globals->aet_name, &GLOBALS->aet_name);
 #endif
 
  /* remaining windows which are completely destroyed and haven't migrated over */
@@ -1755,6 +1860,7 @@ void reload_into_new_context(void)
 	memcpy(new_globals->page_mutex_renderopt_c_1, GLOBALS->page_mutex_renderopt_c_1, sizeof(GLOBALS->page_mutex_renderopt_c_1));
 	memcpy(new_globals->render_mutex_renderopt_c_1, GLOBALS->render_mutex_renderopt_c_1, sizeof(GLOBALS->render_mutex_renderopt_c_1));
 
+	strcpy2_into_new_context(new_globals, &new_globals->filesel_print_pdf_renderopt_c_1, &GLOBALS->filesel_print_pdf_renderopt_c_1);
 	strcpy2_into_new_context(new_globals, &new_globals->filesel_print_ps_renderopt_c_1, &GLOBALS->filesel_print_ps_renderopt_c_1);
 	strcpy2_into_new_context(new_globals, &new_globals->filesel_print_mif_renderopt_c_1, &GLOBALS->filesel_print_mif_renderopt_c_1);
 
@@ -1843,6 +1949,11 @@ void reload_into_new_context(void)
 			load_was_success = (GLOBALS->vzt_vzt_c_1 != NULL);
 			break;
 
+   		case FST_FILE: 
+			fst_main(GLOBALS->loaded_file_name,GLOBALS->skip_start,GLOBALS->skip_end); 
+			load_was_success = (GLOBALS->fst_fst_c_1 != NULL);
+			break;
+
    		case AE2_FILE: 
 			ae2_main(GLOBALS->loaded_file_name,GLOBALS->skip_start,GLOBALS->skip_end,GLOBALS->indirect_fname);
 			load_was_success = (GLOBALS->ae2 != NULL);
@@ -1902,8 +2013,34 @@ void reload_into_new_context(void)
 				else
 				{
 				free(GLOBALS->vcd_jmp_buf); GLOBALS->vcd_jmp_buf = NULL;
-				if(GLOBALS->vcd_handle_vcd_c_1) { fclose(GLOBALS->vcd_handle_vcd_c_1); GLOBALS->vcd_handle_vcd_c_1 = NULL; }
-				if(GLOBALS->vcd_handle_vcd_recoder_c_2) { fclose(GLOBALS->vcd_handle_vcd_recoder_c_2); GLOBALS->vcd_handle_vcd_recoder_c_2 = NULL; }
+				if(GLOBALS->vcd_handle_vcd_c_1)
+					{
+					if(GLOBALS->vcd_is_compressed_vcd_c_1)
+					        {
+					        pclose(GLOBALS->vcd_handle_vcd_c_1);
+					        GLOBALS->vcd_handle_vcd_c_1 = NULL;
+					        }
+					        else
+					        {
+					        fclose(GLOBALS->vcd_handle_vcd_c_1);
+					        GLOBALS->vcd_handle_vcd_c_1 = NULL;
+					        }
+					}
+				if(GLOBALS->vcd_handle_vcd_recoder_c_2)
+					{
+					if(GLOBALS->vcd_is_compressed_vcd_recoder_c_2)
+	        				{
+	        				pclose(GLOBALS->vcd_handle_vcd_recoder_c_2);
+	        				GLOBALS->vcd_handle_vcd_recoder_c_2 = NULL;
+	        				}    
+	        				else
+	        				{
+	        				fclose(GLOBALS->vcd_handle_vcd_recoder_c_2);
+	        				GLOBALS->vcd_handle_vcd_recoder_c_2 = NULL;
+	        				}
+					}
+
+
 				if(GLOBALS->vlist_handle) { fclose(GLOBALS->vlist_handle); GLOBALS->vlist_handle = NULL; }
 				if(GLOBALS->mm_lxt_mmap_addr)
 					{                        
@@ -2180,13 +2317,15 @@ void free_and_destroy_page_context(void)
  
    case LX2_FILE: lxt2_rd_close(GLOBALS->lx2_lx2_c_1); break;
    case VZT_FILE: vzt_rd_close(GLOBALS->vzt_vzt_c_1); break;
+   case FST_FILE: fstReaderClose(GLOBALS->fst_fst_c_1); GLOBALS->fst_fst_c_1 = NULL; break;
    case AE2_FILE:
 #ifdef AET2_IS_PRESENT
         ae2_read_end(GLOBALS->ae2); fclose(GLOBALS->ae2_f);
 #endif
         break;
  
-   case NO_FILE:
+   case MISSING_FILE:
+   case DUMPLESS_FILE:
    case GHW_FILE:
    case VCD_FILE:
    case VCD_RECODER_FILE: 
@@ -2322,6 +2461,10 @@ switch(type)
 							GLOBALS->disable_mouseover = g_old->disable_mouseover;
 							GLOBALS->zoom_pow10_snap = g_old->zoom_pow10_snap;
 
+							GLOBALS->scale_to_time_dimension = g_old->scale_to_time_dimension;
+							GLOBALS->zoom_dyn = g_old->zoom_dyn;
+							GLOBALS->zoom_dyne = g_old->zoom_dyne;
+
 							gtk_notebook_set_current_page(GTK_NOTEBOOK(GLOBALS->notebook), GLOBALS->this_context_page);
 							}
 
@@ -2359,7 +2502,7 @@ if(GLOBALS->gtk_context_bridge_ptr != w)
 	{
 #ifdef GTKWAVE_SIGNAL_CONNECT_DEBUG
 	printf("GTKWAVE | WARNING: globals change caught by ctx_swap_watchdog()! %p vs %p, session %d vs %d\n", 
-		GLOBALS->gtk_context_bridge_ptr,w, (*GLOBALS->gtk_context_bridge_ptr)->this_context_page, watch->this_context_page);
+		(void *)GLOBALS->gtk_context_bridge_ptr,(void *)w, (*GLOBALS->gtk_context_bridge_ptr)->this_context_page, watch->this_context_page);
 #endif
 
 	set_GLOBALS(watch);
@@ -2417,8 +2560,55 @@ void set_GLOBALS_x(struct Global *g, const char *file, int line)
 {
 if(line)
 	{
-	printf("Globals old %p -> new %p (%s: %d)\n", GLOBALS, g, file, line);
+	printf("Globals old %p -> new %p (%s: %d)\n", (void *)GLOBALS, (void *)g, file, line);
 	}
 
 GLOBALS = g;
 }
+
+
+/*
+ * for ensuring continuity of pixmap/mask pointers
+ */
+void clone_icon_pointers_across_contexts(struct Global *a, struct Global *b)
+{
+ if(!a || !b) return;
+
+ a->hiericon_module_pixmap = b->hiericon_module_pixmap;
+ a->hiericon_module_mask = b->hiericon_module_mask;
+ a->hiericon_task_pixmap = b->hiericon_task_pixmap;
+ a->hiericon_task_mask = b->hiericon_task_mask;
+ a->hiericon_function_pixmap = b->hiericon_function_pixmap;
+ a->hiericon_function_mask = b->hiericon_function_mask;
+ a->hiericon_begin_pixmap = b->hiericon_begin_pixmap;
+ a->hiericon_begin_mask = b->hiericon_begin_mask;  
+ a->hiericon_fork_pixmap = b->hiericon_fork_pixmap;
+ a->hiericon_fork_mask = b->hiericon_fork_mask;
+ 
+ a->hiericon_design_pixmap = b->hiericon_design_pixmap;
+ a->hiericon_design_mask = b->hiericon_design_mask;  
+ a->hiericon_block_pixmap = b->hiericon_block_pixmap;
+ a->hiericon_block_mask = b->hiericon_block_mask;
+ a->hiericon_generateif_pixmap = b->hiericon_generateif_pixmap;
+ a->hiericon_generateif_mask = b->hiericon_generateif_mask;
+ a->hiericon_generatefor_pixmap = b->hiericon_generatefor_pixmap;
+ a->hiericon_generatefor_mask = b->hiericon_generatefor_mask;
+ a->hiericon_instance_pixmap = b->hiericon_instance_pixmap;
+ a->hiericon_instance_mask = b->hiericon_instance_mask;  
+ a->hiericon_package_pixmap = b->hiericon_package_pixmap;
+ a->hiericon_package_mask = b->hiericon_package_mask;
+
+ a->hiericon_signal_pixmap = b->hiericon_signal_pixmap;
+ a->hiericon_signal_mask = b->hiericon_signal_mask;
+ a->hiericon_portin_pixmap = b->hiericon_portin_pixmap;
+ a->hiericon_portin_mask = b->hiericon_portin_mask;
+ a->hiericon_portout_pixmap = b->hiericon_portout_pixmap;
+ a->hiericon_portout_mask = b->hiericon_portout_mask;
+ a->hiericon_portinout_pixmap = b->hiericon_portinout_pixmap;
+ a->hiericon_portinout_mask = b->hiericon_portinout_mask;
+ a->hiericon_buffer_pixmap = b->hiericon_buffer_pixmap;
+ a->hiericon_buffer_mask = b->hiericon_buffer_mask;
+ a->hiericon_linkage_pixmap = b->hiericon_linkage_pixmap;
+ a->hiericon_linkage_mask = b->hiericon_linkage_mask;
+} 
+
