@@ -28,6 +28,7 @@
 #include "debug.h"
 #include "fgetdynamic.h"
 #include "fonts.h"
+#include "fstapi.h"
 #include "ghw.h"
 #include "globals.h"
 #include "gnu_regex.h"
@@ -56,6 +57,7 @@
 #include "jrb.h"
 #include "extload.h"
 
+
 struct Global{ 
 
 /*
@@ -91,6 +93,7 @@ Traces traces; /* from analyzer.c 7 */
 int hier_max_level; /* from analyzer.c 8 */
 TimeType timestart_from_savefile;
 char timestart_from_savefile_valid;
+int group_depth;
 
 /*
  * baseconvert.c
@@ -157,6 +160,9 @@ int color_normal; /* from color.c 52 */
 int color_mdgray; /* from color.c 53 */
 int color_dkgray; /* from color.c 54 */
 int color_dkblue; /* from color.c 55 */
+int color_brkred;
+int color_ltblue;
+int color_gmstrd;
 
 
 /*
@@ -249,6 +255,24 @@ PangoLayout *fonts_layout;
 char use_pango_fonts;
 
 
+/*
+ * fst.c
+ */
+void *fst_fst_c_1; 
+const char *fst_scope_name;
+TimeType first_cycle_fst_c_3;
+TimeType last_cycle_fst_c_3; 
+TimeType total_cycles_fst_c_3;
+struct lx2_entry *fst_table_fst_c_1; 
+struct fac *mvlfacs_fst_c_3;
+fstHandle *mvlfacs_fst_alias;
+fstHandle *mvlfacs_fst_rvs_alias;
+fstHandle fst_maxhandle;
+int busycnt_fst_c_2; 
+double *double_curr_fst;
+double *double_fini_fst;
+
+
 /*
  * ghw.c
  */
@@ -403,12 +427,14 @@ int max_compare_pos_tc_lxt_c_2; /* from lxt.c 200 */
 /*
  * main.c
  */
+GtkWidget *missing_file_toolbar;
 char *argvlist;
 #ifdef HAVE_LIBTCL
 Tcl_Interp *interp;
 #endif
 char *repscript_name;
 unsigned int repscript_period;
+char *tcl_init_cmd;
 char tcl_running;
 char block_xy_update;
 char *winname;
@@ -425,6 +451,7 @@ char *skip_start;
 char *skip_end;
 char *indirect_fname;
 enum FileType loaded_file_type;
+char is_optimized_stdin_vcd;
 char *whoami; /* from main.c 201 */
 struct logfile_chain *logfile; /* from main.c 202 */
 char *stems_name; /* from main.c 203 */
@@ -442,6 +469,7 @@ GtkWidget *toppanedwindow; /* from main.c 214 */
 GtkWidget *sstpane; /* from main.c 215 */
 GtkWidget *expanderwindow; /* from main.c 216 */
 char disable_window_manager; /* from main.c 217 */
+char disable_empty_gui; /* from main.c */
 char paned_pack_semantics; /* from main.c 218 */
 char zoom_was_explicitly_set; /* from main.c 219 */
 int initial_window_x; /* from main.c 220 */
@@ -465,7 +493,9 @@ char use_scrollbar_only; /* from main.c 237 */
 char force_toolbars; /* from main.c 238 */
 int hide_sst; /* from main.c 239 */
 int sst_expanded; /* from main.c 240 */
-unsigned int socket_xid; /* from main.c 241 */
+#ifdef WAVE_USE_GTK2
+GdkNativeWindow socket_xid; /* from main.c 241 */
+#endif
 int disable_menus; /* from main.c 242 */
 char *ftext_main_main_c_1; /* from main.c 243 */
 char use_toolbutton_interface; /* from main.c */
@@ -487,7 +517,7 @@ char *shadow_marker_names[26]; /* from markerbox.c */
  */
 char *cutcopylist; /* from menu.c */
 char enable_fast_exit; /* from menu.c 253 */
-FILE *script_handle; /* from menu.c 254 */
+struct wave_script_args *wave_script_args; /* from tcl_helper.c */
 char ignore_savefile_pos; /* from menu.c 255 */
 char ignore_savefile_size; /* from menu.c 256 */
 GtkItemFactory *item_factory_menu_c_1; /* from menu.c 258 */
@@ -556,6 +586,40 @@ GdkDrawable *wave_info_pixmap; /* from pixmaps.c 311 */
 GdkDrawable *wave_info_mask; /* from pixmaps.c 312 */
 GdkDrawable *wave_alert_pixmap; /* from pixmaps.c 314 */
 GdkDrawable *wave_alert_mask; /* from pixmaps.c 315 */
+GdkDrawable *hiericon_module_pixmap; /* from pixmaps.c */
+GdkDrawable *hiericon_module_mask; /* from pixmaps.c */
+GdkDrawable *hiericon_task_pixmap; /* from pixmaps.c */
+GdkDrawable *hiericon_task_mask; /* from pixmaps.c */
+GdkDrawable *hiericon_function_pixmap; /* from pixmaps.c */
+GdkDrawable *hiericon_function_mask; /* from pixmaps.c */
+GdkDrawable *hiericon_begin_pixmap; /* from pixmaps.c */
+GdkDrawable *hiericon_begin_mask; /* from pixmaps.c */
+GdkDrawable *hiericon_fork_pixmap; /* from pixmaps.c */
+GdkDrawable *hiericon_fork_mask; /* from pixmaps.c */
+GdkDrawable *hiericon_design_pixmap;
+GdkDrawable *hiericon_design_mask;
+GdkDrawable *hiericon_block_pixmap;
+GdkDrawable *hiericon_block_mask;
+GdkDrawable *hiericon_generateif_pixmap;
+GdkDrawable *hiericon_generateif_mask;
+GdkDrawable *hiericon_generatefor_pixmap;
+GdkDrawable *hiericon_generatefor_mask;
+GdkDrawable *hiericon_instance_pixmap;
+GdkDrawable *hiericon_instance_mask;
+GdkDrawable *hiericon_package_pixmap;
+GdkDrawable *hiericon_package_mask;
+GdkDrawable *hiericon_signal_pixmap;
+GdkDrawable *hiericon_signal_mask;
+GdkDrawable *hiericon_portin_pixmap;
+GdkDrawable *hiericon_portin_mask;
+GdkDrawable *hiericon_portout_pixmap;
+GdkDrawable *hiericon_portout_mask;
+GdkDrawable *hiericon_portinout_pixmap;
+GdkDrawable *hiericon_portinout_mask;
+GdkDrawable *hiericon_buffer_pixmap;
+GdkDrawable *hiericon_buffer_mask;
+GdkDrawable *hiericon_linkage_pixmap;
+GdkDrawable *hiericon_linkage_mask;
 
 
 /* 
@@ -604,9 +668,10 @@ int *regex_ok_regex_c_1; /* from regex.c 340 */
  */
 char is_active_renderopt_c_3; /* from renderopt.c 341 */
 GtkWidget *window_renderopt_c_6; /* from renderopt.c 342 */
+char *filesel_print_pdf_renderopt_c_1; /* from renderopt.c */
 char *filesel_print_ps_renderopt_c_1; /* from renderopt.c 343 */
 char *filesel_print_mif_renderopt_c_1; /* from renderopt.c 344 */
-char target_mutex_renderopt_c_1[2]; /* from renderopt.c 346 */
+char target_mutex_renderopt_c_1[3]; /* from renderopt.c 346 */
 char page_mutex_renderopt_c_1[5]; /* from renderopt.c 348 */
 char render_mutex_renderopt_c_1[2]; /* from renderopt.c 350 */
 int page_size_type_renderopt_c_1; /* from renderopt.c 351 */
@@ -740,10 +805,10 @@ char shadow_logical_mutex[6]; /* from strace.c 441 */
 char shadow_active; /* from strace.c 442 */
 char shadow_type; /* from strace.c 443 */
 char *shadow_string; /* from strace.c 444 */
-char mark_idx_start; /* from strace.c 445 */
-char mark_idx_end; /* from strace.c 446 */
-char shadow_mark_idx_start; /* from strace.c 447 */
-char shadow_mark_idx_end; /* from strace.c 448 */
+signed char mark_idx_start; /* from strace.c 445 */
+signed char mark_idx_end; /* from strace.c 446 */
+signed char shadow_mark_idx_start; /* from strace.c 447 */
+signed char shadow_mark_idx_end; /* from strace.c 448 */
 struct mprintf_buff_t *mprintf_buff_head; /* from strace.c 451 */
 struct mprintf_buff_t *mprintf_buff_current; /* from strace.c 452 */
 
@@ -787,6 +852,7 @@ GtkWidget *clist_translate_c_4; /* from translate.c 472 */
  * tree.c
  */
 struct tree *treeroot; /* from tree.c 473 */
+struct tree *mod_tree_parent; /* from tree.c */
 char *module_tree_c_1; /* from tree.c 474 */
 int module_len_tree_c_1; /* from tree.c 475 */
 struct tree *terminals_tchain_tree_c_1; /* from tree.c 476 */
@@ -905,7 +971,6 @@ struct vcdsymbol **indexed_vcd_c_1; /* from vcd.c 541 */
 int numsyms_vcd_c_1; /* from vcd.c 542 */
 struct HistEnt *he_curr_vcd_c_1; /* from vcd.c 543 */
 struct HistEnt *he_fini_vcd_c_1; /* from vcd.c 544 */
-struct queuedevent *queuedevents_vcd_c_1; /* from vcd.c 545 */
 unsigned int vcd_minid_vcd_c_1; /* from vcd.c 546 */
 unsigned int vcd_maxid_vcd_c_1; /* from vcd.c 547 */
 int err_vcd_c_1; /* from vcd.c 548 */
@@ -944,7 +1009,6 @@ struct vcdsymbol *vcdsymcurr_vcd_partial_c_2; /* from vcd_partial.c 578 */
 struct vcdsymbol **sorted_vcd_partial_c_2; /* from vcd_partial.c 579 */
 struct vcdsymbol **indexed_vcd_partial_c_2; /* from vcd_partial.c 580 */
 int numsyms_vcd_partial_c_2; /* from vcd_partial.c 582 */
-struct queuedevent *queuedevents_vcd_partial_c_2; /* from vcd_partial.c 583 */
 unsigned int vcd_minid_vcd_partial_c_2; /* from vcd_partial.c 584 */
 unsigned int vcd_maxid_vcd_partial_c_2; /* from vcd_partial.c 585 */
 int err_vcd_partial_c_2; /* from vcd_partial.c 586 */
@@ -958,9 +1022,13 @@ int timeset_vcd_partial_c_1; /* from vcd_partial.c 592 */
  * vcd_recoder.c
  */
 struct vlist_t *time_vlist_vcd_recoder_c_1; /* from vcd_recoder.c 593 */
+struct vlist_t *time_vlist_vcd_recoder_write; /* from vcd_recoder.c */
+char *fastload_depacked; /* from vcd_recoder.c */
+char *fastload_current; /* from vcd_recoder.c */
 unsigned int time_vlist_count_vcd_recoder_c_1; /* from vcd_recoder.c 594 */
 FILE *vcd_handle_vcd_recoder_c_2; /* from vcd_recoder.c 595 */
 char vcd_is_compressed_vcd_recoder_c_2; /* from vcd_recoder.c 596 */
+char use_fastload;
 off_t vcdbyteno_vcd_recoder_c_3; /* from vcd_recoder.c 597 */
 int error_count_vcd_recoder_c_3; /* from vcd_recoder.c 598 */
 int header_over_vcd_recoder_c_3; /* from vcd_recoder.c 599 */
@@ -1105,6 +1173,9 @@ GdkGC *gc_normal; /* from wavewindow.c 713 */
 GdkGC *gc_mdgray; /* from wavewindow.c 714 */
 GdkGC *gc_dkgray; /* from wavewindow.c 715 */
 GdkGC *gc_dkblue; /* from wavewindow.c 716 */
+GdkGC *gc_brkred; 
+GdkGC *gc_ltblue; 
+GdkGC *gc_gmstrd; 
 char fill_in_smaller_rgb_areas_wavewindow_c_1; /* from wavewindow.c 719 */
 TimeType prev_markertime; /* from wavewindow.c */
 GdkGC *gccache_ltgray; /* from wavewindow.c */
@@ -1112,6 +1183,9 @@ GdkGC *gccache_normal; /* from wavewindow.c */
 GdkGC *gccache_mdgray; /* from wavewindow.c */
 GdkGC *gccache_dkgray; /* from wavewindow.c */
 GdkGC *gccache_dkblue; /* from wavewindow.c */
+GdkGC *gccache_brkred; /* from wavewindow.c */
+GdkGC *gccache_ltblue; /* from wavewindow.c */
+GdkGC *gccache_gmstrd; /* from wavewindow.c */
 GdkGC *gccache_back_wavewindow_c_1; /* from wavewindow.c */
 GdkGC *gccache_baseline_wavewindow_c_1; /* from wavewindow.c */
 GdkGC *gccache_grid_wavewindow_c_1; /* from wavewindow.c */
@@ -1142,6 +1216,7 @@ GdkGC *gccache_dash_wavewindow_c_1; /* from wavewindow.c */
  */
 char do_zoom_center; /* from zoombuttons.c 720 */
 char do_initial_zoom_fit; /* from zoombuttons.c 721 */
+
 };
 
 
@@ -1153,7 +1228,6 @@ void dead_context_sweep(void);
 
 void install_focus_cb(GtkWidget *w, unsigned long ptr_offset);
 
-
 gulong gtkwave_signal_connect_x(GtkObject *object, const gchar *name, GtkSignalFunc func, gpointer data, char *f, unsigned long line);
 gulong gtkwave_signal_connect_object_x(GtkObject *object, const gchar *name, GtkSignalFunc func, gpointer data, char *f, unsigned long line);
 
@@ -1165,7 +1239,6 @@ gulong gtkwave_signal_connect_object_x(GtkObject *object, const gchar *name, Gtk
 #define gtkwave_signal_connect_object(a,b,c,d) gtkwave_signal_connect_object_x(a,b,c,d,NULL,0)
 #endif
 
-
 void set_GLOBALS_x(struct Global *g, const char *file, int line);
 
 #ifdef GTKWAVE_GLOBALS_DEBUG
@@ -1175,6 +1248,7 @@ void set_GLOBALS_x(struct Global *g, const char *file, int line);
 #endif
 
 void logbox_reload(void);
+void clone_icon_pointers_across_contexts(struct Global *a, struct Global *b);
 
 extern struct Global *GLOBALS;
 #endif
