@@ -157,17 +157,44 @@ return("01xz"[value&3]);
 static char *vcdid(int value)
 {
 static char buf[16];
+char *pnt = buf;
+int i, vmod;
+
+value++;
+for(i=0;;i++)
+        {
+        if((vmod = (value % 94)))
+                {
+                *(pnt++) = (char)(vmod + 32);
+                }   
+                else
+                {
+                *(pnt++) = '~'; value -= 94;
+                }
+        value = value / 94;  
+        if(!value) { break; }
+        }
+
+*pnt = 0;   
+return(buf);
+}
+
+/*
+static char *vcdid(int value)
+{
+static char buf[16];
 int i;
 
 for(i=0;i<15;i++)
 	{
-	buf[i]=(char)((value%94)+33); /* for range 33..126 */
+	buf[i]=(char)((value%94)+33);
 	value=value/94;
 	if(!value) {buf[i+1]=0; break;}
 	}
 
 return(buf);
 }
+*/
 
 
 /*
@@ -1440,8 +1467,11 @@ while(offs)
 #endif
 
 /*
- * $Id: mvl2vcd.c,v 1.2 2007/08/31 22:42:44 gtkwave Exp $
+ * $Id: mvl2vcd.c,v 1.3 2009/04/15 21:39:50 gtkwave Exp $
  * $Log: mvl2vcd.c,v $
+ * Revision 1.3  2009/04/15 21:39:50  gtkwave
+ * use XL-style identifier sequencing for VCD identifiers
+ *
  * Revision 1.2  2007/08/31 22:42:44  gtkwave
  * 3.1.0 RC3 updates
  *
