@@ -101,6 +101,32 @@ return(v);
 
 struct namehier *nhold=NULL;
 
+static char *vcdid(int value)
+{
+static char buf[16];
+char *pnt = buf;
+int i, vmod;
+
+value++;
+for(i=0;;i++)
+        {
+        if((vmod = (value % 94)))
+                {
+                *(pnt++) = (char)(vmod + 32);
+                }   
+                else
+                {
+                *(pnt++) = '~'; value -= 94;
+                }
+        value = value / 94;  
+        if(!value) { break; }
+        }
+
+*pnt = 0;   
+return(buf);
+}
+
+/*
 static char *vcdid(int value)
 {
 static char buf[16];
@@ -108,13 +134,14 @@ int i;
 
 for(i=0;i<15;i++)
 	{
-	buf[i]=(char)((value%94)+33); /* for range 33..126 */
+	buf[i]=(char)((value%94)+33);
 	value=value/94;
 	if(!value) {buf[i+1]=0; break;}
 	}
 
 return(buf);
 }
+*/
 
 static void diff_hier(struct namehier *nh1, struct namehier *nh2)
 {
@@ -473,8 +500,11 @@ exit(0);
 }
 
 /*
- * $Id: tex2vcd.c,v 1.1.1.1 2007/05/30 04:28:19 gtkwave Exp $
+ * $Id: tex2vcd.c,v 1.2 2009/04/15 21:39:50 gtkwave Exp $
  * $Log: tex2vcd.c,v $
+ * Revision 1.2  2009/04/15 21:39:50  gtkwave
+ * use XL-style identifier sequencing for VCD identifiers
+ *
  * Revision 1.1.1.1  2007/05/30 04:28:19  gtkwave
  * Imported sources
  *
