@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2007 Tony Bybell.
+ * Copyright (c) 2001-2009 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -359,6 +359,16 @@ if(ch=='\n') vcdlineno++;
 return(((ch==EOF)||(errno))?(-1):(ch));
 }
 
+static int getch_peek(void)
+{
+int ch;
+
+ch=fgetc(vcd_handle);
+ungetc(ch, vcd_handle);
+return(((ch==EOF)||(errno))?(-1):(ch));
+}
+
+
 static char *varsplit=NULL, *vsplitcurr=NULL;
 static int getch_patched(void)
 {
@@ -545,7 +555,20 @@ for(yytext[len++]=ch;;yytext[len++]=ch)
                 {
                 yytext=(char *)realloc_2(yytext, (T_MAX_STR=T_MAX_STR*2)+1);
                 }
+
         ch=getch();
+        if(ch==' ')
+                {
+                signed char ch2;
+                if(match_kw) break;
+                if((ch2 = getch_peek()) == '[')
+                        {
+                        ch = getch();
+                        varsplit=yytext+len; /* keep looping so we get the *last* one */
+                        continue;
+                        }
+                }
+
         if((ch==' ')||(ch=='\t')||(ch=='\n')||(ch=='\r')||(ch<0)) break;
         if((ch=='[')&&(yytext[0]!='\\'))
                 {
@@ -955,8 +978,8 @@ switch(yytext[0])
 
 static void evcd_strcpy(char *dst, char *src)
 {
-static char *evcd="DUNZduLHXTlh01?FAaBbCcf";
-static char  *vcd="01xz0101xz0101xzxxxxxxx";
+static const char *evcd="DUNZduLHXTlh01?FAaBbCcf";
+static const char  *vcd="01xz0101xz0101xzxxxxxxz";
 
 char ch;
 int i;
@@ -1118,7 +1141,7 @@ for(;;)
 
 			if(vtok==V_PORT)
 				{
-				vtok=get_vartoken(0);
+				vtok=get_vartoken(1);
 				if(vtok==V_STRING)
 					{
 					v->size=atoi_64(yytext);
@@ -1926,8 +1949,20 @@ exit(0);
 }
 
 /*
- * $Id: vcd2lxt.c,v 1.2 2007/06/01 21:13:41 gtkwave Exp $
+ * $Id: vcd2lxt.c,v 1.6 2009/07/07 19:46:03 gtkwave Exp $
  * $Log: vcd2lxt.c,v $
+ * Revision 1.6  2009/07/07 19:46:03  gtkwave
+ * make evcd->vcd conversion table const
+ *
+ * Revision 1.5  2009/07/07 15:48:37  gtkwave
+ * EVCD "f" value fix (should be z not x)
+ *
+ * Revision 1.4  2009/07/06 21:41:36  gtkwave
+ * evcd support issues
+ *
+ * Revision 1.3  2009/04/30 01:30:53  gtkwave
+ * VCD parser fix for double subscripted nets
+ *
  * Revision 1.2  2007/06/01 21:13:41  gtkwave
  * regenerate configure for cygwin with proper flags, add missing files
  *
