@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2001-2007 Tony Bybell.
+ * Copyright (c) 2001-2009 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -364,6 +364,16 @@ if(ch=='\n') vcdlineno++;
 return(((ch==EOF)||(errno))?(-1):(ch));
 }
 
+static int getch_peek(void)
+{ 
+int ch;
+
+ch=fgetc(vcd_handle);
+ungetc(ch, vcd_handle);
+return(((ch==EOF)||(errno))?(-1):(ch));   
+}
+
+
 static char *varsplit=NULL, *vsplitcurr=NULL;
 static int getch_patched(void)
 {
@@ -550,7 +560,20 @@ for(yytext[len++]=ch;;yytext[len++]=ch)
                 {
                 yytext=(char *)realloc_2(yytext, (T_MAX_STR=T_MAX_STR*2)+1);
                 }
-        ch=getch();
+
+        ch=getch();  
+        if(ch==' ')
+                {
+                signed char ch2;
+                if(match_kw) break;
+                if((ch2 = getch_peek()) == '[')
+                        {
+                        ch = getch();
+                        varsplit=yytext+len; /* keep looping so we get the *last* one */
+                        continue;
+                        }
+                }
+
         if((ch==' ')||(ch=='\t')||(ch=='\n')||(ch=='\r')||(ch<0)) break;
         if((ch=='[')&&(yytext[0]!='\\'))
                 {
@@ -958,8 +981,8 @@ switch(yytext[0])
 
 static void evcd_strcpy(char *dst, char *src)
 {
-static char *evcd="DUNZduLHXTlh01?FAaBbCcf";
-static char  *vcd="01xz0101xz0101xzxxxxxxx";
+static const char *evcd="DUNZduLHXTlh01?FAaBbCcf";
+static const char  *vcd="01xz0101xz0101xzxxxxxxz";
 
 char ch;
 int i;
@@ -1120,7 +1143,7 @@ for(;;)
 
 			if(vtok==V_PORT)
 				{
-				vtok=get_vartoken(0);
+				vtok=get_vartoken(1);
 				if(vtok==V_STRING)
 					{
 					v->size=atoi_64(yytext);
@@ -1869,9 +1892,9 @@ WAVE_LOCALE_FIX
 
 while (1)
         {
+#ifdef __linux__
         int option_index = 0;
                         
-#ifdef __linux__
         static struct option long_options[] =
                 {
 		{"vcdname", 1, 0, 'v'},
@@ -1981,8 +2004,23 @@ return(0);
 }
 
 /*
- * $Id: vcd2lxt2.c,v 1.2 2007/06/01 21:13:41 gtkwave Exp $
+ * $Id: vcd2lxt2.c,v 1.7 2009/07/07 19:46:03 gtkwave Exp $
  * $Log: vcd2lxt2.c,v $
+ * Revision 1.7  2009/07/07 19:46:03  gtkwave
+ * make evcd->vcd conversion table const
+ *
+ * Revision 1.6  2009/07/07 15:48:37  gtkwave
+ * EVCD "f" value fix (should be z not x)
+ *
+ * Revision 1.5  2009/07/06 21:41:36  gtkwave
+ * evcd support issues
+ *
+ * Revision 1.4  2009/04/30 01:30:53  gtkwave
+ * VCD parser fix for double subscripted nets
+ *
+ * Revision 1.3  2009/03/31 18:49:49  gtkwave
+ * removal of warnings under cygwin compile
+ *
  * Revision 1.2  2007/06/01 21:13:41  gtkwave
  * regenerate configure for cygwin with proper flags, add missing files
  *
