@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999-2008 Tony Bybell.
+ * Copyright (c) 1999-2009 Tony Bybell.
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -366,6 +366,16 @@ if(ch=='\n') vcdlineno++;
 return(((ch==EOF)||(errno))?(-1):(ch));
 }
 
+static int getch_peek(void)
+{ 
+int ch;
+
+ch=fgetc(vcd_handle);
+ungetc(ch, vcd_handle);
+return(((ch==EOF)||(errno))?(-1):(ch));   
+}
+
+
 static char *varsplit=NULL, *vsplitcurr=NULL;
 static int getch_patched(void)
 {
@@ -552,7 +562,20 @@ for(yytext[len++]=ch;;yytext[len++]=ch)
                 {
                 yytext=(char *)realloc_2(yytext, (T_MAX_STR=T_MAX_STR*2)+1);
                 }
-        ch=getch();
+
+        ch=getch();  
+        if(ch==' ')
+                {
+                signed char ch2;
+                if(match_kw) break;
+                if((ch2 = getch_peek()) == '[')
+                        {
+                        ch = getch();
+                        varsplit=yytext+len; /* keep looping so we get the *last* one */
+                        continue;
+                        }
+                }
+
         if((ch==' ')||(ch=='\t')||(ch=='\n')||(ch=='\r')||(ch<0)) break;
         if((ch=='[')&&(yytext[0]!='\\'))
                 {
@@ -960,8 +983,8 @@ switch(yytext[0])
 
 static void evcd_strcpy(char *dst, char *src)
 {
-static char *evcd="DUNZduLHXTlh01?FAaBbCcf";
-static char  *vcd="01xz0101xz0101xzxxxxxxx";
+static const char *evcd="DUNZduLHXTlh01?FAaBbCcf";
+static const char  *vcd="01xz0101xz0101xzxxxxxxz";
 
 char ch;
 int i;
@@ -1123,7 +1146,7 @@ for(;;)
 
 			if(vtok==V_PORT)
 				{
-				vtok=get_vartoken(0);
+				vtok=get_vartoken(1);
 				if(vtok==V_STRING)
 					{
 					v->size=atoi_64(yytext);
@@ -1830,7 +1853,7 @@ printf(
 "  -d, --depth=value          specify 0..9 compression depth (default = 4)\n"
 "  -m, --maxgranule=value     specify number of granules per section (def = 8)\n"
 "  -b, --break=value          specify break size (default = 0 = off)\n"
-"  -z, --ziptype=value        specify zip type (default = 0 gzip, 1 = bzip2)\n"
+"  -z, --ziptype=value        specify zip type (default: 0 gzip, 1 bzip2, 2 lzma)\n"
 "  -t, --twostate             force MVL2 twostate mode (default is MVL4)\n"
 "  -r, --rle                  use bitwise RLE compression on value table\n"
 "  -h, --help                 display this help then exit\n\n"
@@ -1847,7 +1870,7 @@ printf(
 "  -d value                   specify 0..9 compression depth (default = 4)\n"
 "  -m value                   specify number of granules per section (def = 8)\n"
 "  -b value                   specify break size (default = 0 = off)\n"
-"  -z value                   specify zip type (default = 0 gzip, 1 = bzip2)\n"
+"  -z value                   specify zip type (default: 0 gzip, 1 bzip2, 2 lzma)\n"
 "  -t                         force MVL2 twostate mode (default is MVL4)\n"
 "  -r                         use bitwise RLE compression on value table\n"
 "  -h                         display this help then exit\n\n"
@@ -1872,9 +1895,9 @@ WAVE_LOCALE_FIX
 
 while (1)
         {
+#ifdef __linux__
         int option_index = 0;
                         
-#ifdef __linux__
         static struct option long_options[] =
                 {
 		{"vcdname", 1, 0, 'v'},
@@ -1939,7 +1962,8 @@ while (1)
                         break;
                         
 		case 'z':
-			ziptype = (atoi(optarg) != 0);
+			ziptype = atoi(optarg);
+			if((ziptype < VZT_WR_IS_GZ) || (ziptype > VZT_WR_IS_LZMA)) ziptype = VZT_WR_IS_GZ;
 			break;
 
                 case '?':
@@ -1987,8 +2011,26 @@ return(0);
 }
 
 /*
- * $Id: vcd2vzt.c,v 1.3 2008/11/24 15:24:13 gtkwave Exp $
+ * $Id: vcd2vzt.c,v 1.9 2009/07/07 19:46:03 gtkwave Exp $
  * $Log: vcd2vzt.c,v $
+ * Revision 1.9  2009/07/07 19:46:03  gtkwave
+ * make evcd->vcd conversion table const
+ *
+ * Revision 1.8  2009/07/07 15:48:37  gtkwave
+ * EVCD "f" value fix (should be z not x)
+ *
+ * Revision 1.7  2009/07/06 21:41:36  gtkwave
+ * evcd support issues
+ *
+ * Revision 1.6  2009/04/30 01:30:53  gtkwave
+ * VCD parser fix for double subscripted nets
+ *
+ * Revision 1.5  2009/03/31 18:49:49  gtkwave
+ * removal of warnings under cygwin compile
+ *
+ * Revision 1.4  2009/03/31 06:21:12  gtkwave
+ * added support for lzma
+ *
  * Revision 1.3  2008/11/24 15:24:13  gtkwave
  * fixed info banner that still had some LXT information
  *
