@@ -390,6 +390,7 @@ for(i=fetchlow(GLOBALS->h_selectedtree_hiersearch_c_1)->which;i<=fetchhigh(GLOBA
 
 set_window_idle(widget);
 
+GLOBALS->traces.scroll_top = GLOBALS->traces.scroll_bottom = GLOBALS->traces.last;
 MaxSignalLength();
 signalarea_configure_event(GLOBALS->signalarea, NULL);
 wavearea_configure_event(GLOBALS->wavearea, NULL);
@@ -978,8 +979,11 @@ void hier_searchbox(char *title, GtkSignalFunc func)
 }
 
 /*
- * $Id: hiersearch.c,v 1.6 2008/02/12 23:35:42 gtkwave Exp $
+ * $Id: hiersearch.c,v 1.7 2008/12/18 01:31:30 gtkwave Exp $
  * $Log: hiersearch.c,v $
+ * Revision 1.7  2008/12/18 01:31:30  gtkwave
+ * integrated experimental autoscroll code on signal adds
+ *
  * Revision 1.6  2008/02/12 23:35:42  gtkwave
  * preparing for 3.1.5 revision bump
  *
