@@ -19,7 +19,7 @@
 #include "vcd.h"
 #include "ae2.h"
 
-enum LXT2_Loader_Type_Encodings { LXT2_IS_INACTIVE, LXT2_IS_LXT2, LXT2_IS_VZT, LXT2_IS_AET2, LXT2_IS_VLIST };
+enum LXT2_Loader_Type_Encodings { LXT2_IS_INACTIVE, LXT2_IS_LXT2, LXT2_IS_VZT, LXT2_IS_AET2, LXT2_IS_VLIST, LXT2_IS_FST };
 
 struct lx2_entry
 {
@@ -37,8 +37,11 @@ void lx2_import_masked(void);
 #endif
 
 /*
- * $Id: lx2.h,v 1.2 2007/08/26 21:35:41 gtkwave Exp $
+ * $Id: lx2.h,v 1.3 2009/06/07 08:40:44 gtkwave Exp $
  * $Log: lx2.h,v $
+ * Revision 1.3  2009/06/07 08:40:44  gtkwave
+ * adding FST support
+ *
  * Revision 1.2  2007/08/26 21:35:41  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
