@@ -1,4 +1,4 @@
-/* 
+/*
  * Copyright (c) Tony Bybell 1999-2009.
  *
  * This program is free software; you can redistribute it and/or
@@ -7,7 +7,6 @@
  * of the License, or (at your option) any later version.
  */
 
-
 /* AIX may need this for alloca to work */ 
 #if defined _AIX
   #pragma alloca
@@ -18,6 +17,9 @@
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <stdlib.h>
+#ifdef __MINGW32__
+#include <windows.h>
+#endif
 
 #include "wave_locale.h"
 
@@ -29,7 +31,7 @@
 #include <sys/types.h>
 #endif
 
-#if !defined _MSC_VER && !defined __MINGW32__ && !defined OS_X && defined WAVE_USE_GTK2
+#if !defined _MSC_VER && !defined OS_X && defined WAVE_USE_GTK2
 #define WAVE_USE_XID
 #else
 #undef WAVE_USE_XID
@@ -52,6 +54,7 @@
 #include "ae2.h"
 #include "vzt.h"
 #include "ghw.h"
+#include "fst.h"
 #include "main.h"
 #include "menu.h"
 #include "vcd.h"
@@ -66,6 +69,10 @@
 #include "ptranslate.h"
 
 #include "tcl_helper.h"
+#if defined(HAVE_LIBTCL)
+#include <tcl.h>
+#include <tk.h>
+#endif
 
 static void switch_page(GtkNotebook     *notebook,
 			GtkNotebookPage *page,
@@ -101,19 +108,11 @@ gtk_entry_set_text(GTK_ENTRY(GLOBALS->from_entry),timestr);
 reformat_time(timestr, GLOBALS->tims.last, GLOBALS->time_dimension);
 gtk_entry_set_text(GTK_ENTRY(GLOBALS->to_entry),timestr);
 
-if(g_old->signalarea_event_box)
-	{
-	if(g_old->keypress_handler_id)
-		{
-		remove_keypress_handler(g_old->keypress_handler_id);
-		g_old->keypress_handler_id = 0;
-		}
-	GLOBALS->keypress_handler_id = install_keypress_handler();
-	}
-
 update_maxmarker_labels();
 update_basetime(GLOBALS->tims.baseline);
 
+GLOBALS->keypress_handler_id = g_old->keypress_handler_id;
+
 if(GLOBALS->second_page_created)
 	{
 	gtk_window_set_title(GTK_WINDOW(GLOBALS->mainwindow), GLOBALS->winname);
@@ -122,31 +121,53 @@ if(GLOBALS->second_page_created)
 	signalarea_configure_event(GLOBALS->signalarea, NULL);
 	wavearea_configure_event(GLOBALS->wavearea, NULL);
 	}
+
 }
 
 
-#if !defined _MSC_VER && !defined __MINGW32__
+void kill_stems_browser_single(void *V)
+{
+struct Global *G = (struct Global *)V;
+#if !defined _MSC_VER
+	if(G && G->anno_ctx)
+		{
+#ifdef __MINGW32__
+		if(G->anno_ctx->browser_process)
+			{
+			TerminateProcess(G->anno_ctx->browser_process, 0);
+			CloseHandle(G->anno_ctx->browser_process);
+			G->anno_ctx->browser_process = 0;
+			}
+#else
+		if(G->anno_ctx->browser_process)
+			{
+#ifdef __CYGWIN__
+			G->anno_ctx->cygwin_remote_kill = 1; /* let cygwin child exit() on its own */
+#else
+			kill(G->anno_ctx->browser_process, SIGKILL);
+#endif
+			G->anno_ctx->browser_process = (pid_t)0;
+			}
+#endif
+		G->anno_ctx = NULL;
+		}
+#endif
+}
+
+#if !defined _MSC_VER
 void kill_stems_browser(void)
 {
-if(GLOBALS->anno_ctx)
+int ix;
+
+for(ix=0;ix<GLOBALS->num_notebook_pages;ix++)
 	{
-	if(GLOBALS->anno_ctx->browser_process)
-		{
-		kill(GLOBALS->anno_ctx->browser_process, SIGKILL);
-		GLOBALS->anno_ctx->browser_process = (pid_t)0;
-		}
-	GLOBALS->anno_ctx = NULL;
+        struct Global *G = (*GLOBALS->contexts)[ix];
+	kill_stems_browser_single(G);
 	}
 }
 #endif
 
 
-/* for XID plug handling... */
-#ifdef WAVE_USE_XID
-#else
-unsigned int socket_xid = 0;
-#endif
-
 static int plug_destroy (GtkWidget *widget, gpointer data)
 {
 exit(0);
@@ -155,6 +176,22 @@ return(FALSE);
 }       
 
 
+#if defined __MINGW32__
+static void close_all_fst_files(void) /* so mingw does delete of reader tempfiles */
+{
+unsigned int i;
+for(i=0;i<GLOBALS->num_notebook_pages;i++)
+	{
+        if((*GLOBALS->contexts)[i]->fst_fst_c_1)
+		{
+		fstReaderClose((*GLOBALS->contexts)[i]->fst_fst_c_1);
+		(*GLOBALS->contexts)[i]->fst_fst_c_1 = NULL;
+		}
+        }
+}
+#endif
+
+
 static void print_help(char *nam)
 {
 #if !defined _MSC_VER && !defined __MINGW32__ && !defined __FreeBSD__ && !defined __CYGWIN__
@@ -164,13 +201,17 @@ static void print_help(char *nam)
 #endif
 
 #if !defined _MSC_VER && !defined __MINGW32__
-#define STEMS_GETOPT	 "  -t, --stems=FILE           specify stems file for source code annotation\n"
 #define VCD_GETOPT       "  -o, --optimize             optimize VCD to LXT2\n"
+#else
+#define VCD_GETOPT
+#endif
+
+#if !defined _MSC_VER
+#define STEMS_GETOPT	 "  -t, --stems=FILE           specify stems file for source code annotation\n"
 #define DUAL_GETOPT      "  -D, --dualid=WHICH         specify multisession identifier\n"
 #define INTR_GETOPT      "  -I, --interactive          interactive VCD mode (filename is shared mem ID)\n"
 #else
 #define STEMS_GETOPT
-#define VCD_GETOPT
 #define DUAL_GETOPT
 #define INTR_GETOPT
 #endif
@@ -181,8 +222,16 @@ static void print_help(char *nam)
 #define XID_GETOPT
 #endif
 
+#if defined(WIN32) && defined(USE_TCL_STUBS)
+#define WISH_GETOPT
+#else
+#define WISH_GETOPT	 "  -T, --tcl_init=FILE        specify Tcl command script file to be loaded on startup\n" \
+			 "  -W, --wish                 enable Tcl command line on stdio\n"
+#endif
+
 #if defined(HAVE_LIBTCL)
-#define REPSCRIPT_GETOPT "  -R, --repscript=FILE       specify timer-driven Tcl command script file\n"\
+#define REPSCRIPT_GETOPT WISH_GETOPT \
+                         "  -R, --repscript=FILE       specify timer-driven Tcl command script file\n" \
                          "  -P, --repperiod=VALUE      specify repscript period in msec (default: 500)\n"
 #else
 #define REPSCRIPT_GETOPT
@@ -198,6 +247,7 @@ printf(
 "Usage: %s [OPTION]... [DUMPFILE] [SAVEFILE] [RCFILE]\n\n"
 "  -n, --nocli=DIRPATH        use file requester for dumpfile name\n"
 "  -f, --dump=FILE            specify dumpfile name\n"
+"  -F, --fastload             generate/use VCD recoder fastload files\n"
 VCD_GETOPT
 "  -a, --save=FILE            specify savefile name\n"
 "  -A, --autosavename         assume savefile is suffix modified dumpfile name\n"
@@ -212,7 +262,7 @@ STEMS_GETOPT
 WAVE_GETOPT_CPUS
 "  -N, --nowm                 disable window manager for most windows\n"
 "  -M, --nomenus              do not render menubar (for making applets)\n"
-"  -S, --script=FILE          specify GUI command script file for execution\n"
+"  -S, --script=FILE          specify Tcl command script file for execution\n"
 REPSCRIPT_GETOPT
 XID_GETOPT
 INTR_GETOPT
@@ -268,6 +318,32 @@ gtk_main();
 return(GLOBALS->ftext_main_main_c_1);
 }
 
+/*
+ * Modify the name of the executable (argv[0]) handed to Tk_MainEx;
+ * The new executable name has _[pid] appended. This gives a unique
+ * (and known) name to the interpreter (for use with send).
+ */
+void addPidToExecutableName(int argc, char* argv[], char* argv_mod[])
+{
+  char* pos;
+  char* buffer;
+
+  int i;
+  for(i=0;i<argc;i++)
+    {
+      argv_mod[i] = argv[i];
+    }
+
+  buffer = malloc_2(strlen(argv[0])+1+10);
+  pos = buffer;
+  strcpy(pos, argv[0]);
+  pos = buffer + strlen(buffer);
+  strcpy(pos, "_");
+  pos = buffer + strlen(buffer);
+  sprintf(pos, "%d", getpid());
+	  
+  argv_mod[0] = buffer;
+}
 
 int main(int argc, char *argv[])
 {
@@ -284,12 +360,15 @@ char *output_name = NULL;
 int i;
 int c;
 char is_vcd=0;
+char is_wish=0;
 char is_interactive=0;
 char is_smartsave = 0;
 char is_legacy = 0;
+char is_fastload = VCD_FSL_NONE;
 char is_giga = 0;
 char fast_exit=0;
 char opt_errors_encountered=0;
+char is_missing_file = 0;
 
 char *wname=NULL;
 char *override_rc=NULL;
@@ -323,9 +402,9 @@ if(!GLOBALS)
 	{
 	set_GLOBALS(initialize_globals());
 	mainwindow_already_built = 0;
+	tcl_interpreter_needs_making = 1;
 
 	GLOBALS->logfiles = calloc(1, sizeof(void **)); /* calloc is deliberate! */
-	tcl_interpreter_needs_making = 1;
 	}
 	else
 	{
@@ -377,6 +456,7 @@ if(!GLOBALS)
 	GLOBALS->to_entry = old_g->to_entry;
 	
 	/* rc.c */
+	GLOBALS->possibly_use_rc_defaults = old_g->possibly_use_rc_defaults;
 	GLOBALS->ignore_savefile_pos = old_g->ignore_savefile_pos;
 	GLOBALS->ignore_savefile_size = old_g->ignore_savefile_size;
 	
@@ -411,6 +491,9 @@ if(!GLOBALS)
 	GLOBALS->color_mdgray = old_g->color_mdgray;
 	GLOBALS->color_dkgray = old_g->color_dkgray;
 	GLOBALS->color_dkblue = old_g->color_dkblue;
+	GLOBALS->color_brkred = old_g->color_brkred;
+	GLOBALS->color_ltblue = old_g->color_ltblue;
+	GLOBALS->color_gmstrd = old_g->color_gmstrd;
 	
 	GLOBALS->atomic_vectors = old_g->atomic_vectors;
 	GLOBALS->autoname_bundles = old_g->autoname_bundles;
@@ -492,14 +575,38 @@ if(!mainwindow_already_built)
 #endif
 	if(!gtk_init_check(&argc, &argv))
 		{
-		printf("Could not initialize GTK!  Is DISPLAY env var/xhost set?\n\n");
+#if defined(__APPLE__)
+		if(!getenv("DISPLAY"))
+			{
+			fprintf(stderr, "DISPLAY environment variable is not set.  Have you ensured\n");
+			fprintf(stderr, "that x11 has been initialized through open-x11, launching\n");
+			fprintf(stderr, "gtkwave in an xterm or x11 window, etc?\n\n");
+			fprintf(stderr, "Attempting to initialize using DISPLAY=:0.0 value...\n\n");
+			setenv("DISPLAY", ":0.0", 0);
+			if(gtk_init_check(&argc, &argv))
+				{
+				goto do_primary_inits;
+				}
+			}
+#endif
+		fprintf(stderr, "Could not initialize GTK!  Is DISPLAY env var/xhost set?\n\n");
 		print_help(argv[0]);
 		}
 	}
 
+#if defined(__APPLE__)
+do_primary_inits:
+#endif
+
 init_filetrans_data(); /* for file translation splay trees */
 init_proctrans_data(); /* for proc translation structs */
-if(!mainwindow_already_built) atexit(remove_all_proc_filters);
+if(!mainwindow_already_built) 
+	{
+	atexit(remove_all_proc_filters);
+#if defined __MINGW32__
+	atexit(close_all_fst_files);
+#endif
+	}
 
 if(mainwindow_already_built)
 	{
@@ -513,6 +620,7 @@ while (1)
         static struct option long_options[] =
                 {
                 {"dump", 1, 0, 'f'},
+		{"fastload", 0, 0, 'F'},
                 {"optimize", 0, 0, 'o'},
                 {"nocli", 1, 0, 'n'},
                 {"save", 1, 0, 'a'},
@@ -538,13 +646,16 @@ while (1)
 		{"giga", 0, 0, 'g'},
 		{"comphier", 0, 0, 'C'},
                 {"legacy", 0, 0, 'L'},  
-		{"repscript", 1, 0, 'R'},
-		{"repperiod", 1, 0, 'P'},
+		{"tcl_init", 1, 0, 'T'},
+		{"wish", 0, 0, 'W'},
+                {"repscript", 1, 0, 'R'},   
+                {"repperiod", 1, 0, 'P'},
 		{"output", 1, 0, 'O' },
                 {0, 0, 0, 0}
                 };
 
-        c = getopt_long (argc, argv, "f:on:a:Ar:di:l:s:e:c:t:NS:vVhxX:MD:IgCLR:P:O:", long_options, &option_index);
+        c = getopt_long (argc, argv, "f:Fon:a:Ar:di:l:s:e:c:t:NS:vVhxX:MD:IgCLR:P:O:WT:", long_options, 
+&option_index);
 
         if (c == -1) break;     /* no more args */
 
@@ -558,8 +669,20 @@ while (1)
 			);
 			exit(0);
 
+		case 'W':
+#if defined(HAVE_LIBTCL)
+#if defined(WIN32) && defined(USE_TCL_STUBS)
+#else
+			is_wish = 1;
+#endif
+#else
+			fprintf(stderr, "GTKWAVE | Tcl support not compiled into this executable, exiting.\n");
+			exit(255);
+#endif
+			break;
+
 		case 'I':
-#if !defined _MSC_VER && !defined __MINGW32__
+#if !defined _MSC_VER
 			is_interactive = 1;
 #endif
 			break;
@@ -569,7 +692,7 @@ while (1)
 			break;
 
 		case 'D':
-#if !defined _MSC_VER && !defined __MINGW32__
+#if !defined _MSC_VER
 			{
 			char *s = optarg;
 			char *plus = strchr(s, '+');
@@ -662,6 +785,11 @@ while (1)
 			strcpy(GLOBALS->loaded_file_name, optarg);
 			break;
 
+		case 'F':
+			is_fastload = VCD_FSL_WRITE;
+			is_giga = 1;
+			break;
+			
                 case 'a':
 			if(wname) free_2(wname);
 			wname = malloc_2(strlen(optarg)+1);
@@ -693,7 +821,7 @@ while (1)
                         break;
 
 		case 't':
-#if !defined _MSC_VER && !defined __MINGW32__
+#if !defined _MSC_VER
 			if(GLOBALS->stems_name) free_2(GLOBALS->stems_name);
 			GLOBALS->stems_name = malloc_2(strlen(optarg)+1);
 			strcpy(GLOBALS->stems_name, optarg);
@@ -748,9 +876,49 @@ while (1)
 			break;
 
                 case 'R':
-			if(GLOBALS->repscript_name) free_2(GLOBALS->repscript_name);
-			GLOBALS->repscript_name = malloc_2(strlen(optarg)+1);
-			strcpy(GLOBALS->repscript_name, optarg);
+                        if(GLOBALS->repscript_name) free_2(GLOBALS->repscript_name);
+                        GLOBALS->repscript_name = malloc_2(strlen(optarg)+1);
+                        strcpy(GLOBALS->repscript_name, optarg);
+                        break;
+                
+                case 'P':   
+                        {
+                        int pd = atoi(optarg);
+                        if(pd > 0)
+                                {
+                                GLOBALS->repscript_period = pd;
+                                }
+                        }
+                        break;
+
+                case 'T':
+#if defined(WIN32) && defined(USE_TCL_STUBS)
+#else
+		        {
+			  char* pos;
+			  is_wish = 1;
+			  if(GLOBALS->tcl_init_cmd) 
+			    {
+			      int length = strlen(GLOBALS->tcl_init_cmd)+9+strlen(optarg);
+			      char* buffer = malloc_2(strlen(GLOBALS->tcl_init_cmd)+1);
+			      strcpy(buffer, GLOBALS->tcl_init_cmd);
+			      free_2(GLOBALS->tcl_init_cmd);
+			      GLOBALS->tcl_init_cmd = malloc_2(length+1);
+			      strcpy(GLOBALS->tcl_init_cmd, buffer);
+			      pos = GLOBALS->tcl_init_cmd + strlen(GLOBALS->tcl_init_cmd);
+			      free_2(buffer);
+			    }
+			  else
+			    {
+			      int length = 9+strlen(optarg);
+			      GLOBALS->tcl_init_cmd = malloc_2(length+1);
+			      pos = GLOBALS->tcl_init_cmd;
+			    }
+			  strcpy(pos, "; source ");
+			  pos = GLOBALS->tcl_init_cmd + strlen(GLOBALS->tcl_init_cmd);
+			  strcpy(pos, optarg);
+			}
+#endif
 			break;
 
                 case 'O':
@@ -759,16 +927,6 @@ while (1)
 			strcpy(output_name, optarg);
 			break;
 
-                case 'P':
-			{
-			int pd = atoi(optarg);
-			if(pd > 0)
-				{
-				GLOBALS->repscript_period = pd;	
-				}
-			}
-			break;
-
                 case '?':
 			opt_errors_encountered=1;
                         break;
@@ -816,13 +974,26 @@ if (optind < argc)
 		}
         }
 
-if(!GLOBALS->loaded_file_name)
+if(is_wish && is_vcd)
 	{
-	print_help(argv[0]);
+	fprintf(stderr, 
+		"GTKWAVE | Cannot use --vcd and --wish options together as both use stdin,\n"
+		"GTKWAVE | exiting!\n");
+	exit(255);
 	}
+
 read_rc_file(override_rc);
 GLOBALS->splash_disable |= splash_disable_rc_override;
 
+if(!GLOBALS->loaded_file_name)
+	{
+	/* if rc can gates off gui, default is not to disable */
+	if(GLOBALS->disable_empty_gui)
+		{
+		print_help(argv[0]);
+		}
+	}
+
 if(is_giga)
 	{
 	GLOBALS->vlist_spill_to_disk = 1;
@@ -863,10 +1034,13 @@ if(output_name)
 	}
 
 fprintf(stderr, "\n%s\n\n",WAVE_VERSION_INFO);
-if(tcl_interpreter_needs_making)
+if(!is_wish)
 	{
-	GLOBALS->argvlist = zMergeTclList(argc, (const char**)argv);
-	make_tcl_interpreter(argv);
+	if(tcl_interpreter_needs_making)
+	        {
+	        GLOBALS->argvlist = zMergeTclList(argc, (const char**)argv);
+	        make_tcl_interpreter(argv);
+	        }
 	}
 
 if((!wname)&&(GLOBALS->make_vcd_save_file))
@@ -878,6 +1052,18 @@ if((!wname)&&(GLOBALS->make_vcd_save_file))
 
 GLOBALS->sym=(struct symbol **)calloc_2(SYMPRIME,sizeof(struct symbol *));
 
+if(!GLOBALS->loaded_file_name)
+	{
+	GLOBALS->loaded_file_name = strdup_2("[no file loaded]");	
+	is_missing_file = 1;
+	GLOBALS->min_time=LLDescriptor(0);
+	GLOBALS->max_time=LLDescriptor(0);
+	if(!is_wish)
+		{
+		fprintf(stderr, "GTKWAVE | Use the -h, --help command line flags to display help.\n");
+		}
+	}
+	
 /* load either the vcd or aet file depending on suffix then mode setting */
 if(is_vcd)
 	{
@@ -903,6 +1089,11 @@ strcat(GLOBALS->winname,GLOBALS->loaded_file_name);
 
 loader_check_head:
 
+if(is_missing_file)
+	{
+	GLOBALS->loaded_file_type = MISSING_FILE;
+	}
+else
 #ifdef EXTLOAD_SUFFIX
 if( (strlen(GLOBALS->loaded_file_name)>strlen(EXTLOAD_SUFFIX))&&
 	((!strcasecmp(GLOBALS->loaded_file_name+strlen(GLOBALS->loaded_file_name)-strlen(EXTLOAD_SUFFIX),EXTLOAD_SUFFIX))) )
@@ -913,8 +1104,8 @@ if( (strlen(GLOBALS->loaded_file_name)>strlen(EXTLOAD_SUFFIX))&&
 	extload_max = extload_main(GLOBALS->loaded_file_name, GLOBALS->skip_start, GLOBALS->skip_end);
 	if((!GLOBALS->extload) || (GLOBALS->extload_already_errored) || (!extload_max))
 		{
-		fprintf(stderr, "Could not initialize '%s', exiting.\n", GLOBALS->loaded_file_name);
-		exit(255);
+		fprintf(stderr, "GTKWAVE | Could not initialize '%s'%s.\n", GLOBALS->loaded_file_name, GLOBALS->vcd_jmp_buf ? "" : ", exiting");
+		vcd_exit(255);
 		}
 	}
 else
@@ -945,7 +1136,7 @@ if((strlen(GLOBALS->loaded_file_name)>3)&&((!strcasecmp(GLOBALS->loaded_file_nam
 		}
 		else
 		{
-#if !defined _MSC_VER && !defined __MINGW32__
+#if !defined _MSC_VER
 		GLOBALS->stems_type = WAVE_ANNO_LXT2;
 		GLOBALS->aet_name = malloc_2(strlen(GLOBALS->loaded_file_name)+1);
 		strcpy(GLOBALS->aet_name, GLOBALS->loaded_file_name);
@@ -954,15 +1145,31 @@ if((strlen(GLOBALS->loaded_file_name)>3)&&((!strcasecmp(GLOBALS->loaded_file_nam
 		lx2_main(GLOBALS->loaded_file_name, GLOBALS->skip_start, GLOBALS->skip_end);
 		if(!GLOBALS->lx2_lx2_c_1)
 			{
-			fprintf(stderr, "Could not initialize '%s', exiting.\n", GLOBALS->loaded_file_name);
-			exit(255);
+			fprintf(stderr, "GTKWAVE | Could not initialize '%s'%s.\n", GLOBALS->loaded_file_name, GLOBALS->vcd_jmp_buf ? "" : ", exiting");
+			vcd_exit(255);
 			}
 		}	
 	}
 else
+if((strlen(GLOBALS->loaded_file_name)>3)&&(!strcasecmp(GLOBALS->loaded_file_name+strlen(GLOBALS->loaded_file_name)-4,".fst")))
+	{
+#if !defined _MSC_VER
+	GLOBALS->stems_type = WAVE_ANNO_FST;
+	GLOBALS->aet_name = malloc_2(strlen(GLOBALS->loaded_file_name)+1);
+	strcpy(GLOBALS->aet_name, GLOBALS->loaded_file_name);
+#endif
+        GLOBALS->loaded_file_type = FST_FILE;
+	fst_main(GLOBALS->loaded_file_name, GLOBALS->skip_start, GLOBALS->skip_end);
+	if(!GLOBALS->fst_fst_c_1)
+		{
+		fprintf(stderr, "GTKWAVE | Could not initialize '%s'%s.\n", GLOBALS->loaded_file_name, GLOBALS->vcd_jmp_buf ? "" : ", exiting");
+		vcd_exit(255);
+		}
+	}
+else
 if((strlen(GLOBALS->loaded_file_name)>3)&&(!strcasecmp(GLOBALS->loaded_file_name+strlen(GLOBALS->loaded_file_name)-4,".vzt")))
 	{
-#if !defined _MSC_VER && !defined __MINGW32__
+#if !defined _MSC_VER
 	GLOBALS->stems_type = WAVE_ANNO_VZT;
 	GLOBALS->aet_name = malloc_2(strlen(GLOBALS->loaded_file_name)+1);
 	strcpy(GLOBALS->aet_name, GLOBALS->loaded_file_name);
@@ -971,13 +1178,13 @@ if((strlen(GLOBALS->loaded_file_name)>3)&&(!strcasecmp(GLOBALS->loaded_file_name
 	vzt_main(GLOBALS->loaded_file_name, GLOBALS->skip_start, GLOBALS->skip_end);
 	if(!GLOBALS->vzt_vzt_c_1)
 		{
-		fprintf(stderr, "Could not initialize '%s', exiting.\n", GLOBALS->loaded_file_name);
-		exit(255);
+		fprintf(stderr, "GTKWAVE | Could not initialize '%s'%s.\n", GLOBALS->loaded_file_name, GLOBALS->vcd_jmp_buf ? "" : ", exiting");
+		vcd_exit(255);
 		}
 	}
 else if ((strlen(GLOBALS->loaded_file_name)>3)&&((!strcasecmp(GLOBALS->loaded_file_name+strlen(GLOBALS->loaded_file_name)-4,".aet"))||(!strcasecmp(GLOBALS->loaded_file_name+strlen(GLOBALS->loaded_file_name)-4,".ae2"))))
 	{
-#if !defined _MSC_VER && !defined __MINGW32__
+#if !defined _MSC_VER
 	GLOBALS->stems_type = WAVE_ANNO_AE2;
 	GLOBALS->aet_name = malloc_2(strlen(GLOBALS->loaded_file_name)+1);
 	strcpy(GLOBALS->aet_name, GLOBALS->loaded_file_name);
@@ -986,8 +1193,8 @@ else if ((strlen(GLOBALS->loaded_file_name)>3)&&((!strcasecmp(GLOBALS->loaded_fi
 	ae2_main(GLOBALS->loaded_file_name, GLOBALS->skip_start, GLOBALS->skip_end, GLOBALS->indirect_fname);
 	if(!GLOBALS->ae2)
 		{
-		fprintf(stderr, "Could not initialize '%s', exiting.\n", GLOBALS->loaded_file_name);
-		exit(255);
+		fprintf(stderr, "GTKWAVE | Could not initialize '%s'%s.\n", GLOBALS->loaded_file_name, GLOBALS->vcd_jmp_buf ? "" : ", exiting");
+		vcd_exit(255);
 		}
 	}
 else if (
@@ -1000,7 +1207,7 @@ else if (
 	  if(!ghw_main(GLOBALS->loaded_file_name))
 		{
 		/* error message printed in ghw_main() */
-		exit(255);
+		vcd_exit(255);
 		}
 	}
 else if (strlen(GLOBALS->loaded_file_name)>4)	/* case for .aet? type filenames */
@@ -1010,7 +1217,7 @@ else if (strlen(GLOBALS->loaded_file_name)>4)	/* case for .aet? type filenames *
 	sufbuf[4] = 0;
 	if(!strcasecmp(sufbuf, ".aet"))	/* strncasecmp() in windows? */
 		{
-#if !defined _MSC_VER && !defined __MINGW32__
+#if !defined _MSC_VER
 		GLOBALS->stems_type = WAVE_ANNO_AE2;
 		GLOBALS->aet_name = malloc_2(strlen(GLOBALS->loaded_file_name)+1);
 		strcpy(GLOBALS->aet_name, GLOBALS->loaded_file_name);
@@ -1019,8 +1226,8 @@ else if (strlen(GLOBALS->loaded_file_name)>4)	/* case for .aet? type filenames *
 		ae2_main(GLOBALS->loaded_file_name, GLOBALS->skip_start, GLOBALS->skip_end, GLOBALS->indirect_fname);
 		if(!GLOBALS->ae2)
 			{
-			fprintf(stderr, "Could not initialize '%s', exiting.\n", GLOBALS->loaded_file_name);
-			exit(255);
+			fprintf(stderr, "GTKWAVE | Could not initialize '%s'%s.\n", GLOBALS->loaded_file_name, GLOBALS->vcd_jmp_buf ? "" : ", exiting");
+			vcd_exit(255);
 			}
 		}
 		else
@@ -1042,10 +1249,10 @@ load_vcd:
 
 #endif
 
-#if !defined _MSC_VER && !defined __MINGW32__
+#if !defined _MSC_VER 
 	if(is_interactive)
 		{
-		GLOBALS->loaded_file_type = NO_FILE;
+		GLOBALS->loaded_file_type = DUMPLESS_FILE;
 		vcd_partial_main(GLOBALS->loaded_file_name);
 		}
 		else
@@ -1053,12 +1260,21 @@ load_vcd:
 		{
 		if(is_legacy)
 			{
-			  GLOBALS->loaded_file_type = (strcmp(GLOBALS->loaded_file_name, "-vcd")) ? VCD_FILE : NO_FILE;
+			  GLOBALS->loaded_file_type = (strcmp(GLOBALS->loaded_file_name, "-vcd")) ? VCD_FILE : DUMPLESS_FILE;
 			  vcd_main(GLOBALS->loaded_file_name);
 			}
 			else
 			{
-			  GLOBALS->loaded_file_type = (strcmp(GLOBALS->loaded_file_name, "-vcd")) ? VCD_RECODER_FILE : NO_FILE;
+			  if(strcmp(GLOBALS->loaded_file_name, "-vcd"))
+				{
+				GLOBALS->loaded_file_type = VCD_RECODER_FILE;
+				GLOBALS->use_fastload = is_fastload;
+				}
+				else
+				{
+				GLOBALS->loaded_file_type = DUMPLESS_FILE;
+				GLOBALS->use_fastload = VCD_FSL_NONE;
+				}
 			  vcd_recoder_main(GLOBALS->loaded_file_name);
 			}
 		}
@@ -1151,7 +1367,7 @@ if((wname)||(vcd_save_handle_cached)||(is_smartsave))
 			{
 		        while((iline=fgetmalloc(wave)))
 		                {
-		                parsewavline_lx2(iline, 0);
+		                parsewavline_lx2(iline, NULL, 0);
 				free_2(iline);
 		                }
 
@@ -1161,6 +1377,7 @@ if((wname)||(vcd_save_handle_cached)||(is_smartsave))
 				case LXT2_IS_AET2: ae2_import_masked(); break;
 				case LXT2_IS_VZT:  vzt_import_masked(); break;
 				case LXT2_IS_VLIST: vcd_import_masked(); break;
+				case LXT2_IS_FST: fst_import_masked(); break;
 				}
 
 			if(wave_is_compressed)
@@ -1177,6 +1394,7 @@ if((wname)||(vcd_save_handle_cached)||(is_smartsave))
 			if(!wave)
 			        {
 			        fprintf(stderr, "** WARNING: Error opening .sav file '%s', skipping.\n",wname);
+				EnsureGroupsMatch();
 				goto savefile_bail;
 			        }	
 			}
@@ -1185,7 +1403,7 @@ if((wname)||(vcd_save_handle_cached)||(is_smartsave))
 		GLOBALS->shift_timebase_default_for_add=LLDescriptor(0);
 	        while((iline=fgetmalloc(wave)))
 	                {
-	                parsewavline(iline, 0);
+	                parsewavline(iline, NULL, 0);
 			any_shadow |= GLOBALS->shadow_active;
 			free_2(iline);
 	                }
@@ -1194,6 +1412,8 @@ if((wname)||(vcd_save_handle_cached)||(is_smartsave))
 
 		if(wave_is_compressed) pclose(wave); else fclose(wave);
 
+		EnsureGroupsMatch();
+
                 if(any_shadow)
                         {
                         if(GLOBALS->shadow_straces)
@@ -1456,7 +1676,7 @@ if(GLOBALS->use_toolbutton_interface)
 
 		gtk_toolbar_insert_space(GTK_TOOLBAR(tb), tb_pos++);
 
-		if((GLOBALS->loaded_file_type != NO_FILE)&&(!GLOBALS->disable_menus))
+		if((GLOBALS->loaded_file_type != DUMPLESS_FILE)&&(!GLOBALS->disable_menus))
 			{
 			stock = gtk_toolbar_insert_stock(GTK_TOOLBAR(tb),
 	                                         GTK_STOCK_REFRESH,
@@ -1481,6 +1701,11 @@ if(GLOBALS->use_toolbutton_interface)
 					  NULL,
 					  tb_pos++);
 
+		GLOBALS->missing_file_toolbar = tb;
+		if(GLOBALS->loaded_file_type == MISSING_FILE)
+			{
+			gtk_widget_set_sensitive(GLOBALS->missing_file_toolbar, FALSE);
+			}
 		} /* of ...if(mainwindow_already_built) */
 	}
 	else
@@ -1591,7 +1816,7 @@ if(GLOBALS->use_toolbutton_interface)
 		                      	GTK_FILL | GTK_EXPAND | GTK_SHRINK, 20, 0);
 		gtk_widget_show (timebox);
 
-		if((GLOBALS->loaded_file_type != NO_FILE)&&(!GLOBALS->disable_menus))
+		if((GLOBALS->loaded_file_type != DUMPLESS_FILE)&&(!GLOBALS->disable_menus))
 			{
 			GtkWidget *r_pixmap = gtk_pixmap_new(GLOBALS->redo_pixmap, GLOBALS->redo_mask);
 			GtkWidget *main_vbox1;
@@ -1657,11 +1882,10 @@ if(GLOBALS->do_resize_signals)
 gtk_widget_show(GLOBALS->signalwindow);
 
 #if GTK_CHECK_VERSION(2,4,0)
-if(!GLOBALS->hide_sst)
+if((!GLOBALS->hide_sst)&&(GLOBALS->loaded_file_type != MISSING_FILE))
 	{
 	GLOBALS->toppanedwindow = gtk_hpaned_new();
 	GLOBALS->sstpane = treeboxframe("SST", GTK_SIGNAL_FUNC(mkmenu_treesearch_cleanup));
- 
 	GLOBALS->expanderwindow = gtk_expander_new_with_mnemonic("_SST");
 	gtk_expander_set_expanded(GTK_EXPANDER(GLOBALS->expanderwindow), (GLOBALS->sst_expanded==TRUE));
 	gtk_container_add(GTK_CONTAINER(GLOBALS->expanderwindow), GLOBALS->sstpane);
@@ -1698,7 +1922,7 @@ if(GLOBALS->dnd_sigview)
 dnd_setup(GLOBALS->signalarea, GLOBALS->wavearea, 1);
 
 #if GTK_CHECK_VERSION(2,4,0)
-if(!GLOBALS->hide_sst)
+if((!GLOBALS->hide_sst)&&(GLOBALS->loaded_file_type != MISSING_FILE))
 	{
 	gtk_paned_pack1(GTK_PANED(GLOBALS->toppanedwindow), GLOBALS->expanderwindow, 0, 0);
 	gtk_paned_pack2(GTK_PANED(GLOBALS->toppanedwindow), panedwindow, ~0, 0);
@@ -1731,7 +1955,6 @@ if(GLOBALS->treeopen_chain_head)
 if(!mainwindow_already_built)
 	{
 	gtk_widget_show(top_table);
-
 	gtk_table_attach (GTK_TABLE (whole_table), GLOBALS->force_toolbars?toolhandle:top_table, 0, 16, 0, 1,
 	                      	GTK_FILL | GTK_EXPAND,
 	                      	GTK_FILL | GTK_EXPAND | GTK_SHRINK, 0, 0);
@@ -1850,12 +2073,33 @@ if(scriptfile)
 	free_2(scriptfile); scriptfile=NULL;
 	}
 
-#if !defined _MSC_VER && !defined __MINGW32__
+#if !defined _MSC_VER
 if(GLOBALS->dual_attach_id_main_c_1)
 	{
 	fprintf(stderr, "GTKWAVE | Attaching %08X as dual head session %d\n", GLOBALS->dual_attach_id_main_c_1, GLOBALS->dual_id);
 
+#ifdef __MINGW32__
+		{
+		HANDLE hMapFile;
+		char mapName[257];
+
+		sprintf(mapName, "twinwave%d", GLOBALS->dual_attach_id_main_c_1);
+		hMapFile = OpenFileMapping(FILE_MAP_ALL_ACCESS, FALSE, mapName);
+		if(hMapFile == NULL)
+		        {
+		        fprintf(stderr, "Could not attach shared memory map name '%s', exiting.\n", mapName);
+		        exit(255);
+		        }
+		GLOBALS->dual_ctx = MapViewOfFile(hMapFile, FILE_MAP_ALL_ACCESS, 0, 0, 2 * sizeof(struct gtkwave_dual_ipc_t));
+		if(GLOBALS->dual_ctx == NULL)
+		        {
+		        fprintf(stderr, "Could not map view of file '%s', exiting.\n", mapName);
+		        exit(255);
+		        }
+		}
+#else
 	GLOBALS->dual_ctx = shmat(GLOBALS->dual_attach_id_main_c_1, NULL, 0);
+#endif
 	if(GLOBALS->dual_ctx)
 		{
 		if(memcmp(GLOBALS->dual_ctx[GLOBALS->dual_id].matchword, DUAL_MATCHWORD, 4))
@@ -1869,8 +2113,9 @@ if(GLOBALS->dual_attach_id_main_c_1)
 			{
 		        GtkAdjustment *hadj;
 		        TimeType pageinc, gt;
+#ifndef __MINGW32__
 			struct timeval tv;
-
+#endif
 			if(GLOBALS->dual_ctx[1-GLOBALS->dual_id].use_new_times)
 				{
 				GLOBALS->dual_race_lock = 1;
@@ -1963,9 +2208,13 @@ if(GLOBALS->dual_attach_id_main_c_1)
 
 			GLOBALS->dual_race_lock = 0;
 
+#ifdef __MINGW32__
+			Sleep(1000 / 25);
+#else
 			tv.tv_sec = 0;
        			tv.tv_usec = 1000000 / 25;
 			select(0, NULL, NULL, NULL, &tv);
+#endif
 			}
 		}
 		else
@@ -1975,15 +2224,31 @@ if(GLOBALS->dual_attach_id_main_c_1)
 		}
 	}
 else
+#endif
 if(is_interactive)
 	{
 	for(;;) kick_partial_vcd();
 	}
 	else
-#endif
 	{
-	/* Jump in to the main program loop */
-	gtk_main();
+#if defined(HAVE_LIBTCL)
+	if(is_wish)
+	  {
+	  char* argv_mod[1];
+
+	  set_globals_interp(argv[0], 1);
+	  addPidToExecutableName(1, argv, argv_mod);
+	  Tk_MainEx(1, argv_mod, gtkwaveInterpreterInit, GLOBALS->interp);
+
+	  /* note: for(kk=0;kk<argc;kk++) { free_2(argv_mod[kk]); } can't really be done here, doesn't matter anyway as context free will get it */
+	  }
+	  else
+	  {
+	  gtk_main();
+          }
+#else
+	  gtk_main();
+#endif
 	}
 
 return(0);
@@ -2015,7 +2280,9 @@ set_window_size (int x, int y)
     }
   else
     {
+#ifdef WAVE_USE_XID
       if(!GLOBALS->socket_xid)
+#endif
 	{
       	gtk_window_set_default_size(GTK_WINDOW (GLOBALS->mainwindow), x, y);
 	}
@@ -2082,9 +2349,16 @@ if((GLOBALS->initial_window_xpos>=0)||(GLOBALS->initial_window_ypos>=0))
 /*
  * bring up stems browser
  */
-#if !defined _MSC_VER && !defined __MINGW32__
+#if !defined _MSC_VER
 int stems_are_active(void)
 {
+#ifdef __MINGW32__
+if(GLOBALS->anno_ctx && GLOBALS->anno_ctx->browser_process)
+	{
+	/* nothing */
+	return(1);
+	}
+#else
 if(GLOBALS->anno_ctx && GLOBALS->anno_ctx->browser_process)
 	{
 	int mystat =0;
@@ -2100,7 +2374,7 @@ if(GLOBALS->anno_ctx && GLOBALS->anno_ctx->browser_process)
 		GLOBALS->anno_ctx = NULL;
 		}
 	}
-
+#endif
 return(0);
 }
 #endif
@@ -2108,7 +2382,7 @@ return(0);
 
 void activate_stems_reader(char *stems_name)
 {
-#if !defined _MSC_VER && !defined __MINGW32__
+#if !defined _MSC_VER
 
 #ifdef __CYGWIN__
 /* ajb : ok static as this is a one-time warning message... */
@@ -2133,6 +2407,10 @@ if(GLOBALS->stems_type != WAVE_ANNO_NONE)
 			fprintf(stderr, "GTKWAVE | The Cygserver services are used by Cygwin applications only\n");
 			fprintf(stderr, "GTKWAVE | if you set the environment variable CYGWIN to contain the\n");
 			fprintf(stderr, "GTKWAVE | string \"server\". You must do this before starting this program.\n");
+			fprintf(stderr, "GTKWAVE |\n");
+			fprintf(stderr, "GTKWAVE | If this still does not work, you may have to enable the cygserver\n");
+			fprintf(stderr, "GTKWAVE | by entering \"cygserver-config\" and answering \"yes\" followed by\n");
+			fprintf(stderr, "GTKWAVE | \"net start cygserver\".\n");
 			fprintf(stderr, "GTKWAVE | =================================================================\n");
 			}
 		cyg_called = 1;
@@ -2142,6 +2420,69 @@ if(GLOBALS->stems_type != WAVE_ANNO_NONE)
 
 if(GLOBALS->stems_type != WAVE_ANNO_NONE)
 	{
+#ifdef __MINGW32__
+	int shmid = getpid();
+	char mapName[257];
+	HANDLE hMapFile;
+        STARTUPINFO si;
+        PROCESS_INFORMATION pi;
+        BOOL rc;
+
+        memset(&si, 0, sizeof(STARTUPINFO));
+        memset(&pi, 0, sizeof(PROCESS_INFORMATION));
+	si.cb = sizeof(si);
+
+	sprintf(mapName, "rtlbrowse%d", shmid);
+	hMapFile = CreateFileMapping(INVALID_HANDLE_VALUE, NULL, PAGE_READWRITE, 0, sizeof(struct gtkwave_annotate_ipc_t), mapName);
+	if(hMapFile != NULL)
+	        {
+	        GLOBALS->anno_ctx = MapViewOfFile(hMapFile, FILE_MAP_ALL_ACCESS, 0, 0, sizeof(struct gtkwave_annotate_ipc_t));
+		if(GLOBALS->anno_ctx)
+			{
+			char mylist[257];
+
+                        sprintf(mylist, "rtlbrowse.exe %08x", shmid);
+
+			memset(GLOBALS->anno_ctx, 0, sizeof(struct gtkwave_annotate_ipc_t));
+
+			memcpy(GLOBALS->anno_ctx->matchword, WAVE_MATCHWORD, 4);
+			GLOBALS->anno_ctx->aet_type = GLOBALS->stems_type;			
+			strcpy(GLOBALS->anno_ctx->aet_name, GLOBALS->aet_name);
+			strcpy(GLOBALS->anno_ctx->stems_name, stems_name);
+
+			update_markertime(GLOBALS->tims.marker);
+
+                        rc = CreateProcess(
+                                        "rtlbrowse.exe",
+                                        mylist,
+                                        NULL,
+                                        NULL,
+                                        FALSE,
+                                        0,
+                                        NULL,
+                                        NULL,
+                                        &si,
+                                        &pi);
+                                        
+                        if(!rc)  
+                        	{
+				UnmapViewOfFile(GLOBALS->anno_ctx);
+				CloseHandle(hMapFile);
+				GLOBALS->anno_ctx = NULL;
+				GLOBALS->stems_type = WAVE_ANNO_NONE;
+                                }
+				else
+				{
+				GLOBALS->anno_ctx->browser_process = pi.hProcess;
+				}
+			}
+			else
+			{
+			CloseHandle(hMapFile);
+			GLOBALS->stems_type = WAVE_ANNO_NONE;
+			}
+		}
+#else
 	int shmid = shmget(0, sizeof(struct gtkwave_annotate_ipc_t), IPC_CREAT | 0600 );
 	if(shmid >=0)
 		{
@@ -2176,8 +2517,16 @@ if(GLOBALS->stems_type != WAVE_ANNO_NONE)
 				{
 			        if(pid) /* parent==original server_pid */
 			                {
+#ifndef __CYGWIN__
+					static int kill_installed = 0;
+
+					if(!kill_installed)
+						{
+						kill_installed = 1;
+						atexit(kill_stems_browser);
+						}
+#endif
 					GLOBALS->anno_ctx->browser_process = pid;
-					atexit(kill_stems_browser);
 #ifndef __linux__
 					sleep(2);
 					shmctl(shmid, IPC_RMID, &ds); /* mark for destroy */
@@ -2198,6 +2547,7 @@ if(GLOBALS->stems_type != WAVE_ANNO_NONE)
 			GLOBALS->stems_type = WAVE_ANNO_NONE;
 			}
 		}
+#endif
 	}
 	else
 	{
@@ -2210,6 +2560,13 @@ if(GLOBALS->stems_type != WAVE_ANNO_NONE)
 #if !defined _MSC_VER && !defined __MINGW32__
 void optimize_vcd_file(void) {
   if(!strcmp("-vcd", GLOBALS->unoptimized_vcd_file_name)) {        
+#ifdef __CYGWIN__
+    char *buf = strdup_2("vcd2lxt2 -- - vcd.lx2");
+    system(buf);
+    free_2(buf);
+    GLOBALS->loaded_file_name = strdup_2("vcd.lx2");
+    GLOBALS->is_optimized_stdin_vcd = 1;
+#else
     pid_t pid;
     char *buf = malloc_2(strlen("vcd") + 4 + 1);
     sprintf(buf, "%s.lx2", "vcd");
@@ -2224,6 +2581,7 @@ void optimize_vcd_file(void) {
 	if(rc > 0) {
 	  free_2(GLOBALS->loaded_file_name);
 	  GLOBALS->loaded_file_name = buf;
+	  GLOBALS->is_optimized_stdin_vcd = 1;
 	}					
       }
       else {
@@ -2231,8 +2589,18 @@ void optimize_vcd_file(void) {
 	exit(255);
       }
     }
+#endif
   }
   else {
+#ifdef __CYGWIN__
+    char *buf = malloc_2(9 + (strlen(GLOBALS->unoptimized_vcd_file_name) + 1) + (strlen(GLOBALS->unoptimized_vcd_file_name) + 4 + 1));
+    sprintf(buf, "vcd2lxt2 %s %s.lx2", GLOBALS->unoptimized_vcd_file_name, GLOBALS->unoptimized_vcd_file_name);
+    system(buf);
+    free_2(buf);
+    buf = malloc_2(strlen(GLOBALS->unoptimized_vcd_file_name) + 4 + 1);
+    sprintf(buf, "%s.lx2", GLOBALS->unoptimized_vcd_file_name);
+    GLOBALS->loaded_file_name = buf;
+#else
     pid_t pid;
     char *buf = malloc_2(strlen(GLOBALS->unoptimized_vcd_file_name) + 4 + 1);
     sprintf(buf, "%s.lx2", GLOBALS->unoptimized_vcd_file_name);
@@ -2254,13 +2622,119 @@ void optimize_vcd_file(void) {
 	exit(255);
       }
     }
+#endif
   }	
 }
 #endif
 
 /*
- * $Id: main.c,v 1.55 2009/02/16 17:16:05 gtkwave Exp $
+ * $Id: main.c,v 1.90 2009/12/24 20:55:27 gtkwave Exp $
  * $Log: main.c,v $
+ * Revision 1.90  2009/12/24 20:55:27  gtkwave
+ * warnings cleanups
+ *
+ * Revision 1.89  2009/12/16 17:41:21  gtkwave
+ * code + documentation cleanups for --script
+ *
+ * Revision 1.88  2009/12/12 06:06:39  gtkwave
+ * added error for --wish if no tcl present
+ *
+ * Revision 1.87  2009/12/12 01:12:57  gtkwave
+ * tcl cross-platform fixes
+ *
+ * Revision 1.86  2009/12/11 23:41:07  gtkwave
+ * cygwin fixes for optimized vcd
+ *
+ * Revision 1.85  2009/11/17 00:14:40  gtkwave
+ * removed redundant is_wish check
+ *
+ * Revision 1.84  2009/11/11 16:30:57  gtkwave
+ * changed tcl library ordering, no tk unless --wish
+ *
+ * Revision 1.83  2009/11/09 20:09:12  gtkwave
+ * made --vcd and --wish mutually exclusive
+ *
+ * Revision 1.82  2009/11/06 04:15:17  gtkwave
+ * gtk+-1.2 compile fixes
+ *
+ * Revision 1.81  2009/11/05 23:11:09  gtkwave
+ * added EnsureGroupsMatch()
+ *
+ * Revision 1.80  2009/10/07 16:59:07  gtkwave
+ * move Tcl_CreateInterp to tcl_helper.c to make stubify easier
+ *
+ * Revision 1.79  2009/09/22 13:51:13  gtkwave
+ * warnings fixes
+ *
+ * Revision 1.78  2009/09/15 06:21:07  gtkwave
+ * simpod-style tcl command reintegration
+ *
+ * Revision 1.77  2009/09/14 03:00:08  gtkwave
+ * bluespec code integration
+ *
+ * Revision 1.76  2009/08/16 04:41:41  gtkwave
+ * fix -d flag across reloads and new tab openings
+ *
+ * Revision 1.75  2009/08/06 20:03:31  gtkwave
+ * warnings fixes
+ *
+ * Revision 1.74  2009/07/03 18:48:33  gtkwave
+ * fst read compatibility fixes for mingw
+ *
+ * Revision 1.73  2009/06/07 08:40:44  gtkwave
+ * adding FST support
+ *
+ * Revision 1.72  2009/04/24 20:00:03  gtkwave
+ * rtlbrowse exit kill mods
+ *
+ * Revision 1.71  2009/04/24 19:47:15  gtkwave
+ * multiple rtlbrowse session kill on gtkwave exit with mult tabs active
+ *
+ * Revision 1.70  2009/04/24 04:24:22  gtkwave
+ * reload and cygwin fixes for rtlbrowse
+ *
+ * Revision 1.69  2009/04/23 21:57:53  gtkwave
+ * added mingw support for rtlbrowse
+ *
+ * Revision 1.68  2009/04/23 19:38:50  gtkwave
+ * add mingw support to twinwave
+ *
+ * Revision 1.67  2009/04/23 04:57:38  gtkwave
+ * ported shmidcat and partial vcd loader function to mingw
+ *
+ * Revision 1.66  2009/04/11 21:57:53  gtkwave
+ * changed exit() to vcd_exit() in some instances for tab loader hardening
+ *
+ * Revision 1.65  2009/04/09 22:17:21  gtkwave
+ * install_keypress_handler() fixes
+ *
+ * Revision 1.64  2009/03/27 05:08:56  gtkwave
+ * disable splash screen for now on empty gui due to undetermine conflicts
+ *
+ * Revision 1.63  2009/03/27 04:58:14  gtkwave
+ * enable splash screen during empty gui handling / load dumpfile
+ *
+ * Revision 1.62  2009/03/27 04:38:05  gtkwave
+ * working on ergonomics of drag and drop into an empty gui
+ *
+ * Revision 1.61  2009/03/27 00:11:01  gtkwave
+ * minor change in -h, --help text when gui enabled
+ *
+ * Revision 1.60  2009/03/26 23:53:22  gtkwave
+ * added disable_empty_gui rc variable which reverts to old behavior
+ *
+ * Revision 1.59  2009/03/26 20:57:41  gtkwave
+ * added MISSING_FILE support for bringing up gtkwave without a dumpfile
+ *
+ * Revision 1.58  2009/03/09 06:23:37  gtkwave
+ * cygwin tcl compatibility fix
+ *
+ * Revision 1.57  2009/03/05 16:17:56  gtkwave
+ * added fastload option
+ *
+ * Revision 1.56  2009/02/23 18:29:50  gtkwave
+ * add more information on init failure for mac users
+ *
  * Revision 1.55  2009/02/16 17:16:05  gtkwave
  * extload error hardening and recovery
  *
@@ -2475,4 +2949,3 @@ void optimize_vcd_file(void) {
  * initial release
  *
  */
-
