@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2008.
+ * Copyright (c) Tony Bybell 1999-2009.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,6 +30,7 @@
 #include "main.h"
 
 void get_main_menu (GtkWidget *, GtkWidget **menubar);
+void menu_set_sensitive(void);
 int file_quit_cmd_callback (GtkWidget *widget, gpointer data);
 int set_wave_menu_accelerator(char *str);
 int execute_script(char *name);
@@ -61,7 +62,7 @@ WV_MENU_FWSFAS,
 WV_MENU_SEP2,
 WV_MENU_FRLF,
 WV_MENU_SEP2LF,
-#if !defined __MINGW32__ && !defined _MSC_VER
+#if !defined _MSC_VER
 WV_MENU_FRSTMF,
 WV_MENU_SEP2STMF,
 #endif
@@ -72,15 +73,17 @@ WV_MENU_TCLSEP,
 WV_MENU_FQY,
 WV_MENU_FQN,
 WV_MENU_ESTMH,
+WV_MENU_ETH,
 WV_MENU_SEP3,
 WV_MENU_EIB,
 WV_MENU_EIC,
 WV_MENU_EIA,
-WV_MENU_EAHT,
-WV_MENU_ERHA,
 WV_MENU_EC,
 WV_MENU_ECY,
 WV_MENU_EP,
+WV_MENU_SEP3A,
+WV_MENU_EAHT,
+WV_MENU_ERHA,
 WV_MENU_SEP4,
 WV_MENU_EE,
 WV_MENU_ECD,
@@ -100,6 +103,12 @@ WV_MENU_EDFION,
 WV_MENU_EDFIOFF,
 WV_MENU_EDFRON,
 WV_MENU_EDFROFF,
+WV_MENU_XLF_0,
+WV_MENU_XLF_1,
+#if !defined __MINGW32__ && !defined _MSC_VER
+WV_MENU_XLP_0,
+WV_MENU_XLP_1,
+#endif
 WV_MENU_EDFAOFF,
 WV_MENU_EDFASTEP,
 WV_MENU_EDFAINTERPOL,
@@ -109,12 +118,9 @@ WV_MENU_EDFARAD,
 WV_MENU_RFILL0,
 WV_MENU_RFILL1,
 WV_MENU_RFILLOFF,
-WV_MENU_XLF_0,
-WV_MENU_XLF_1,
-#if !defined __MINGW32__ && !defined _MSC_VER
-WV_MENU_XLP_0,
-WV_MENU_XLP_1,
-#endif
+WV_MENU_B2G,
+WV_MENU_G2B,
+WV_MENU_GBNONE,
 WV_MENU_ESCAH,
 WV_MENU_ESCFH,
 WV_MENU_SEP6,
@@ -125,8 +131,10 @@ WV_MENU_SEP7A,
 WV_MENU_EEX,
 WV_MENU_ESH,
 WV_MENU_SEP6A,
-WV_MENU_EXA,
-WV_MENU_CPA,
+/* WV_MENU_EXA, */
+/* WV_MENU_CPA, */
+WV_MENU_TG,
+WV_MENU_AG,
 WV_MENU_SEP6A1,
 WV_MENU_EHR,
 WV_MENU_EUHR,
@@ -238,7 +246,6 @@ void menu_remove_aliases(GtkWidget *widget, gpointer data);
 void menu_cut_traces(GtkWidget *widget, gpointer data);
 void menu_copy_traces(GtkWidget *widget, gpointer data);
 void menu_paste_traces(GtkWidget *widget, gpointer data);
-void menu_expand(GtkWidget *widget, gpointer data);
 void menu_combine_down(GtkWidget *widget, gpointer data);
 void menu_combine_up(GtkWidget *widget, gpointer data);
 void menu_reduce_singlebit_vex(GtkWidget *widget, gpointer data);
@@ -269,8 +276,6 @@ void menu_unwarp_traces(GtkWidget *widget, gpointer data);
 void menu_unwarp_traces_all(GtkWidget *widget, gpointer data);
 void menu_dataformat_exclude_on(GtkWidget *widget, gpointer data);
 void menu_dataformat_exclude_off(GtkWidget *widget, gpointer data);
-void menu_expand_all(GtkWidget *widget, gpointer data);
-void menu_collapse_all(GtkWidget *widget, gpointer data);
 void menu_regexp_highlight(GtkWidget *widget, gpointer data);
 void menu_regexp_unhighlight(GtkWidget *widget, gpointer data);
 void menu_dataformat_highlight_all(GtkWidget *widget, gpointer data);
@@ -314,6 +319,8 @@ void menu_remove_marked(GtkWidget *widget, gpointer data);
 void menu_lxt_clk_compress(GtkWidget *widget, gpointer data);
 void menu_help(GtkWidget *widget, gpointer data);
 void menu_version(GtkWidget *widget, gpointer data);
+void menu_toggle_group(GtkWidget *widget, gpointer data);
+
 
 GtkItemFactoryEntry *retrieve_menu_items_array(int *num_items);
 
@@ -326,11 +333,28 @@ void set_scale_to_time_dimension_toggles(void);
 void write_save_helper(FILE *file);
 void read_save_helper(char *wname);
 
+void SetTraceScrollbarRowValue(int row, unsigned center);
+
 #endif
 
 /*
- * $Id: menu.h,v 1.24 2009/01/13 23:09:12 gtkwave Exp $
+ * $Id: menu.h,v 1.29 2009/11/25 09:49:28 gtkwave Exp $
  * $Log: menu.h,v $
+ * Revision 1.29  2009/11/25 09:49:28  gtkwave
+ * added gray code support
+ *
+ * Revision 1.28  2009/09/22 13:51:14  gtkwave
+ * warnings fixes
+ *
+ * Revision 1.27  2009/09/14 03:00:08  gtkwave
+ * bluespec code integration
+ *
+ * Revision 1.26  2009/04/23 21:57:53  gtkwave
+ * added mingw support for rtlbrowse
+ *
+ * Revision 1.25  2009/04/10 04:33:58  gtkwave
+ * added menu blackouts on empty gui
+ *
  * Revision 1.24  2009/01/13 23:09:12  gtkwave
  * added copy traces button to toolbar in gtkwave
  *
