@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 2006-2008.
+ * Copyright (c) Tony Bybell 2006-2009.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -64,7 +64,12 @@ if((flags & TR_ZEROFILL) != 0) { ch[pos++] = '0'; }
 else
 if((flags & TR_ONEFILL) != 0) { ch[pos++] = '1'; }
 
-/* [8] (at worst case this needs 9 characters) */
+/* [8] */
+if((flags & TR_BINGRAY) != 0) { ch[pos++] = 'G'; }
+/* [9] */
+if((flags & TR_GRAYBIN) != 0) { ch[pos++] = 'g'; }
+
+/* [10]  (at worst case this needs 11 characters) */
 ch[pos] = 0;
 
 return(pos);
@@ -112,14 +117,20 @@ if(t->name)
 				{
 				if(!t->n.nd->ext)
 					{
+					unsigned char h_val = h_ptr->v.h_val;
+					if(t->n.nd->vartype == ND_VCD_EVENT)
+						{
+						h_val = (h_ptr->time >= GLOBALS->tims.first) && ((GLOBALS->tims.marker-GLOBALS->shift_timebase) == h_ptr->time) ? AN_1 : AN_0; /* generate impulse */
+						}
+
 					str=(char *)calloc_2(1,2*sizeof(char));
 					if(t->flags&TR_INVERT)
 						{
-						str[0]=AN_STR_INV[h_ptr->v.h_val];
+						str[0]=AN_STR_INV[h_val];
 						}
 						else
 						{
-						str[0]=AN_STR[h_ptr->v.h_val];
+						str[0]=AN_STR[h_val];
 						}
 					*asciivalue=str;
 					vlen=font_engine_string_measure(GLOBALS->wavefont,str);
@@ -240,7 +251,7 @@ int num_info_rows = 2;
 char *flagged_name = NULL;
 char *alternate_name = NULL;
 int fh;
-char flag_string[9];
+char flag_string[11];
 
 if(GLOBALS->disable_mouseover)
 	{
@@ -385,8 +396,14 @@ if(flagged_name) { free_2(flagged_name); }
 }
 
 /*
- * $Id: mouseover.c,v 1.10 2008/12/09 00:36:42 gtkwave Exp $
+ * $Id: mouseover.c,v 1.12 2009/11/25 09:49:28 gtkwave Exp $
  * $Log: mouseover.c,v $
+ * Revision 1.12  2009/11/25 09:49:28  gtkwave
+ * added gray code support
+ *
+ * Revision 1.11  2009/06/25 22:12:30  gtkwave
+ * convert event impulses to strict 1/0 activity values regardless of val
+ *
  * Revision 1.10  2008/12/09 00:36:42  gtkwave
  * added mouseover support for signal window
  *
