@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 2006-2008.
+ * Copyright (c) Tony Bybell 2006-2009.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,6 +24,8 @@
 #include "bsearch.h"
 #include "hierpack.h"
 
+WAVE_NODEVARTYPE_STR
+
 /************************************************************************************************/
 
 static char *get_fullname(Trptr t)
@@ -37,7 +39,7 @@ if(!(t->flags&(TR_BLANK|TR_ANALOG_BLANK_STRETCH)))
 		}
 		else 
 		{
-		if(!t->is_alias)
+		if(!HasAlias(t))
 			{
 			int flagged;
 	                s = hier_decompress_flagged(t->n.nd->nname, &flagged);
@@ -50,8 +52,9 @@ return(s);
 }
 
 
-static int determine_trace_flags(unsigned int flags, char *ch)
+static int determine_trace_flags(Trptr t, char *ch)
 {
+unsigned int flags = t->flags;
 int pos = 0;
 
 /* [0] */
@@ -89,9 +92,31 @@ if((flags & TR_ZEROFILL) != 0) { ch[pos++] = '0'; }
 else
 if((flags & TR_ONEFILL) != 0) { ch[pos++] = '1'; }
 
-/* [8] (at worst case this needs 9 characters) */
+/* [8] */
+if((flags & TR_BINGRAY) != 0) { ch[pos++] = 'G'; }
+/* [9] */
+if((flags & TR_GRAYBIN) != 0) { ch[pos++] = 'g'; }
+
+/* [10]  (at worst case this front part needs 11 characters) */
 ch[pos] = 0;
 
+if(!t->vector)
+	{
+	int vartype = t->n.nd->vartype;
+	if((vartype < 0) || (vartype > ND_VARTYPE_MAX))
+		{
+		vartype = 0;
+		}
+
+	if(vartype)
+		{
+		ch[pos++] = ':';
+		strcpy(ch + pos, vartype_strings[vartype]);
+		pos += strlen(vartype_strings[vartype]);
+		ch[++pos] = 0;
+		}
+	}
+
 return(pos);
 }
 
@@ -137,14 +162,20 @@ if(tname)
 				{
 				if(!t->n.nd->ext)
 					{
+					unsigned char h_val = h_ptr->v.h_val;
+					if(t->n.nd->vartype == ND_VCD_EVENT)
+						{
+						h_val = (h_ptr->time >= GLOBALS->tims.first) && ((GLOBALS->tims.marker-GLOBALS->shift_timebase) == h_ptr->time) ? AN_1 : AN_0; /* generate impulse */
+						}
+
 					str=(char *)calloc_2(1,2*sizeof(char));
 					if(t->flags&TR_INVERT)
 						{
-						str[0]=AN_STR_INV[h_ptr->v.h_val];
+						str[0]=AN_STR_INV[h_val];
 						}
 						else
 						{
-						str[0]=AN_STR[h_ptr->v.h_val];
+						str[0]=AN_STR[h_val];
 						}
 					*asciivalue=str;
 					vlen=font_engine_string_measure(GLOBALS->wavefont,str);
@@ -265,7 +296,7 @@ int num_info_rows = 2;
 char *flagged_name = NULL;
 char *alternate_name = NULL;
 int fh;
-char flag_string[9];
+char flag_string[65];
 char *tname = NULL;
 
 if(GLOBALS->disable_mouseover)
@@ -280,9 +311,8 @@ if(GLOBALS->disable_mouseover)
 
 fh = GLOBALS->wavefont->ascent+GLOBALS->wavefont->descent;
 
-if(t)
+if(t && (tname = get_fullname(t)))
 	{
-	tname = get_fullname(t);
 	local_trace_asciival(t, tname, tim, &nmaxlen, &vmaxlen, &asciivalue);
 
 	value_charlen = asciivalue ? strlen(asciivalue) : 0;
@@ -290,7 +320,7 @@ if(t)
 	name_charlen = tname ? strlen(tname) : 0;
 	if(name_charlen)
 		{
-		int len = determine_trace_flags(t->flags, flag_string);
+		int len = determine_trace_flags(t, flag_string);
 		flagged_name = malloc_2(name_charlen + 1 + len + 1);
 		memcpy(flagged_name, tname, name_charlen);
 		flagged_name[name_charlen] = ' ';
@@ -341,7 +371,7 @@ if(t)
 		}
 	}
 
-if((!t)||(yin<0)||(yin>GLOBALS->waveheight))
+if((!t)||(!tname)||(yin<0)||(yin>GLOBALS->waveheight))
 	{
 	if(GLOBALS->mouseover_mouseover_c_1)
 		{
@@ -413,8 +443,23 @@ if(tname) { free_2(tname); }
 }
 
 /*
- * $Id: mouseover_sigs.c,v 1.1 2008/12/09 00:36:42 gtkwave Exp $
+ * $Id: mouseover_sigs.c,v 1.6 2009/11/25 09:49:28 gtkwave Exp $
  * $Log: mouseover_sigs.c,v $
+ * Revision 1.6  2009/11/25 09:49:28  gtkwave
+ * added gray code support
+ *
+ * Revision 1.5  2009/09/14 03:00:08  gtkwave
+ * bluespec code integration
+ *
+ * Revision 1.4  2009/08/03 03:52:54  gtkwave
+ * fix bug with displaying sig type in mouseover on signalwindow
+ *
+ * Revision 1.3  2009/07/23 20:00:55  gtkwave
+ * added type info to signal window mouseover
+ *
+ * Revision 1.2  2009/06/25 22:12:30  gtkwave
+ * convert event impulses to strict 1/0 activity values regardless of val
+ *
  * Revision 1.1  2008/12/09 00:36:42  gtkwave
  * added mouseover support for signal window
  *
