@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 1999-2008. 
+ * Copyright (c) Tony Bybell 1999-2009. 
  *
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free
@@ -687,15 +687,21 @@ ps_MaxSignalLength (void)
 		    {
 		      if (!t->n.nd->ext)
 			{
+			  unsigned char h_val = h_ptr->v.h_val;
+			
+ 			  if(t->n.nd->vartype == ND_VCD_EVENT)
+				{
+				h_val = (h_ptr->time >= GLOBALS->tims.first) && ((GLOBALS->tims.marker-GLOBALS->shift_timebase) == h_ptr->time) ? AN_1 : AN_0; /* generate impulse */
+				}
 			  str = (char *) calloc_2 (1, 3 * sizeof (char));
 			  str[0] = '=';
 			  if (t->flags & TR_INVERT)
 			    {
-			      str[1] = AN_STR_INV[h_ptr->v.h_val];
+			      str[1] = AN_STR_INV[h_val];
 			    }
 			  else
 			    {
-			      str[1] = AN_STR[h_ptr->v.h_val];
+			      str[1] = AN_STR[h_val];
 			    }
 			  t->asciivalue = str;
 			  vlen =
@@ -1131,12 +1137,13 @@ pr_draw_hptr_trace (pr_context * prc, Trptr t, hptr h, int which, int dodraw,
   hptr h2, h3;
   char hval, h2val;
   char identifier_str[2];
+  int is_event = t && t->n.nd && (t->n.nd->vartype == ND_VCD_EVENT);
 
   GLOBALS->tims.start -= GLOBALS->shift_timebase;
   GLOBALS->tims.end -= GLOBALS->shift_timebase;
 
   liney = ((which + 2) * GLOBALS->fontheight) - 2;
-  if (t && (t->flags & TR_INVERT))
+  if ((t && (t->flags & TR_INVERT))&&(!is_event))
     {
       _y0 = ((which + 1) * GLOBALS->fontheight) + 2;
       _y1 = liney - 2;
@@ -1206,6 +1213,18 @@ pr_draw_hptr_trace (pr_context * prc, Trptr t, hptr h, int which, int dodraw,
 	  }
 	if (_x0 != _x1)
 	  {
+	    if(is_event)
+                {
+		if(h->time >= GLOBALS->tims.first)
+		  {
+                  pr_draw_line(prc, _x0, _y0, _x0, _y1);
+                  pr_draw_line(prc, _x0, _y1, _x0+2, _y1+2);
+                  pr_draw_line(prc, _x0, _y1, _x0-2, _y1+2);
+		  }
+                h=h->next;
+                continue;
+                }
+
 	    hval = h->v.h_val;
 	    h2val = h2->v.h_val;
 
@@ -1335,6 +1354,12 @@ pr_draw_hptr_trace (pr_context * prc, Trptr t, hptr h, int which, int dodraw,
 	else
 	  {
 	    pr_draw_line (prc, _x1, _y0, _x1, _y1);
+	    if(is_event)
+		{
+                  pr_draw_line(prc, _x0, _y1, _x0+2, _y1+2);
+                  pr_draw_line(prc, _x0, _y1, _x0-2, _y1+2);
+		}
+
 	    newtime = (((gdouble) (_x1 + WAVE_OPT_SKIP)) * GLOBALS->nspx) + GLOBALS->tims.start + GLOBALS->shift_timebase;	/* skip to next pixel */
 	    h3 = bsearch_node (t->n.nd, newtime);
 	    if (h3->time > h->time)
@@ -2868,8 +2893,17 @@ print_mif_image (FILE * wave, gdouble px, gdouble py)
 }
 
 /*
- * $Id: print.c,v 1.19 2008/12/31 22:20:12 gtkwave Exp $
+ * $Id: print.c,v 1.22 2009/06/26 19:56:18 gtkwave Exp $
  * $Log: print.c,v $
+ * Revision 1.22  2009/06/26 19:56:18  gtkwave
+ * add arrowheads to all impulse arrows
+ *
+ * Revision 1.21  2009/06/25 22:12:30  gtkwave
+ * convert event impulses to strict 1/0 activity values regardless of val
+ *
+ * Revision 1.20  2009/06/25 18:31:19  gtkwave
+ * added event types for VCD+FST and impulse arrows on event types
+ *
  * Revision 1.19  2008/12/31 22:20:12  gtkwave
  * adding more tcl commands
  *
