@@ -12,7 +12,7 @@
 #ifndef REGEX_WAVE_H
 #define REGEX_WAVE_H
 
-enum WaveRegexTypes { WAVE_REGEX_SEARCH, WAVE_REGEX_TREE, WAVE_REGEX_WILD, WAVE_REGEX_TOTAL };
+enum WaveRegexTypes { WAVE_REGEX_SEARCH, WAVE_REGEX_TREE, WAVE_REGEX_WILD, WAVE_REGEX_DND, WAVE_REGEX_TOTAL };
 
 int wave_regex_compile(char *regex, int which);
 int wave_regex_match(char *str, int which);
@@ -24,8 +24,11 @@ void wave_regex_alloc_free(void *pnt);
 #endif
 
 /*
- * $Id: regex_wave.h,v 1.2 2007/08/26 21:35:44 gtkwave Exp $
+ * $Id: regex_wave.h,v 1.3 2008/09/22 03:27:03 gtkwave Exp $
  * $Log: regex_wave.h,v $
+ * Revision 1.3  2008/09/22 03:27:03  gtkwave
+ * more DND adds
+ *
  * Revision 1.2  2007/08/26 21:35:44  gtkwave
  * integrated global context management from SystemOfCode2007 branch
  *
