@@ -333,6 +333,7 @@ for(i=0;i<GLOBALS->num_rows_search_c_2;i++)
 			{
 			len=0;
 			t=s->vec_root;
+			t->selected = 1; /* move selected to head */
 			while(t)
 				{
 				if(t->selected)
@@ -653,6 +654,7 @@ while(symc)
 	free_2(symc_current);
 	}
 
+GLOBALS->traces.scroll_top = GLOBALS->traces.scroll_bottom = GLOBALS->traces.last;
 MaxSignalLength();
 signalarea_configure_event(GLOBALS->signalarea, NULL);
 wavearea_configure_event(GLOBALS->wavearea, NULL);
@@ -823,6 +825,7 @@ if((!GLOBALS->is_insert_running_search_c_1)&&(!GLOBALS->is_replace_running_searc
   	GLOBALS->is_active_search_c_4=0;
   	gtk_widget_destroy(GLOBALS->window_search_c_7);
 	GLOBALS->window_search_c_7 = NULL;
+	GLOBALS->clist_search_c_3 = NULL;
 	}
 }
 
@@ -950,7 +953,7 @@ void searchbox(char *title, GtkSignalFunc func)
     gtk_widget_show (GLOBALS->clist_search_c_3);
 
 #if WAVE_USE_GTK2
-    dnd_setup(GLOBALS->clist_search_c_3, GLOBALS->signalarea);
+    dnd_setup(GLOBALS->clist_search_c_3, GLOBALS->signalarea, 0);
 #endif
 
     scrolled_win = gtk_scrolled_window_new (NULL, NULL);
@@ -1106,8 +1109,20 @@ void searchbox(char *title, GtkSignalFunc func)
 }
 
 /*
- * $Id: search.c,v 1.9 2008/07/18 17:27:01 gtkwave Exp $
+ * $Id: search.c,v 1.13 2008/12/18 01:31:30 gtkwave Exp $
  * $Log: search.c,v $
+ * Revision 1.13  2008/12/18 01:31:30  gtkwave
+ * integrated experimental autoscroll code on signal adds
+ *
+ * Revision 1.12  2008/09/24 15:37:38  gtkwave
+ * move "selected" to top bit on blasted vector selection w/coalesce
+ *
+ * Revision 1.11  2008/09/24 02:22:49  gtkwave
+ * added (commented out) prelim support for dragging names from viewer
+ *
+ * Revision 1.10  2008/09/16 00:01:26  gtkwave
+ * prelim drag and drop from external apps (now disabled)
+ *
  * Revision 1.9  2008/07/18 17:27:01  gtkwave
  * adding hierpack code
  *
