@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2008.
+ * Copyright (c) Tony Bybell 1999-2009.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -39,7 +39,7 @@ if(GLOBALS->signalpixmap)
 	xsrc=(gint)hadj->value;
 	DEBUG(printf("Signal HSlider Moved to %d\n",xsrc));
 
-	gdk_draw_rectangle(GLOBALS->signalpixmap, GLOBALS->gc_dkgray, TRUE,
+	gdk_draw_rectangle(GLOBALS->signalpixmap, GLOBALS->gc_mdgray, TRUE,
 	        0, -1, GLOBALS->signal_fill_width, GLOBALS->fontheight);
 	gdk_draw_line(GLOBALS->signalpixmap, GLOBALS->gc_white,  
 	        0, GLOBALS->fontheight-1, GLOBALS->signal_fill_width-1, GLOBALS->fontheight-1);
@@ -81,8 +81,6 @@ static void DNDBeginCB(
         GtkWidget *widget, GdkDragContext *dc, gpointer data
 )
 {
-if((widget == NULL) || (dc == NULL))
-	return;
 
 GLOBALS->dnd_state = 1;
 }
@@ -144,7 +142,11 @@ if(GLOBALS->std_dnd_tgt_on_signalarea || GLOBALS->std_dnd_tgt_on_wavearea)
 	                {
 	                break;
 	                }
-	        }       
+	        }
+
+	while(t->t_next && IsGroupEnd(t->t_next) && IsCollapsed(t->t_next)) {
+	  t = t->t_next;
+	}
         
         GLOBALS->cachedtrace=t;
         if(GLOBALS->cachedtrace)
@@ -309,21 +311,25 @@ if(GLOBALS->std_dnd_tgt_on_signalarea || GLOBALS->std_dnd_tgt_on_wavearea)
 	                }
 	        }       
 
-	if(t)
-		{
-		while(t)
-			{
-			if(t->flags & TR_HIGHLIGHT)
-				{
-				t=GivePrevTrace(t);
-				which--;
-				}
-				else
-				{
-				break;
-				}
-			}
-		}
+	while(t && t->t_next && IsGroupEnd(t->t_next) && IsCollapsed(t->t_next)) {
+	  t = t->t_next;
+	}
+
+/* 	if(t) */
+/* 		{ */
+/* 		while(t) */
+/* 			{ */
+/* 			if(t->flags & TR_HIGHLIGHT) */
+/* 				{ */
+/* 				t=GivePrevTrace(t); */
+/* 				which--; */
+/* 				} */
+/* 				else */
+/* 				{ */
+/* 				break; */
+/* 				} */
+/* 			} */
+/* 		} */
 
 	if(1)
 		{
@@ -378,6 +384,20 @@ if(GLOBALS->std_dnd_tgt_on_signalarea || GLOBALS->std_dnd_tgt_on_wavearea)
 	return(FALSE);
 }
 
+static gboolean ignoreAccelerators(GdkEventKey *event)
+{
+if(!GLOBALS || !GLOBALS->filter_entry || !event)
+	{
+	return(FALSE);
+	}
+	else
+	{
+	return (GTK_WIDGET_HAS_FOCUS(GLOBALS->filter_entry) && 
+	  !(event->state & GDK_CONTROL_MASK) &&
+	  !(event->state & GDK_MOD1_MASK));
+	}
+}
+
 /*
  * keypress processing, return TRUE to block the event from gtk
  */
@@ -395,13 +415,6 @@ printf("focus: %d %08x %08x %08x\n", GTK_WIDGET_HAS_FOCUS(GLOBALS->signalarea_ev
 	GLOBALS->signalarea_event_box, widget, data);
 #endif
 
-if(GLOBALS->signalarea_event_box != data)
-	{
-#ifdef FOCUS_DEBUG_MSGS
-	printf("wrong session\n");
-#endif
-	}
-else
 if(GTK_WIDGET_HAS_FOCUS(GLOBALS->signalarea_event_box))
 	{
 	switch(event->keyval)
@@ -512,52 +525,57 @@ if(GTK_WIDGET_HAS_FOCUS(GLOBALS->signalarea_event_box))
 else
 if(GLOBALS->dnd_sigview)
 	{
-	if(GTK_WIDGET_HAS_FOCUS(GLOBALS->dnd_sigview) || GTK_WIDGET_HAS_FOCUS(GLOBALS->filter_entry))
+	  if(GTK_WIDGET_HAS_FOCUS(GLOBALS->dnd_sigview) || GTK_WIDGET_HAS_FOCUS(GLOBALS->filter_entry))
+	    {
+	      switch(event->keyval)
 		{
-		switch(event->keyval)
-			{
-			case GDK_a:
-				if(event->state & GDK_CONTROL_MASK)
-					{
-					treeview_select_all_callback();
-					rc = TRUE;
-					}
-				break;
+		case GDK_a:
+		  if(event->state & GDK_CONTROL_MASK)
+		    {
+		      treeview_select_all_callback();
+		      rc = TRUE;
+		    }
+		  break;
 
-			case GDK_A:
-				if(event->state & GDK_CONTROL_MASK)
-					{
-					treeview_unselect_all_callback();
-					rc = TRUE;
-					}
-			default:
-				break;
-			}
+		case GDK_A:
+		  if(event->state & GDK_CONTROL_MASK)
+		    {
+		      treeview_unselect_all_callback();
+		      rc = TRUE;
+		    }
+		default:
+		  break;
 		}
+	    }
 	else
-	if(GTK_WIDGET_HAS_FOCUS(GLOBALS->tree_treesearch_gtk2_c_1))
+	  if(GTK_WIDGET_HAS_FOCUS(GLOBALS->tree_treesearch_gtk2_c_1))
+	    {
+	      switch(event->keyval)
 		{
-		switch(event->keyval)
-			{
-			case GDK_a:
-				if(event->state & GDK_CONTROL_MASK)
-					{
-					/* eat keystroke */
-					rc = TRUE;
-					}
-				break;
+		case GDK_a:
+		  if(event->state & GDK_CONTROL_MASK)
+		    {
+		      /* eat keystroke */
+		      rc = TRUE;
+		    }
+		  break;
 
-			case GDK_A:
-				if(event->state & GDK_CONTROL_MASK)
-					{
-					/* eat keystroke */
-					rc = TRUE;
-					}
-			default:
-				break;
-			}
+		case GDK_A:
+		  if(event->state & GDK_CONTROL_MASK)
+		    {
+		      /* eat keystroke */
+		      rc = TRUE;
+		    }
+		default:
+		  break;
 		}
+	    }
 	}
+ if (ignoreAccelerators(event)) {
+   gtk_widget_event(GLOBALS->filter_entry, (GdkEvent *)event);
+   /* eat keystroke */
+   rc = TRUE; 
+ }
 
 return(rc);
 }
@@ -600,12 +618,22 @@ GdkEventMotion event[1];
 event[0].deviceid = GDK_CORE_POINTER;  
 #endif
 
+if(GLOBALS->loaded_file_type == MISSING_FILE)
+	{
+	return(TRUE);
+	}
+
 if(run_once == FALSE) /* avoid any race conditions with the toolkit for uninitialized data */
 	{
 	run_once = TRUE;
 	return(TRUE);
 	}
 
+if((!GLOBALS) || (!GLOBALS->signalarea) || (!GLOBALS->signalarea->window))                 
+	{
+	return(TRUE);
+	}
+
 if(GLOBALS->dnd_cursor_timer)
 	{
 	GLOBALS->dnd_cursor_timer++;
@@ -617,7 +645,7 @@ if(GLOBALS->dnd_cursor_timer)
 	}
 
 if(GLOBALS->mouseover_counter < 0) return(TRUE); /* mouseover is up in wave window so don't bother */
-                 
+
 WAVE_GDK_GET_POINTER(GLOBALS->signalarea->window, &x, &y, &xi, &yi, &state);
 WAVE_GDK_GET_POINTER_COPY;
 
@@ -741,6 +769,18 @@ Trptr t, t2;
 
 if(GLOBALS->signalarea_event_box)
 	{
+
+	  /* Don't mess with highlights with button 2 (save for dnd) */
+	  if((event->button == 2) && (event->type == GDK_BUTTON_PRESS))
+	    {
+	      return(TRUE);
+	    }
+
+	  /* Don't mess with highlights with button 3 (save for menu_check) */
+	  if((event->button == 3) && (event->type == GDK_BUTTON_PRESS))
+	    {
+	      goto menu_chk;
+	    }
 	if((event->x<0)||(event->x>=widget->allocation.width)||(event->y<0)||(event->y>=widget->allocation.height))
 		{
 		/* let gtk take focus from us with focus out event */
@@ -772,13 +812,15 @@ if((GLOBALS->traces.visible)&&(GLOBALS->signalpixmap))
 			}
 			else
 			{
-			goto menu_chk; /* off in no man's land */
+			  ClearTraces();
+			  goto redraw; /* off in no man's land */
 			}
 		}
 
 	if((which>=num_traces_displayable)||(which<0))
 		{
-		goto menu_chk; /* off in no man's land */
+		  ClearTraces();
+		  goto redraw; /* off in no man's land */
 		}
 
 	wadj=GTK_ADJUSTMENT(GLOBALS->wave_vslider);
@@ -799,26 +841,20 @@ if((GLOBALS->traces.visible)&&(GLOBALS->signalpixmap))
 	                }
 	        }
 
-	if((event->state&(GDK_CONTROL_MASK|GDK_SHIFT_MASK)) == (GDK_CONTROL_MASK|GDK_SHIFT_MASK))
-		{
-		/* frankel add */
-		if(t)
-			{
-			if((!GLOBALS->std_collapse_pressed) && CollapseTrace(t))
-				{
-				GLOBALS->signalwindow_width_dirty=1;
-	        		MaxSignalLength();
-	        		signalarea_configure_event(GLOBALS->signalarea, NULL);
-	        		wavearea_configure_event(GLOBALS->wavearea, NULL);
-				GLOBALS->std_collapse_pressed = 1;
-				}
-			goto menu_chk;
-			}
-		}
-
 	if(event->state&GDK_CONTROL_MASK)
 		{
-		t->flags ^= TR_HIGHLIGHT;
+		  if(IsGroupBegin(t) && IsSelected(t))
+		    {
+		      ClearGroupTraces(t);
+		    }
+		  else if(IsGroupEnd(t) && IsSelected(t))
+		    {
+		      ClearGroupTraces(t->t_match);
+		    }
+		  else
+		    {
+		      t->flags ^= TR_HIGHLIGHT;
+		    }
 		}
 	else
 	if((event->state&GDK_SHIFT_MASK)&&(GLOBALS->starting_unshifted_trace))
@@ -834,22 +870,33 @@ if((GLOBALS->traces.visible)&&(GLOBALS->signalpixmap))
 
 			cnt++;
 
-			t2->flags &= ~TR_HIGHLIGHT;
+			/*			t2->flags &= ~TR_HIGHLIGHT; */
 			t2 = t2->t_next;
 			}
 
 		if(src != -1)
 			{
-			int cpy;
+			  cnt = 0;
+			  t2=GLOBALS->traces.first;
+			  while(t2)
+				{
+				  if ((cnt == src) && (cnt == dst) && IsSelected(t2))
+				    {
+				      GLOBALS->starting_unshifted_trace = NULL;
+				    }
+				  t2->flags &= ~TR_HIGHLIGHT;
+				  t2=t2->t_next;
+				  cnt++;
+				}
 
-			if(src > dst) { cpy = src; src = dst; dst = cpy; }
+			if(src > dst) { int cpy; cpy = src; src = dst; dst = cpy; }
 			cnt = 0;
 			t2=GLOBALS->traces.first;
-			while(t2)
+			while(t2 && GLOBALS->starting_unshifted_trace)
 				{
 				if((cnt >= src) && (cnt <= dst))
 					{
-					t2->flags |= TR_HIGHLIGHT;
+					  t2->flags |= TR_HIGHLIGHT;
 					}
 
 				cnt++;
@@ -862,7 +909,8 @@ if((GLOBALS->traces.visible)&&(GLOBALS->signalpixmap))
 			t->flags |= TR_HIGHLIGHT;
 			}
 		}
-	else if(!(t->flags & TR_HIGHLIGHT)) /* Ben Sferrazza suggested fix rather than a regular "else" */
+	/*	else if(!(t->flags & TR_HIGHLIGHT)) Ben Sferrazza suggested fix rather than a regular "else" */
+else
 		{
 		GLOBALS->starting_unshifted_trace = t;
 
@@ -876,6 +924,13 @@ if((GLOBALS->traces.visible)&&(GLOBALS->signalpixmap))
 		t->flags |= TR_HIGHLIGHT;
 		}
 
+	if(event->type == GDK_2BUTTON_PRESS)
+	  {
+	    menu_toggle_group(widget, NULL);
+	    goto menu_chk;
+	  }
+
+	redraw:
 
 	GLOBALS->signalwindow_width_dirty=1;
         MaxSignalLength();
@@ -898,403 +953,10 @@ return(TRUE);
 
 
 /**************************************************************************/
-/***  gtkwave click routines turned on with "use_standard_clicking"=0   ***/
-
-static gint motion_notify_event(GtkWidget *widget, GdkEventMotion *event)
-{
-int num_traces_displayable;
-int which;
-int trwhich, trtarget;
-int new_cachedwhich;
-GtkAdjustment *wadj;
-Trptr t;
-gdouble x,y;
-GdkModifierType state;
-int doloop;
-
-#ifdef WAVE_USE_GTK2
-gint xi, yi;
-#endif
-
-if(event->is_hint)
-	{
-	WAVE_GDK_GET_POINTER(event->window, &x, &y, &xi, &yi, &state);
-	WAVE_GDK_GET_POINTER_COPY;
-	}
-	else
-	{
-	x = event->x;
-	y = event->y;
-	state = event->state;
-	}
-
-top: doloop=0;
-
-/********************* button 1 *********************/
-
-if((GLOBALS->traces.visible)&&(state&(GDK_BUTTON1_MASK|GDK_BUTTON3_MASK))&&(GLOBALS->signalpixmap)&&(GLOBALS->cachedwhich_signalwindow_c_1!=-1))
-	{
-	num_traces_displayable=widget->allocation.height/(GLOBALS->fontheight);
-	num_traces_displayable--;   /* for the time trace that is always there */
-
-	which=(int)(y);
-	which=(which/GLOBALS->fontheight)-1;
-
-	if(which>=GLOBALS->traces.visible)
-		{
-		which=GLOBALS->traces.visible-1;
-		}
-
-
-	wadj=GTK_ADJUSTMENT(GLOBALS->wave_vslider);
-
-	if(num_traces_displayable<GLOBALS->traces.visible)
-		{
-		if(which>=num_traces_displayable)
-			{
-			int target;
-
-			target=((int)wadj->value)+1;
-			which=num_traces_displayable-1;
-
-			if(target+which>=(GLOBALS->traces.visible-1)) target=GLOBALS->traces.visible-which-1;
-			wadj->value=target;
-
-			if(GLOBALS->cachedwhich_signalwindow_c_1==which) GLOBALS->cachedwhich_signalwindow_c_1=which-1; /* force update */
-
-			gtk_signal_emit_by_name (GTK_OBJECT (wadj), "changed");	/* force bar update */
-			gtk_signal_emit_by_name (GTK_OBJECT (wadj), "value_changed"); /* force text update */
-	
-			doloop=1;
-			}
-			else
-			if (which<0)
-			{
-			int target;
-	
-			target=((int)wadj->value)-1;
-			if(target<0) target=0;
-			wadj->value=target;
-	
-			which=0;
-			if(GLOBALS->cachedwhich_signalwindow_c_1==which) GLOBALS->cachedwhich_signalwindow_c_1=-1; /* force update */
-	
-			gtk_signal_emit_by_name (GTK_OBJECT (wadj), "changed");	/* force bar update */
-			gtk_signal_emit_by_name (GTK_OBJECT (wadj), "value_changed"); /* force text update */
-	
-			doloop=1;
-			}
-		}
-		else
-		{
-		if(which<0) which=0;
-		}
-
-	trtarget=((int)wadj->value)+which;
-
-	GLOBALS->cachedtrace=t=GLOBALS->traces.first;
-	trwhich=0;
-	while(t)
-	        {
-	        if((trwhich<trtarget)&&(GiveNextTrace(t)))
-	                {
-	                trwhich++;
-	                t=GiveNextTrace(t);
-	                }
-	                else
-	                {
-	                break;
-	                }
-	        }
-
-	GLOBALS->cachedtrace=t;
-
-	if((GLOBALS->dnd_state==1)&&(state&GDK_BUTTON3_MASK))
-		{
-		GtkAdjustment *hadj;
-		gint xsrc;
-		int yval;
-
-		hadj=GTK_ADJUSTMENT(GLOBALS->signal_hslider);
-		wadj=GTK_ADJUSTMENT(GLOBALS->wave_vslider);
-		gtk_signal_emit_by_name (GTK_OBJECT (wadj), "changed");	/* force bar update */
-		gtk_signal_emit_by_name (GTK_OBJECT (wadj), "value_changed"); /* force text update */
-
-		xsrc=(gint)hadj->value;
-
-		yval=RenderSig(t, which, 2);
-        	gdk_draw_pixmap(GLOBALS->signalarea->window, GLOBALS->signalarea->style->fg_gc[GTK_WIDGET_STATE(GLOBALS->signalarea)],GLOBALS->signalpixmap,xsrc, yval,0, yval,GLOBALS->signalarea->allocation.width, GLOBALS->fontheight-1);
-		}
-	else
-	if((state&GDK_BUTTON1_MASK)&&(GLOBALS->dnd_state==0))
-	if((t)&&(which!=GLOBALS->cachedwhich_signalwindow_c_1))
-		{
-		GtkAdjustment *hadj;
-		gint xsrc;
-
-		hadj=GTK_ADJUSTMENT(GLOBALS->signal_hslider);
-		xsrc=(gint)hadj->value;
-
-		new_cachedwhich=which;	/* save so fill ins go from deltas in the future */
-		
-		do {
-		int oldflags;
-
-		oldflags = t->flags;
-
-		t->flags = (t->flags & (~TR_HIGHLIGHT)) | GLOBALS->cachedhiflag_signalwindow_c_1;
-
-		if(oldflags!=t->flags)
-			{
-			int yval;
-			DEBUG(printf("Motion highlight swap in signalarea at x: %d, y: %d row: %d\n",
-				(int)x, (int)y, which));
-
-			yval=RenderSig(t, which, 1);
-        		gdk_draw_pixmap(GLOBALS->signalarea->window, GLOBALS->signalarea->style->fg_gc[GTK_WIDGET_STATE(GLOBALS->signalarea)],GLOBALS->signalpixmap,xsrc, yval,0, yval,GLOBALS->signalarea->allocation.width, GLOBALS->fontheight-1);
-			}
-
-		if(which>GLOBALS->cachedwhich_signalwindow_c_1)
-			{
-			which--;
-			t=GivePrevTrace(t);
-			}
-		else if(which<GLOBALS->cachedwhich_signalwindow_c_1)
-			{
-			which++;
-			t=GiveNextTrace(t);
-			}
-
-		} while((which!=GLOBALS->cachedwhich_signalwindow_c_1)&&(t));
-
-		GLOBALS->cachedwhich_signalwindow_c_1=new_cachedwhich;	/* for next time around */
-		}
-	}
-
-if(doloop)
-	{
-	WAVE_GDK_GET_POINTER(event->window, &x, &y, &xi, &yi, &state);
-	WAVE_GDK_GET_POINTER_COPY;
-	goto top;
-	}
-
-return(TRUE);
-}
-
-
-static gint button_release_event(GtkWidget *widget, GdkEventButton *event)
-{
-int which;
-
-if(event->button==1)
-	{
-	if(GLOBALS->dnd_state==0) GLOBALS->cachedwhich_signalwindow_c_1=-1;
-	gdk_pointer_ungrab(event->time);
-	DEBUG(printf("Button 1 released\n"));
-	}
-
-/********************* button 3 *********************/
-
-if((event->button==3)&&(GLOBALS->signalpixmap))
-	{
-	GLOBALS->cachedwhich_signalwindow_c_1=-1;
-	gdk_pointer_ungrab(event->time);
-	DEBUG(printf("Button 3 released\n"));
-
-	if(GLOBALS->dnd_state==1)
-		{
-		if(GLOBALS->cachedtrace)
-			{
-			GLOBALS->cachedtrace->flags|=TR_HIGHLIGHT;
-			}
-
-		which=(int)(event->y);
-		which=(which/GLOBALS->fontheight)-1;
-	
-		if( ((which<0) && (GLOBALS->topmost_trace==GLOBALS->traces.first) && PrependBuffer()) || (PasteBuffer()) ) /* short circuit on special which<0 case */
-	       		{
-			/* status_text("Drop completed.\n"); */
-
-			GLOBALS->signalwindow_width_dirty=1;
-        		MaxSignalLength();
-        		signalarea_configure_event(GLOBALS->signalarea, NULL);
-        		wavearea_configure_event(GLOBALS->wavearea, NULL);
-        		}
-		GLOBALS->dnd_state=0;
-		}
-	}
-
-/********************* button 3 *********************/
-
-return(TRUE);
-}
-
-static gint button_press_event(GtkWidget *widget, GdkEventButton *event)
-{
-int num_traces_displayable;
-int which;
-int trwhich, trtarget;
-GtkAdjustment *wadj;
-Trptr t;
-
-if((GLOBALS->traces.visible)&&(GLOBALS->signalpixmap))
-	{
-	gdk_pointer_grab(widget->window, FALSE,
-		GDK_POINTER_MOTION_HINT_MASK | GDK_BUTTON1_MOTION_MASK | GDK_BUTTON3_MOTION_MASK | 
-		GDK_BUTTON_RELEASE_MASK, NULL, NULL, event->time);
-
-	num_traces_displayable=widget->allocation.height/(GLOBALS->fontheight);
-	num_traces_displayable--;   /* for the time trace that is always there */
-
-	which=(int)(event->y);
-	which=(which/GLOBALS->fontheight)-1;
-
-	if((which>=GLOBALS->traces.visible)||(which>=num_traces_displayable)||(which<0))
-		{
-		if(GLOBALS->dnd_state==0)GLOBALS->cachedwhich_signalwindow_c_1=-1;
-		goto check_button_3;	/* off in no man's land, but check 3rd anyways.. */
-		}
-
-	GLOBALS->cachedwhich_signalwindow_c_1=which;	/* cache for later fill in */
-	wadj=GTK_ADJUSTMENT(GLOBALS->wave_vslider);
-	trtarget=((int)wadj->value)+which;
-
-	t=GLOBALS->traces.first;
-	trwhich=0;
-	while(t)
-	        {
-	        if((trwhich<trtarget)&&(GiveNextTrace(t)))
-	                {
-	                trwhich++;
-	                t=GiveNextTrace(t);
-	                }
-	                else
-	                {
-	                break;
-	                }
-	        }
-
-	GLOBALS->cachedtrace=t;
-
-	/* frankel add */
-	if((event->state&GDK_CONTROL_MASK)&&(GLOBALS->dnd_state==0)&&(event->button==1))
-	if(t)
-		{
-		if(CollapseTrace(t))
-			{
-			GLOBALS->signalwindow_width_dirty=1;
-        		MaxSignalLength();
-        		signalarea_configure_event(GLOBALS->signalarea, NULL);
-        		wavearea_configure_event(GLOBALS->wavearea, NULL);
-			return(TRUE);
-			}
-		}
-
-	if((GLOBALS->dnd_state==0)&&(event->button==1))
-	if(t)
-		{
-		int yval;
-		GtkAdjustment *hadj;
-		gint xsrc;
-
-		if((GLOBALS->shift_click_trace)&&(event->state&GDK_SHIFT_MASK))
-			{
-			Trptr t2;
-			unsigned int f;
-
-			t2=GLOBALS->shift_click_trace;
-			while(t2)
-				{
-				if(t2==t)
-					{
-					t2=GLOBALS->shift_click_trace;
-					f=t2->flags&TR_HIGHLIGHT;
-					while(t2)
-						{
-						t2->flags = (t2->flags & (~TR_HIGHLIGHT)) | f;
-						if(t2==t) break;
-						t2=GivePrevTrace(t2);
-						}					
-					goto resync_signalarea;
-					}
-				t2=GivePrevTrace(t2);
-				}
-
-			t2=GLOBALS->shift_click_trace;
-			while(t2)
-				{
-				if(t2==t)
-					{
-					t2=GLOBALS->shift_click_trace;
-					f=t2->flags&TR_HIGHLIGHT;
-					while(t2)
-						{
-						t2->flags = (t2->flags & (~TR_HIGHLIGHT)) | f;
-						if(t2==t) break;
-						t2=GiveNextTrace(t2);
-						}					
-					goto resync_signalarea;
-					}
-				t2=GiveNextTrace(t2);
-				}
-
-			goto normal_button1_press;	/* couldn't find original so make this original... */
-			
-			resync_signalarea:
-        		MaxSignalLength();
-        		signalarea_configure_event(GLOBALS->signalarea, NULL);
-			DEBUG(printf("Shift-Click in signalarea!\n"));
-			return(TRUE);
-			}
-			else
-			{
-			normal_button1_press:
-			hadj=GTK_ADJUSTMENT(GLOBALS->signal_hslider);
-			xsrc=(gint)hadj->value;
-
-			GLOBALS->shift_click_trace=t;
-			t->flags ^= TR_HIGHLIGHT;
-			GLOBALS->cachedhiflag_signalwindow_c_1 = t->flags & TR_HIGHLIGHT;
-
-			DEBUG(printf("Button pressed in signalarea at x: %d, y: %d row: %d\n",
-				(int)event->x, (int)event->y, which));
-
-			yval=RenderSig(t, which, 1);
-	        	gdk_draw_pixmap(GLOBALS->signalarea->window, GLOBALS->signalarea->style->fg_gc[GTK_WIDGET_STATE(GLOBALS->signalarea)],GLOBALS->signalpixmap,xsrc, yval,0, yval,GLOBALS->signalarea->allocation.width, GLOBALS->fontheight-1);
-			}
-		}
-
-check_button_3:
-	if(event->button==3)
-		{
-		if(GLOBALS->dnd_state==0)
-			{
-			if(CutBuffer())
-	        		{
-				/* char buf[32]; */
-				/* sprintf(buf,"Dragging %d trace%s.\n",traces.buffercount,traces.buffercount!=1?"s":"");
-				status_text(buf); */
-	        		MaxSignalLength();
-	        		signalarea_configure_event(GLOBALS->signalarea, NULL);
-	        		wavearea_configure_event(GLOBALS->wavearea, NULL);
-				GLOBALS->dnd_state=1;
-				}
-			}
-		}
-	}
-
-return(TRUE);
-}
-
-
-/*
-static gint popup_event (GtkWidget *widget)
-{
-do_popup_menu(widget, NULL);
-return(TRUE);
-}
-*/
-
+/***  standard click routines turned on with "use_standard_clicking"=0  ***/
+/***                                                                    ***/
+/***                        no longer supported                         ***/
+/***                                                                    ***/
 /***  gtkwave click routines turned on with "use_standard_clicking"=0   ***/
 /**************************************************************************/
 
@@ -1313,6 +975,7 @@ UpdateTracesVisible();
 num_traces_displayable=widget->allocation.height/(GLOBALS->fontheight);
 num_traces_displayable--;   /* for the time trace that is always there */
 
+
 DEBUG(printf("SigWin Configure Event h: %d, w: %d\n",
 		widget->allocation.height,
 		widget->allocation.width));
@@ -1544,6 +1207,7 @@ gtk_widget_set_events(GLOBALS->signalarea,
 gtk_signal_connect(GTK_OBJECT(GLOBALS->signalarea), "configure_event", GTK_SIGNAL_FUNC(signalarea_configure_event_local), NULL);
 gtk_signal_connect(GTK_OBJECT(GLOBALS->signalarea), "expose_event",GTK_SIGNAL_FUNC(expose_event_local), NULL);
 
+sclick:
 if(GLOBALS->use_standard_clicking)
 	{
 	GtkTargetEntry target_entry[3];
@@ -1602,9 +1266,10 @@ if(GLOBALS->use_standard_clicking)
 	}
 	else
 	{
-	gtkwave_signal_connect(GTK_OBJECT(GLOBALS->signalarea), "button_press_event",GTK_SIGNAL_FUNC(button_press_event), NULL);
-	gtkwave_signal_connect(GTK_OBJECT(GLOBALS->signalarea), "button_release_event", GTK_SIGNAL_FUNC(button_release_event), NULL);
-	gtkwave_signal_connect(GTK_OBJECT(GLOBALS->signalarea), "motion_notify_event",GTK_SIGNAL_FUNC(motion_notify_event), NULL);
+	fprintf(stderr, "GTKWAVE | \"use_standard_clicking off\" has been removed.\n");
+	fprintf(stderr, "GTKWAVE | Please update your rc files accordingly.\n");
+	GLOBALS->use_standard_clicking = 1;
+	goto sclick;
 	}
 
 gtk_table_attach (GTK_TABLE (table), GLOBALS->signalarea, 0, 10, 0, 9,
@@ -1639,11 +1304,10 @@ if(do_focusing)
 
 	if(!GLOBALS->second_page_created)
 		{
-		GLOBALS->keypress_handler_id = install_keypress_handler();
-		}
-		else
-		{
-		GLOBALS->keypress_handler_id = 0;
+	        if(!GLOBALS->keypress_handler_id)
+	                {
+			GLOBALS->keypress_handler_id = install_keypress_handler();
+	                }
 		}
 
 	return(GLOBALS->signalarea_event_box);
@@ -1659,7 +1323,7 @@ gint install_keypress_handler(void)
 {
 gint rc = 
 	gtk_signal_connect(GTK_OBJECT(GLOBALS->mainwindow), 
-	"key_press_event",GTK_SIGNAL_FUNC(keypress_local), GLOBALS->signalarea_event_box);
+	"key_press_event",GTK_SIGNAL_FUNC(keypress_local), NULL);
 
 return(rc);
 }
@@ -1672,8 +1336,32 @@ gtk_signal_disconnect(GTK_OBJECT(GLOBALS->mainwindow), id);
 
 
 /*
- * $Id: signalwindow.c,v 1.40 2008/12/25 03:21:57 gtkwave Exp $
+ * $Id: signalwindow.c,v 1.48 2009/12/24 20:55:27 gtkwave Exp $
  * $Log: signalwindow.c,v $
+ * Revision 1.48  2009/12/24 20:55:27  gtkwave
+ * warnings cleanups
+ *
+ * Revision 1.47  2009/10/30 18:05:51  gtkwave
+ * removed use_standard_clicking off click semantics
+ *
+ * Revision 1.46  2009/10/24 01:51:41  gtkwave
+ * added dynamic loading for tcl/tk via --enable-stubify
+ *
+ * Revision 1.45  2009/09/27 23:46:53  gtkwave
+ * crash fix on DnD drop
+ *
+ * Revision 1.44  2009/09/14 03:00:08  gtkwave
+ * bluespec code integration
+ *
+ * Revision 1.43  2009/04/09 22:17:21  gtkwave
+ * install_keypress_handler() fixes
+ *
+ * Revision 1.42  2009/03/27 04:58:14  gtkwave
+ * enable splash screen during empty gui handling / load dumpfile
+ *
+ * Revision 1.41  2009/03/24 21:31:34  gtkwave
+ * changed dkgray to mdgray for "Time" background as intensity changed
+ *
  * Revision 1.40  2008/12/25 03:21:57  gtkwave
  * -Wshadow warning fixes
  *
