@@ -46,7 +46,7 @@ void simplereqbox(char *title, int width, char *default_text,
 
     GLOBALS->cleanup=WAVE_GTK_SFUNCAST(func);
 
-    if(GLOBALS->script_handle)
+    if(GLOBALS->wave_script_args)
 	{
 	if(GLOBALS->cleanup)GLOBALS->cleanup(NULL,(gpointer)1);
 	return;
@@ -112,8 +112,11 @@ void simplereqbox(char *title, int width, char *default_text,
 }
 
 /*
- * $Id: simplereq.c,v 1.5 2008/11/14 19:01:28 gtkwave Exp $
+ * $Id: simplereq.c,v 1.6 2009/12/15 23:40:59 gtkwave Exp $
  * $Log: simplereq.c,v $
+ * Revision 1.6  2009/12/15 23:40:59  gtkwave
+ * removed old style scripts; also removed tempfiles for Tcl args
+ *
  * Revision 1.5  2008/11/14 19:01:28  gtkwave
  * updated simplereq so the window is transient
  *
