@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2007.
+ * Copyright (c) Tony Bybell 1999-2009.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -729,33 +729,33 @@ while(s)
 				
 			case ST_HIGH:
 				totaltraces++;
-				if((str[0]=='1')||(str[0]=='H')) s->search_result=1;	
+				if((str[0]=='1')||(str[0]=='h')||(str[0]=='H')) s->search_result=1;	
 				break;
 
 			case ST_RISE:
-				if((str[0]=='1')||(str[0]=='H')) s->search_result=1;	
+				if((str[0]=='1')||(str[0]=='h')||(str[0]=='H')) s->search_result=1;	
 				totaltraces++;
 				break;
 
 			case ST_LOW:
 				totaltraces++;
-				if((str[0]=='0')||(str[0]=='L')) s->search_result=1;
+				if((str[0]=='0')||(str[0]=='l')||(str[0]=='L')) s->search_result=1;
 				break;
 
 			case ST_FALL:
 				totaltraces++;
-				if((str[0]=='0')||(str[0]=='L')) s->search_result=1;
+				if((str[0]=='0')||(str[0]=='l')||(str[0]=='L')) s->search_result=1;
 				break;
 
 			case ST_MID:
 				totaltraces++;
-				if(str[0]=='Z')
+				if((str[0]=='z')||(str[0]=='Z'))
  					s->search_result=1;
 				break;				
 
 			case ST_X:
 				totaltraces++;
-				if(str[0]=='X') s->search_result=1;
+				if((str[0]=='x')||(str[0]=='X')) s->search_result=1;
 				break;
 
 			case ST_ANY:
@@ -835,7 +835,7 @@ while(s)
 				if((chval2=chval))
 				while((ch=*(chval2++)))
 					{
-					if(((ch>='1')&&(ch<='9'))||(ch=='H')||((ch>='A')&&(ch<='F')))
+					if(((ch>='1')&&(ch<='9'))||(ch=='h')||(ch=='H')||((ch>='A')&&(ch<='F')))
 						{
 						s->search_result=1;
 						break;
@@ -850,7 +850,7 @@ while(s)
 				s->search_result=1;
 				while((ch=*(chval2++)))
 					{
-					if((ch!='0')&&(ch!='L'))
+					if((ch!='0')&&(ch!='l')&&(ch!='L'))
 						{
 						s->search_result=0;
 						break;
@@ -866,7 +866,7 @@ while(s)
 				s->search_result=1;
 				while((ch=*(chval2++)))
 					{
-					if(ch!='Z')
+					if((ch!='z')&&(ch!='Z'))
 						{
 						s->search_result=0;
 						break;
@@ -882,7 +882,7 @@ while(s)
 				s->search_result=1;
 				while((ch=*(chval2++)))
 					{
-					if((ch!='X')&&(ch!='W'))
+					if((ch!='x')&&(ch!='w')&&(ch!='X')&&(ch!='W'))
 						{
 						s->search_result=0;
 						break;
@@ -1075,35 +1075,35 @@ while(s)
 				
 			case ST_HIGH:
 				totaltraces++;
-				if((str[0]=='1')||(str[0]=='H')) s->search_result=1;	
+				if((str[0]=='1')||(str[0]=='h')||(str[0]=='H')) s->search_result=1;	
 				break;
 
 			case ST_RISE:
 				totaltraces++;
-				if(((str[0]=='1')||(str[0]=='H'))&&(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)==maxbase)) 
+				if(((str[0]=='1')||(str[0]=='h')||(str[0]=='H'))&&(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)==maxbase)) 
 					s->search_result=1;	
 				break;
 
 			case ST_LOW:
 				totaltraces++;
-				if((str[0]=='0')||(str[0]=='L')) s->search_result=1;
+				if((str[0]=='0')||(str[0]=='l')||(str[0]=='L')) s->search_result=1;
 				break;
 
 			case ST_FALL:
 				totaltraces++;
-				if(((str[0]=='0')||(str[0]=='L'))&&(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)==maxbase))
+				if(((str[0]=='0')||(str[0]=='l')||(str[0]=='L'))&&(strace_adjust(s->his.h->time,GLOBALS->shift_timebase)==maxbase))
  					s->search_result=1;
 				break;
 
 			case ST_MID:
 				totaltraces++;
-				if(str[0]=='Z')
+				if((str[0]=='z')||(str[0]=='Z'))
  					s->search_result=1;
 				break;				
 
 			case ST_X:
 				totaltraces++;
-				if(str[0]=='X') s->search_result=1;
+				if((str[0]=='x')||(str[0]=='X')) s->search_result=1;
 				break;
 
 			case ST_ANY:
@@ -1183,7 +1183,7 @@ while(s)
 				if((chval2=chval))
 				while((ch=*(chval2++)))
 					{
-					if(((ch>='1')&&(ch<='9'))||(ch=='H')||((ch>='A')&&(ch<='F')))
+					if(((ch>='1')&&(ch<='9'))||(ch=='h')||(ch=='H')||((ch>='A')&&(ch<='F')))
 						{
 						s->search_result=1;
 						break;
@@ -1198,7 +1198,7 @@ while(s)
 				s->search_result=1;
 				while((ch=*(chval2++)))
 					{
-					if((ch!='0')&&(ch!='L'))
+					if((ch!='0')&&(ch!='l')&&(ch!='L'))
 						{
 						s->search_result=0;
 						break;
@@ -1214,7 +1214,7 @@ while(s)
 				s->search_result=1;
 				while((ch=*(chval2++)))
 					{
-					if(ch!='Z')
+					if((ch!='z')&&(ch!='Z'))
 						{
 						s->search_result=0;
 						break;
@@ -1230,7 +1230,7 @@ while(s)
 				s->search_result=1;
 				while((ch=*(chval2++)))
 					{
-					if((ch!='X')&&(ch!='W'))
+					if((ch!='x')&&(ch!='w')&&(ch!='X')&&(ch!='W'))
 						{
 						s->search_result=0;
 						break;
@@ -1343,8 +1343,9 @@ if(GLOBALS->mark_idx_start>0)
 		basetime=GLOBALS->named_markers[GLOBALS->mark_idx_start-1];
 	else
 		{
-		status_text(item_mark_start_strings[(unsigned int)GLOBALS->mark_idx_start].str);
-		status_text(" not in use.\n");
+		char notused[129];
+		sprintf(notused, "%s not in use.\n", item_mark_start_strings[(unsigned int)GLOBALS->mark_idx_start].str);
+		status_text(notused);
 		}
 	}
 
@@ -1354,8 +1355,9 @@ if(GLOBALS->mark_idx_end>0)
 		endtime=GLOBALS->named_markers[GLOBALS->mark_idx_end-1];
 	else
 		{
-		status_text(item_mark_end_strings[(unsigned int)GLOBALS->mark_idx_end].str);
-		status_text(" not in use.\n");
+		char notused[129];
+		sprintf(notused, "%s not in use.\n", item_mark_end_strings[(unsigned int)GLOBALS->mark_idx_end].str);
+		status_text(notused);
 		}
 	}
 
@@ -1588,7 +1590,9 @@ if(GLOBALS->timearray)
 				int i;
 				nptr *nodes;
 
-				mprintf("#%s",t->name);
+				if(HasAlias(t)) { mprintf("+{%s} ",t->name_full); }
+
+				mprintf("#{%s}",t->name);
 
 				nodes=t->n.vec->bits->nodes;
 				for(i=0;i<t->n.vec->nbits;i++)
@@ -1606,15 +1610,15 @@ if(GLOBALS->timearray)
 				}
 				else
 				{
-				if(t->is_alias)
+				if(HasAlias(t))
 					{
 					if(t->n.nd->expansion)
 						{
-						mprintf("+%s (%d)%s\n",t->name+2,t->n.nd->expansion->parentbit, t->n.nd->expansion->parent->nname);
+						mprintf("+{%s} (%d)%s\n",t->name+2,t->n.nd->expansion->parentbit, t->n.nd->expansion->parent->nname);
 						}
 						else
 						{
-						mprintf("+%s %s\n",t->name+2,t->n.nd->nname);
+						mprintf("+{%s} %s\n",t->name+2,t->n.nd->nname);
 						}
 					}
 					else
@@ -1639,8 +1643,20 @@ if(GLOBALS->timearray)
 }
 
 /*
- * $Id: strace.c,v 1.8 2008/07/01 18:51:07 gtkwave Exp $
+ * $Id: strace.c,v 1.12 2009/12/24 20:55:27 gtkwave Exp $
  * $Log: strace.c,v $
+ * Revision 1.12  2009/12/24 20:55:27  gtkwave
+ * warnings cleanups
+ *
+ * Revision 1.11  2009/09/14 03:00:08  gtkwave
+ * bluespec code integration
+ *
+ * Revision 1.10  2009/07/07 20:12:53  gtkwave
+ * convert hex capitalization to match verilog
+ *
+ * Revision 1.9  2009/03/09 23:29:12  gtkwave
+ * fixed memory access violation and added comprehensive option.
+ *
  * Revision 1.8  2008/07/01 18:51:07  gtkwave
  * compiler warning fixes for amd64
  *
