@@ -30,6 +30,7 @@
 #include "hierpack.h"
 #include "menu.h"
 #include "tcl_helper.h"
+#include "tcl_support_commands.h"
 
 #if !defined __MINGW32__ && !defined _MSC_VER
 #include <sys/types.h>
@@ -123,31 +124,28 @@ static char *extractFullTraceName(Trptr t)
 {
 char *name = NULL;
 
-if(!(t->flags&(TR_BLANK|TR_ANALOG_BLANK_STRETCH)))
-	{
-	if(t->vector==TRUE)
-		{
-		name = strdup_2(t->n.vec->name);
-		}
-		else 
-		{
-		if(!t->is_alias)
-			{
-	                int flagged = 0;
+ if(HasWave(t))
+   {
+     if (HasAlias(t))
+       {
+	 name = strdup_2(t->name_full);
+       }
+     else if (t->vector)
+       {
+	 name = strdup_2(t->n.vec->name);
+       }
+     else
+       {
+	 int flagged = 0;
 
-	                name = hier_decompress_flagged(t->n.nd->nname, &flagged);
-			if(!flagged)
-				{
-				name = strdup_2(name);
-				}
-       			}
-       			else
-       			{
-			name = strdup_2(t->name);
-       			} 
-		}
-	}
-return(name);
+	 name = hier_decompress_flagged(t->n.nd->nname, &flagged);
+	 if(!flagged)
+	   {
+	     name = strdup_2(name);
+	   }
+       }
+   }
+ return(name);
 }
 
 
@@ -287,6 +285,7 @@ if(GLOBALS->is_lx2)
                 case LXT2_IS_AET2: reportString = "AET2"; break;
                 case LXT2_IS_VZT:  reportString = "VZT"; break;
                 case LXT2_IS_VLIST:reportString = "VCD"; break;
+                case LXT2_IS_FST:  reportString = "FST"; break;
                 }
         }
 
@@ -938,20 +937,23 @@ if(objc == 2)
         {
         char *s = Tcl_GetString(objv[1]);
         int target = atoi(s);
-        GtkAdjustment *wadj=GTK_ADJUSTMENT(GLOBALS->wave_vslider);
 
-        int num_traces_displayable=(GLOBALS->signalarea->allocation.height)/(GLOBALS->fontheight);
-        num_traces_displayable--;   /* for the time trace that is always there */
+ 	SetTraceScrollbarRowValue(target, 0);
 
-	if(target > GLOBALS->traces.visible - num_traces_displayable) target = GLOBALS->traces.visible - num_traces_displayable;
+/*         GtkAdjustment *wadj=GTK_ADJUSTMENT(GLOBALS->wave_vslider); */
 
-	if(target < 0) target = 0;
+/*         int num_traces_displayable=(GLOBALS->signalarea->allocation.height)/(GLOBALS->fontheight); */
+/*         num_traces_displayable--;   /\* for the time trace that is always there *\/ */
 
-	wadj->value = target;
+/* 	if(target > GLOBALS->traces.visible - num_traces_displayable) target = GLOBALS->traces.visible - num_traces_displayable; */
 
-        gtk_signal_emit_by_name (GTK_OBJECT (wadj), "changed"); /* force bar update */
-        gtk_signal_emit_by_name (GTK_OBJECT (wadj), "value_changed"); /* force text update */
-	gtkwave_gtk_main_iteration();
+/* 	if(target < 0) target = 0; */
+
+/* 	wadj->value = target; */
+
+/*         gtk_signal_emit_by_name (GTK_OBJECT (wadj), "changed"); /\* force bar update *\/ */
+/*         gtk_signal_emit_by_name (GTK_OBJECT (wadj), "value_changed"); /\* force text update *\/ */
+/*	gtkwave_gtk_main_iteration(); */
 	}
         else  
         {
@@ -988,8 +990,11 @@ if(objc==2)
 			}
                 free_2(elem);
                 elem = NULL;
-		num_found = process_tcl_list(mult_entry, FALSE);
-		free_2(mult_entry);
+		if(mult_entry)
+			{
+			num_found = process_tcl_list(mult_entry, FALSE);
+			free_2(mult_entry);
+			}
 		if(num_found)
         		{
         		MaxSignalLength();
@@ -1417,6 +1422,109 @@ return(TCL_OK);
 }
 
 
+static int gtkwavetcl_signalChangeList(ClientData clientData, Tcl_Interp *interp,
+				       int objc, Tcl_Obj *CONST objv[]) {
+    int dir = STRACE_FORWARD ;
+    TimeType start_time = 0 ;
+    TimeType end_time = MAX_HISTENT_TIME ;
+    int max_elements = 0x7fffffff ;
+    char *sig_name = NULL ;
+    int i ;
+    char *str_p, *str1_p ;
+    int error = 0 ;
+    llist_p *l_head ;
+    Tcl_Obj *l_obj ;
+    Tcl_Obj *obj ;
+    llist_p *p, *p1 ;
+
+    for(i=1; i<objc; i++) {
+      str_p = Tcl_GetStringFromObj(objv[i], NULL) ;
+      if (*str_p != '-') {
+	sig_name = str_p ;
+      } else {
+        if(i == (objc-1)) { /* loop overflow on i check */
+	  error++;
+	  break;
+	  }
+	str1_p = Tcl_GetStringFromObj(objv[++i], NULL) ;
+	switch(str_p[1]) {
+	case 's': /* start time */
+	  if(!strstr("-start_time", str_p))
+	    error++ ;
+	  else {
+	    if((start_time = atoi_64(str1_p)) < 0)
+	      start_time = 0 ;
+	    dir = (start_time > end_time) ? STRACE_BACKWARD : STRACE_FORWARD ;
+	  }
+	  break ;
+	case 'e': /* end time */
+	  if(!strstr("-end_time", str_p))
+	    error++ ;
+	  else {
+	    end_time = atoi_64(str1_p) ;
+	    dir = (start_time > end_time) ? STRACE_BACKWARD : STRACE_FORWARD ;
+	  }
+	  break ;
+	case 'm': /* max */
+	  if(!strstr("-max", str_p))
+	    error++ ;
+	  else {
+	    max_elements = atoi(str1_p) ;
+	  }
+	  break ;
+	case 'd': /* dir */
+	  if(!strstr("-dir", str_p))
+	    error++ ;
+	  else {
+	    if(strstr("forward", str1_p))
+	      dir = STRACE_FORWARD ;
+	    else 
+	      if(strstr("backward", str1_p))
+		dir = STRACE_BACKWARD ;
+	      else
+		error++ ;
+	  }
+	  break ;
+	default:
+	  error++ ;
+	}
+      }
+    }
+    /* consistancy check */
+    if(dir == STRACE_FORWARD) {
+      if(start_time > end_time) error++ ;
+    } else {
+      if(start_time < end_time) {
+	if(end_time == MAX_HISTENT_TIME)
+	  end_time = 0 ;
+	else
+	  error ++ ;
+      }
+    }
+    if(error) {
+      Tcl_SetObjResult
+	(interp, 
+	 Tcl_NewStringObj("Usage: signal_change_list ?name? ?-start time? ?-end time? ?-max size? ?-dir forward|backward?", -1)) ;
+      return TCL_ERROR;
+    } 
+    l_head = signal_change_list(sig_name, dir, start_time, end_time, max_elements) ;
+    l_obj = Tcl_NewListObj(0, NULL) ;
+    p = l_head;
+    while(p) {
+      obj = Tcl_NewWideIntObj((Tcl_WideInt )p->u.tt) ;
+      p1= p->next ;
+      free_2(p) ;
+      Tcl_ListObjAppendElement(interp, l_obj, obj) ;
+      obj = Tcl_NewStringObj(p1->u.str,-1) ;
+      Tcl_ListObjAppendElement(interp, l_obj, obj) ;
+      p = p1->next ;
+      free_2(p1->u.str) ;
+      free_2(p1) ;
+    }
+    Tcl_SetObjResult(interp, l_obj) ;
+    return TCL_OK ;
+}
+
 static int gtkwavetcl_findNextEdge(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
 edge_search(STRACE_FORWARD);
@@ -1433,8 +1541,10 @@ return(gtkwavetcl_getMarker(clientData, interp, objc, objv));
 }
 
 
+int SST_open_node(char *name) ;
 static int gtkwavetcl_forceOpenTreeNode(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
+  int rv = -100;		/* Tree does not exist */
 if(objc == 2)
         {
         char *s = Tcl_GetString(objv[1]);
@@ -1444,33 +1554,29 @@ if(objc == 2)
 		int len = strlen(s);
 		if(s[len-1]!=GLOBALS->hier_delimeter)
 			{
-			char *s2 = calloc_2(1, len+2);
-			strcpy(s2, s);
-			s2[len] = GLOBALS->hier_delimeter;
 #ifdef WAVE_USE_GTK2
-			force_open_tree_node(s2);
+			rv = SST_open_node(s);
 #endif
-			free_2(s2);
 			}
 			else
 			{
 #ifdef WAVE_USE_GTK2
-			force_open_tree_node(s);
+
+			rv = SST_open_node(s);
 #endif
-			}
-		}
-
-	gtkwave_gtk_main_iteration();
+	    }
 	}
-        else  
-        {
-        return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
-        }
-
-return(TCL_OK);
+      gtkwave_gtk_main_iteration(); /* check if this is needed */
+    }
+  else  
+    {
+      return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
+    }
+  Tcl_SetObjResult(GLOBALS->interp, Tcl_NewIntObj(rv)) ;
+  
+  return(TCL_OK);
 }
 
-
 static int gtkwavetcl_setFromEntry(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
 if(objc == 2)
@@ -1593,6 +1699,153 @@ if(objc == 2)
 return(TCL_OK);
 }
 
+static int gtkwavetcl_loadFile(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
+{
+  if(objc == 2)
+    {
+      char *s = Tcl_GetString(objv[1]);
+	
+      /*	read_save_helper(s); */
+      process_url_file(s);
+      /*	process_url_list(s); */
+      /*	gtkwave_gtk_main_iteration(); */
+
+
+    }
+  else  
+    {
+      return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
+    }
+
+  return(TCL_OK);
+}
+
+static int gtkwavetcl_reLoadFile(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
+{
+
+  if(objc == 1)
+    {
+      reload_into_new_context();
+    }
+  else  
+    {
+      return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 0));
+    }
+  return(TCL_OK);
+}
+
+static int gtkwavetcl_presentWindow(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
+{
+
+  if(objc == 1)
+    {
+#ifdef WAVE_USE_GTK2 
+      gtk_window_present(GTK_WINDOW(GLOBALS->mainwindow));
+#else
+      gdk_window_raise(GTK_WIDGET(GLOBALS->mainwindow)->window);
+#endif
+    }
+  else  
+    {
+      return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 0));
+    }
+  return(TCL_OK);
+}
+
+static int gtkwavetcl_showSignal(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
+{
+  if(objc == 3)
+    {
+      char *s0 = Tcl_GetString(objv[1]);
+      char *s1;
+      int row;
+      unsigned location;
+
+      sscanf(s0, "%d", &row);
+      if (row < 0) { row = 0; };
+
+      s1 = Tcl_GetString(objv[2]);
+      sscanf(s1, "%d", &location);
+
+      SetTraceScrollbarRowValue(row, location);
+    }
+  else  
+    {
+      return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 2));
+    }
+
+  return(TCL_OK);
+}
+
+
+/* 
+ * swap to a given context based on tab number (from Tcl)
+ */
+static gint switch_to_tab_number(unsigned int i)
+{       
+if(i < GLOBALS->num_notebook_pages)  
+        {
+        struct Global *g_old = GLOBALS;
+        /* printf("Switching to: %d\n", i); */
+
+        set_GLOBALS((*GLOBALS->contexts)[i]);
+        
+        GLOBALS->lxt_clock_compress_to_z = g_old->lxt_clock_compress_to_z;
+        GLOBALS->autoname_bundles = g_old->autoname_bundles;
+        GLOBALS->autocoalesce_reversal = g_old->autocoalesce_reversal;
+        GLOBALS->autocoalesce = g_old->autocoalesce;
+        GLOBALS->hier_grouping = g_old->hier_grouping;
+        GLOBALS->wave_scrolling = g_old->wave_scrolling;
+        GLOBALS->constant_marker_update = g_old->constant_marker_update;
+        GLOBALS->do_zoom_center = g_old->do_zoom_center;
+        GLOBALS->use_roundcaps = g_old->use_roundcaps;
+        GLOBALS->do_resize_signals = g_old->do_resize_signals;
+        GLOBALS->use_full_precision = g_old->use_full_precision;
+        GLOBALS->show_base = g_old->show_base;
+        GLOBALS->display_grid = g_old->display_grid;
+        GLOBALS->disable_mouseover = g_old->disable_mouseover;
+        GLOBALS->zoom_pow10_snap = g_old->zoom_pow10_snap;
+                                         
+        GLOBALS->scale_to_time_dimension = g_old->scale_to_time_dimension;
+        GLOBALS->zoom_dyn = g_old->zoom_dyn;
+        GLOBALS->zoom_dyne = g_old->zoom_dyne;
+                                                         
+        gtk_notebook_set_current_page(GTK_NOTEBOOK(GLOBALS->notebook), GLOBALS->this_context_page);
+        return(TRUE);
+        }
+                
+return(FALSE);
+}                     
+
+
+static int gtkwavetcl_setTabActive(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
+{
+if(objc == 2)
+        {       
+        char *s = Tcl_GetString(objv[1]);
+        unsigned int tabnum = atoi(s);
+	gint rc = switch_to_tab_number(tabnum);
+        
+        MaxSignalLength();
+        signalarea_configure_event(GLOBALS->signalarea, NULL);
+        
+        gtkwave_gtk_main_iteration();
+	return(gtkwavetcl_printInteger(clientData, interp, objc, objv, rc));
+        }
+        else
+        {
+        return(gtkwavetcl_badNumArgs(clientData, interp, objc, objv, 1));
+        }
+       
+}
+
+
+static int gtkwavetcl_getNumTabs(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
+{
+int value = GLOBALS->num_notebook_pages;
+return(gtkwavetcl_printInteger(clientData, interp, objc, objv, value));
+}
+
 
 tcl_cmdstruct gtkwave_commands[] =
 	{
@@ -1618,6 +1871,7 @@ tcl_cmdstruct gtkwave_commands[] =
 	{"getMinTime", 				gtkwavetcl_getMinTime},
 	{"getNamedMarker", 			gtkwavetcl_getNamedMarker},
 	{"getNumFacs", 				gtkwavetcl_getNumFacs},
+	{"getNumTabs",				gtkwavetcl_getNumTabs},
 	{"getPixelsUnitTime", 			gtkwavetcl_getPixelsUnitTime},
 	{"getSaveFileName",			gtkwavetcl_getSaveFileName},
 	{"getStemsFileName",			gtkwavetcl_getStemsFileName},
@@ -1645,6 +1899,7 @@ tcl_cmdstruct gtkwave_commands[] =
 	{"setLeftJustifySigs",			gtkwavetcl_setLeftJustifySigs},
 	{"setMarker",				gtkwavetcl_setMarker},
 	{"setNamedMarker",			gtkwavetcl_setNamedMarker},
+   	{"setTabActive",			gtkwavetcl_setTabActive},
 	{"setToEntry",				gtkwavetcl_setToEntry},
 	{"setTraceHighlightFromIndex",		gtkwavetcl_setTraceHighlightFromIndex},
 	{"setTraceHighlightFromNameMatch",	gtkwavetcl_setTraceHighlightFromNameMatch},
@@ -1652,7 +1907,12 @@ tcl_cmdstruct gtkwave_commands[] =
 	{"setWindowStartTime",			gtkwavetcl_setWindowStartTime},
 	{"setZoomFactor",			gtkwavetcl_setZoomFactor},
 	{"setZoomRangeTimes",			gtkwavetcl_setZoomRangeTimes},
+	{"loadFile",			        gtkwavetcl_loadFile},
+	{"reLoadFile",			        gtkwavetcl_reLoadFile},
+	{"presentWindow",			gtkwavetcl_presentWindow},
+	{"showSignal",         			gtkwavetcl_showSignal},
 	{"unhighlightSignalsFromList",		gtkwavetcl_unhighlightSignalsFromList},
+	{"signalChangeList",                    gtkwavetcl_signalChangeList},	/* changed from signal_change_list for consistency! */
    	{"", 					NULL} /* sentinel */
 	};
 
@@ -1667,8 +1927,44 @@ static void dummy_function(void)
 
 
 /*
- * $Id: tcl_commands.c,v 1.23 2009/02/16 05:24:32 gtkwave Exp $
+ * $Id: tcl_commands.c,v 1.35 2009/12/24 20:55:27 gtkwave Exp $
  * $Log: tcl_commands.c,v $
+ * Revision 1.35  2009/12/24 20:55:27  gtkwave
+ * warnings cleanups
+ *
+ * Revision 1.34  2009/11/29 19:16:13  gtkwave
+ * added gtkwave::setTabActive and gtkwave::getNumTabs
+ *
+ * Revision 1.33  2009/11/29 18:38:20  gtkwave
+ * added FST to return types for gtkwave::getDumpType
+ *
+ * Revision 1.32  2009/11/06 04:15:17  gtkwave
+ * gtk+-1.2 compile fixes
+ *
+ * Revision 1.31  2009/10/26 22:44:01  gtkwave
+ * output style fixes, remove double init for bluespec
+ *
+ * Revision 1.30  2009/10/08 17:40:49  gtkwave
+ * removed casting on llist_new, use union instead as arg
+ *
+ * Revision 1.29  2009/10/07 21:13:10  gtkwave
+ * 64-bit fixes on signal list generation
+ *
+ * Revision 1.28  2009/09/29 02:45:19  gtkwave
+ * warnings cleanups
+ *
+ * Revision 1.27  2009/09/28 05:58:05  gtkwave
+ * changes to support signal_change_list
+ *
+ * Revision 1.26  2009/09/20 21:45:50  gtkwave
+ * tree force open node handling changed for tcl
+ *
+ * Revision 1.25  2009/09/14 03:00:08  gtkwave
+ * bluespec code integration
+ *
+ * Revision 1.24  2009/03/26 20:57:42  gtkwave
+ * added MISSING_FILE support for bringing up gtkwave without a dumpfile
+ *
  * Revision 1.23  2009/02/16 05:24:32  gtkwave
  * added setBaselineMarker command
  *
