@@ -30,6 +30,7 @@
 #include "hierpack.h"
 #include "menu.h"
 #include "tcl_helper.h"
+#include "tcl_np.h"
 
 #if !defined __MINGW32__ && !defined _MSC_VER
 #include <sys/types.h>
@@ -40,7 +41,6 @@
 #define strcasecmp _stricmp
 #endif
 
-
 /*----------------------------------------------------------------------
  * tclBackslash -- Figure out how to handle a backslash sequence in tcl list.
  *
@@ -771,6 +771,11 @@ char** elem = NULL;
 char *pnt, *pnt2;
 int esc = 0;
 
+if(!s)
+	{
+	return(NULL);
+	}
+
 elem = zSplitTclList(s, &l);
 
 if(elem)
@@ -865,6 +870,11 @@ int unesc_len;
 int curr_srch_idx = 0;
 char *unescaped_str = NULL;
 
+if(!sl)
+	{
+	return(0);
+	}
+
 list = zSplitTclList(sl, &c);
 if(!list)
 	{
@@ -958,14 +968,14 @@ for(ii=0;ii<c;ii++)
 										break;
 										}
 	
-									if((!is)&&(GLOBALS->is_lx2)) { parsewavline_lx2(nxt_hd, 0); found++; } else { parsewavline(nxt_hd, 0); }
+									if((!is)&&(GLOBALS->is_lx2)) { parsewavline_lx2(nxt_hd, NULL, 0); found++; } else { parsewavline(nxt_hd, NULL, 0); }
 									break;
 									}
 								else
 								if(*pnt == '\n')
 									{
 									*pnt = 0;
-									if((!is)&&(GLOBALS->is_lx2)) { parsewavline_lx2(nxt_hd, 0); found++; } else { parsewavline(nxt_hd, 0); }
+									if((!is)&&(GLOBALS->is_lx2)) { parsewavline_lx2(nxt_hd, NULL, 0); found++; } else { parsewavline(nxt_hd, NULL, 0); }
 									*pnt = '\n';
 									nxt_hd = pnt+1;
 									pnt++;
@@ -1232,6 +1242,8 @@ free_2(match_type_list);
 free_2(most_recent_lbrack_list);
 free_2(list);
 
+EnsureGroupsMatch();
+
 return(found);
 }
 
@@ -1577,7 +1589,7 @@ char *one_entry = NULL, *mult_entry = NULL;
 unsigned int mult_len = 0;
 char *netoff = "{gtkwave NET OFF} ";
 char *trace_val = NULL;
-const char xfwd[AN_COUNT]= AN_NORMAL;
+static const char xfwd[AN_COUNT]= AN_NORMAL;
 char trace_val_vec_single[2] = { 0, 0 };
 
 if(is_from_tcl_command)
@@ -1957,37 +1969,33 @@ char *emit_gtkwave_savefile_formatted_entries_in_tcl_list(Trptr t, gboolean use_
 	unsigned int def=0;
 	TimeType prevshift=LLDescriptor(0);
 	char is_first = 1;
-	char collapsed_state = 0, flag_skip;
+	char flag_skip;
 
 	while(t)
 		{
 		flag_skip = 0;
 
 		if(use_tcl_mode)
-			{
-			if((t->flags & (TR_HIGHLIGHT|TR_COLLAPSED)) == (TR_HIGHLIGHT|TR_COLLAPSED)) 
-				{
-				collapsed_state = 1;
-				}
+		  {
+		    if(IsSelected(t) || (t->t_grp && IsSelected(t->t_grp)))
+		      {
+			/* members of closed groups may not be highlighted */
+			/* so propogate highlighting here */
+			t->flags |= TR_HIGHLIGHT;
+		      }
+		    else
+		      {
+			if((prev_flags & TR_ANALOGMASK) && (t->flags &TR_ANALOG_BLANK_STRETCH))
+			  {
+			    flag_skip = 1;
+			  }
 			else
-			if((t->flags & TR_BLANK) && collapsed_state)
-				{
-				collapsed_state = 0;
-				}
-			else
-			if(!(t->flags & TR_HIGHLIGHT))
-				{
-				if((prev_flags & TR_ANALOGMASK) && (t->flags &TR_ANALOG_BLANK_STRETCH))
-					{
-					flag_skip = 1;
-					}
-				else
-					{
-					t = t->t_next;
-					continue;
-					}
-				}
-			}
+			  {
+			    t = t->t_next;
+			    continue;
+			  }
+		      }
+		  }
 
 		if((t->flags!=def)||(is_first))
 			{
@@ -2040,10 +2048,15 @@ char *emit_gtkwave_savefile_formatted_entries_in_tcl_list(Trptr t, gboolean use_
 				{
 				int i;
 				nptr *nodes;
-				bptr bits = t->n.vec->bits;
-				baptr ba = bits ? bits->attribs : NULL;
+				bptr bits;
+				baptr ba;
 
-				one_entry = make_message("%c%s", ba ? ':' : '#', t->name);
+				if(HasAlias(t)) { one_entry = make_message("+{%s} ",t->name_full); 
+				                  WAVE_OE_ME }
+				bits = t->n.vec->bits;
+				ba = bits ? bits->attribs : NULL;
+
+				one_entry = make_message("%c{%s}", ba ? ':' : '#', t->n.vec->name);
 				WAVE_OE_ME
 
 				nodes=t->n.vec->bits->nodes;
@@ -2071,16 +2084,16 @@ char *emit_gtkwave_savefile_formatted_entries_in_tcl_list(Trptr t, gboolean use_
 				}
 				else
 				{
-				if(t->is_alias)
+				  if(HasAlias(t))
 					{
 					if(t->n.nd->expansion)
 						{
-						one_entry = make_message("+%s (%d)%s\n",t->name+2,t->n.nd->expansion->parentbit, append_array_row(t->n.nd->expansion->parent));
+						one_entry = make_message("+{%s} (%d)%s\n",t->name_full,t->n.nd->expansion->parentbit, append_array_row(t->n.nd->expansion->parent));
 						WAVE_OE_ME
 						}
 						else
 						{
-						one_entry = make_message("+%s %s\n",t->name+2,append_array_row(t->n.nd));
+						one_entry = make_message("+{%s} %s\n",t->name_full,append_array_row(t->n.nd));
 						WAVE_OE_ME
 						}
 					}
@@ -2134,20 +2147,21 @@ return(mult_entry);
 /* XXX functions for URL (not TCL list) handling XXX */
 /* XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX */
 
+enum GtkwaveFtype { WAVE_FTYPE_UNKNOWN, WAVE_FTYPE_DUMPFILE, WAVE_FTYPE_STEMSFILE, WAVE_FTYPE_SAVEFILE };
+
 /* ----------------------------------------------------------------------------
- * process_url_file - examines filename and performs appropriate side-effect
+ * determine_ftype - examines filename (perhaps initial contents) and 
+ *      determines file type
  *
  * Results:
- *      Loads save file, new dump file, or stems file viewer
+ *      enum of ftype determination
  * ----------------------------------------------------------------------------
  */
-
-static int process_url_file(char *s)
+static int determine_ftype(char *s, char **dotpnt)
 {
-int rc = 0;
 char *pnt = s;
 char *dot = NULL, *dot2 = NULL;
-int ftype = 0;
+int ftype = WAVE_FTYPE_UNKNOWN;
 
 while(*pnt)
 	{
@@ -2155,16 +2169,18 @@ while(*pnt)
 	pnt++;
 	}
 
+*dotpnt = dot;
+
 if(dot)
 	{
 	if(!strcasecmp("sav", dot+1))
 		{
-		ftype = 1;
+		ftype = WAVE_FTYPE_SAVEFILE;
 		}
 	else
 	if(!strcasecmp("stems", dot+1))
 		{
-		ftype = 2;
+		ftype = WAVE_FTYPE_STEMSFILE;
 		}
 	else /* detect dumpfile type */
 	if	(
@@ -2176,12 +2192,13 @@ if(dot)
 		(!strcasecmp("lxt", dot+1)) ||
 		(!strcasecmp("lx2", dot+1)) ||
 		(!strcasecmp("vzt", dot+1)) ||
+		(!strcasecmp("fst", dot+1)) ||
 		(!strcasecmp("ghw", dot+1)) ||
 		(!strcasecmp("aet", dot+1)) ||
 		(!strcasecmp("ae2", dot+1))
 		)
 		{
-		ftype = 3;
+		ftype = WAVE_FTYPE_DUMPFILE;
 		}
 	else
 	if(dot2)
@@ -2194,7 +2211,7 @@ if(dot)
 			(!strcasecmp("vcd.zip", dot2+1)) 
 			)
 			{
-			ftype = 3;
+			ftype = WAVE_FTYPE_DUMPFILE;
 			}
 		}
 	}
@@ -2212,22 +2229,37 @@ if(dot)
 
 		if((ch0 == '+') && (ch1 == '+'))
 			{
-			ftype = 2; /* stems file */
+			ftype = WAVE_FTYPE_STEMSFILE; /* stems file */
 			}
 		else 
 		if(ch0 == '[')
 			{
-			ftype = 1; /* save file */
+			ftype = WAVE_FTYPE_SAVEFILE; /* save file */
 			}
 
 		fclose(f);
 		}
 	}
 
+return(ftype);
+}
+
+/* ----------------------------------------------------------------------------
+ * process_url_file - examines filename and performs appropriate side-effect
+ *
+ * Results:
+ *      Loads save file, new dump file, or stems file viewer
+ * ----------------------------------------------------------------------------
+ */
+int process_url_file(char *s)
+{
+int rc = 0;
+char *dotpnt = NULL;
+int ftype = determine_ftype(s, &dotpnt);
 
 switch(ftype)
 	{
-	case 1:
+	case WAVE_FTYPE_SAVEFILE:
 		GLOBALS->fileselbox_text = &GLOBALS->filesel_writesave;
 	        GLOBALS->filesel_ok=1;
         	if(*GLOBALS->fileselbox_text) free_2(*GLOBALS->fileselbox_text);
@@ -2239,7 +2271,7 @@ switch(ftype)
 		rc = 1;
 		break;
 
-	case 2:
+	case WAVE_FTYPE_STEMSFILE:
 #if !defined _MSC_VER && !defined __MINGW32__
 		GLOBALS->fileselbox_text = &GLOBALS->stems_name;
 	        GLOBALS->filesel_ok=1;
@@ -2251,7 +2283,7 @@ switch(ftype)
 		rc = 1;
 		break;
 
-	case 3:
+	case WAVE_FTYPE_DUMPFILE:
 		GLOBALS->fileselbox_text = &GLOBALS->filesel_newviewer_menu_c_1;
 	        GLOBALS->filesel_ok=1;
         	if(*GLOBALS->fileselbox_text) free_2(*GLOBALS->fileselbox_text);
@@ -2268,9 +2300,44 @@ switch(ftype)
 return(rc);
 }
 
+/* ----------------------------------------------------------------------------
+ * uri_cmp - qsort compare function that ensures save files and stems are
+ *      ordered after their respective dumpfiles
+ *
+ * Results:
+ *      returns correct sort order for processing (based on name and
+ *      GtkwaveFtype
+ * ----------------------------------------------------------------------------
+ */
+static int uri_cmp(const void *v1, const void *v2)
+{
+char *s1 = *(char **)v1;
+char *s2 = *(char **)v2;
+char *d1, *d2;
+int typ1 = determine_ftype(s1, &d1);
+int typ2 = determine_ftype(s2, &d2);
+int rc;
+
+if(!d1 || !d2)
+	{
+	return(strcmp(s1, s2));
+	}
+
+*d1 = 0; *d2 = 0;
+
+rc = strcmp(s1, s2);
+if(!rc)
+	{
+	rc = (typ1 - typ2); /* use suffix ftype to manipulate sort */
+	}
+
+*d1 = '.'; *d2 = '.';
+
+return(rc);
+}
 
 /* ----------------------------------------------------------------------------
- * process_url_list - examines list of URLs and 
+ * process_url_list - examines list of URLs and processes if valid files
  *
  * Results:
  *      Indicates if any URLs were processed
@@ -2281,11 +2348,14 @@ int process_url_list(char *s)
 {
 int is_url = 0;
 #if WAVE_USE_GTK2
+int i;
+int url_cnt = 0;
 char pch = 0;
 
 char *nxt_hd = s;
 char *pnt = s;
 char *path;
+char **url_list = calloc_2(1, sizeof(gchar *));
 
 if(*pnt == '{') return(0); /* exit early if tcl list */
 
@@ -2299,7 +2369,7 @@ for(;;)
 			}
 
 		path = g_filename_from_uri(nxt_hd, NULL, NULL);
-		if(path) { is_url += process_url_file(path); }
+		if(path) { url_list[url_cnt++] = path; url_list = realloc_2(url_list, (url_cnt+1) * sizeof(gchar *)); }
 		break;
 		}
 	else
@@ -2311,7 +2381,7 @@ for(;;)
 			*pnt = 0;
 
 			path = g_filename_from_uri(nxt_hd, NULL, NULL);
-			if(path) { is_url += process_url_file(path); }
+			if(path) { url_list[url_cnt++] = path; url_list = realloc_2(url_list, (url_cnt+1) * sizeof(gchar *)); }
 			*pnt = sav;
 			}
 		pch = *pnt;
@@ -2325,6 +2395,36 @@ for(;;)
 		}
 	}
 
+if(url_list)
+	{
+	if(url_cnt > 2) 
+		{
+		qsort(url_list, url_cnt, sizeof(struct gchar *), uri_cmp);
+		}
+	else
+	if(url_cnt == 2) /* in case there are only 2 files, make the savefile last */
+		{
+		char *d1, *d2;
+		int typ1 = determine_ftype(url_list[0], &d1);
+		int typ2 = determine_ftype(url_list[1], &d2);
+
+		if(typ1 > typ2)
+			{
+			char *tmp_swap = url_list[0];
+			url_list[0] = url_list[1];
+			url_list[1] = tmp_swap;
+			}
+		}
+
+	for(i=0;i<url_cnt;i++)
+		{
+		is_url += process_url_file(url_list[i]);
+		g_free(url_list[i]);
+		}
+
+	free_2(url_list);
+	}
+
 #endif
 return(is_url);
 }
@@ -2339,45 +2439,53 @@ static int menu_func(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Ob
 {
 GtkItemFactoryEntry *ife = (GtkItemFactoryEntry *)clientData;
 int i;
-FILE *old_handle = GLOBALS->script_handle;
+struct wave_script_args *old_wave_script_args = GLOBALS->wave_script_args; /* stackable args */
 char fexit = GLOBALS->enable_fast_exit;
 
-GLOBALS->script_handle = NULL;
+GLOBALS->wave_script_args = NULL;
 GLOBALS->enable_fast_exit = 1;
 
 if(objc > 1)
 	{
-	int fd = -1;
-	char *fnam = tmpnam_2("tclwave", &fd);
-	if(fnam)
+	struct wave_script_args *wc = NULL;
+
+	for(i=1;i<objc;i++)
 		{
-		FILE *local_script_handle;
-
-		GLOBALS->script_handle = fopen(fnam, "wb");
-		for(i=1;i<objc;i++)
+		char *s = Tcl_GetString(objv[i]);
+		int slen = strlen(s);
+		struct wave_script_args *w = wave_alloca(sizeof(struct wave_script_args) + slen);
+			/*  alloca used in case we context switch and get our allocator ripped out from under us -- the call stack won't go away */
+		if(slen)
 			{
-			char *s = Tcl_GetString(objv[i]);
-			fprintf(GLOBALS->script_handle,"%s\n", s);
+			strcpy(w->payload, s);
 			}
-		fclose(GLOBALS->script_handle);
-
-		local_script_handle = GLOBALS->script_handle = fopen(fnam, "rb");
-		ife->callback();
-		gtkwave_gtk_main_iteration();
-		if(fd>-1) 
+		w->curr = NULL; /* yes, curr is only ever used for the 1st struct, but there is no sense creating head/follower structs for this */
+		w->next = NULL;
+		if(!GLOBALS->wave_script_args)
 			{
-			close(fd);
+			GLOBALS->wave_script_args = w;
+			w->curr = w;
+			wc = w;
 			}
-
-		fclose(local_script_handle);
-		GLOBALS->script_handle = NULL;
-
-		unlink(fnam);
-		if(fd>-1) 
+			else
 			{
-			free_2(fnam);
+			wc->next = w; /* we later really traverse through curr->next from the head pointer */
+			wc = w;
 			}
 		}
+
+	if(!GLOBALS->wave_script_args) /* create a dummy list in order to keep requesters from popping up in file.c, etc. */
+		{
+		GLOBALS->wave_script_args = wave_alloca(sizeof(struct wave_script_args));
+		GLOBALS->wave_script_args->curr = NULL;
+		GLOBALS->wave_script_args->next = NULL;
+		GLOBALS->wave_script_args->payload[0] = 0;
+		}
+
+	ife->callback();
+	gtkwave_gtk_main_iteration();
+
+	GLOBALS->wave_script_args = NULL;
 	}
 	else
 	{
@@ -2386,10 +2494,85 @@ if(objc > 1)
 	}
 
 GLOBALS->enable_fast_exit = fexit;
-GLOBALS->script_handle = old_handle;
+GLOBALS->wave_script_args = old_wave_script_args;
 return(TCL_OK); /* signal error with rc=TCL_ERROR, Tcl_Obj *aobj = Tcl_NewStringObj(reportString, -1); Tcl_SetObjResult(interp, aobj); */
 }
 
+/* XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX */
+/* XXX  Bluespec Tcl Variant  XXX */
+/* XXXXXXXXXXXXXXXXXXXXXXXXXXXXXX */
+
+void gtkUpdate(ClientData ignore)
+{
+  while (gtk_events_pending()) { gtk_main_iteration(); }
+  Tcl_CreateTimerHandler(0,gtkUpdate, (ClientData) NULL);
+}
+
+int  gtkwaveInterpreterInit(Tcl_Interp *interp) {
+  int i;
+  char commandName[128];
+  GtkItemFactoryEntry *ife;
+  int num_menu_items;
+
+#ifdef WAVE_TCL_STUBIFY
+/* not needed...this does a double init if enabled:  set_globals_interp(); */
+#else
+  if(Tcl_Init(interp) == TCL_ERROR) return TCL_ERROR;
+  if(Tk_Init(interp) == TCL_ERROR) return TCL_ERROR;
+  Tcl_SetVar(interp,"tcl_rcFileName","~/.wishrc",TCL_GLOBAL_ONLY);
+#endif
+
+  strcpy(commandName, "gtkwave::");
+
+  ife = retrieve_menu_items_array(&num_menu_items);
+  for(i=0;i<num_menu_items;i++)
+    {
+      if(ife[i].callback)
+	{
+	  char *pnt = commandName + 9;
+	  strcpy(pnt, ife[i].path);
+	  while(*pnt)
+	    {
+	      if(*pnt==' ') *pnt='_';
+	      pnt++;
+	    }
+	
+	  Tcl_CreateObjCommand(interp, commandName,
+			       (Tcl_ObjCmdProc *)menu_func,
+			       (ClientData)(ife+i), (Tcl_CmdDeleteProc *)NULL);
+	}
+    }
+
+
+  for (i = 0; gtkwave_commands[i].func != NULL; i++)
+    {
+      strcpy(commandName + 9, gtkwave_commands[i].cmdstr);
+
+      Tcl_CreateObjCommand(interp, commandName,
+			   (Tcl_ObjCmdProc *)gtkwave_commands[i].func,
+			   (ClientData)NULL, (Tcl_CmdDeleteProc *)NULL);
+    }
+
+  /* hide the "wish" window */
+  Tcl_Eval(interp, "wm withdraw .");
+
+  Tcl_Eval(interp, 
+    "puts \"Interpreter id is [file tail $::argv0]\"");
+
+  if (GLOBALS->tcl_init_cmd)
+    {
+      Tcl_Eval(interp, GLOBALS->tcl_init_cmd);
+    }
+
+  Tcl_CreateTimerHandler(50,gtkUpdate, (ClientData) NULL);
+
+
+  return TCL_OK;
+}
+
+/* XXXXXXXXXXXXXXXXXXXXXXXXXXXX */
+/* XXX  Simpod Tcl Variant  XXX */
+/* XXXXXXXXXXXXXXXXXXXXXXXXXXXX */
 
 static gboolean repscript_timer(gpointer dummy)
 {
@@ -2423,6 +2606,27 @@ if((GLOBALS->repscript_name) && (!GLOBALS->tcl_running))
 	}
 }
 
+
+void set_globals_interp(char *me, int install_tk)
+{
+#ifdef WAVE_TCL_STUBIFY
+  if(NpCreateMainInterp(me, install_tk))
+	{
+	GLOBALS->interp = NpGetMainInterp();
+	}
+	else
+	{
+	fprintf(stderr, "GTKWAVE | Error, failed to find Tcl/Tk runtime libraries.\n");
+	fprintf(stderr, "GTKWAVE | Set the environment variable TCL_PLUGIN_DLL to point to\n");
+	fprintf(stderr, "GTKWAVE | the Tcl shared object file.\n");
+	exit(255);
+	}
+#else
+GLOBALS->interp = Tcl_CreateInterp();
+#endif
+}
+
+
 void make_tcl_interpreter(char *argv[])
 {
 int i;
@@ -2430,15 +2634,19 @@ char commandName[128];
 GtkItemFactoryEntry *ife;
 int num_menu_items;
 
-Tcl_FindExecutable(argv[0]);
+#ifndef WAVE_TCL_STUBIFY
+ Tcl_FindExecutable(argv[0]);
+#endif
 
-GLOBALS->interp = Tcl_CreateInterp();
+ set_globals_interp(argv[0], 0);
 
+#ifndef WAVE_TCL_STUBIFY
 if (TCL_OK != Tcl_Init(GLOBALS->interp)) 
 	{
    	fprintf(stderr, "GTKWAVE | Tcl_Init error: %s\n", Tcl_GetStringResult (GLOBALS->interp));
    	exit(EXIT_FAILURE);
   	}
+#endif
 
 strcpy(commandName, "gtkwave::");
 
@@ -2499,8 +2707,68 @@ void make_tcl_interpreter(char *argv[])
 
 
 /*
- * $Id: tcl_helper.c,v 1.47 2009/02/16 20:55:10 gtkwave Exp $
+ * $Id: tcl_helper.c,v 1.67 2009/12/24 20:55:27 gtkwave Exp $
  * $Log: tcl_helper.c,v $
+ * Revision 1.67  2009/12/24 20:55:27  gtkwave
+ * warnings cleanups
+ *
+ * Revision 1.66  2009/12/22 20:02:19  gtkwave
+ * fixed usage of NULL for a char assign
+ *
+ * Revision 1.65  2009/12/16 17:41:21  gtkwave
+ * code + documentation cleanups for --script
+ *
+ * Revision 1.64  2009/12/15 23:40:59  gtkwave
+ * removed old style scripts; also removed tempfiles for Tcl args
+ *
+ * Revision 1.63  2009/12/11 19:48:59  gtkwave
+ * mingw tcl fixes
+ *
+ * Revision 1.62  2009/11/11 16:30:58  gtkwave
+ * changed tcl library ordering, no tk unless --wish
+ *
+ * Revision 1.61  2009/11/05 23:11:09  gtkwave
+ * added EnsureGroupsMatch()
+ *
+ * Revision 1.60  2009/10/26 22:44:01  gtkwave
+ * output style fixes, remove double init for bluespec
+ *
+ * Revision 1.59  2009/10/24 01:51:41  gtkwave
+ * added dynamic loading for tcl/tk via --enable-stubify
+ *
+ * Revision 1.58  2009/10/23 20:10:33  gtkwave
+ * compatibility cleanups with syntax
+ *
+ * Revision 1.57  2009/10/07 16:59:08  gtkwave
+ * move Tcl_CreateInterp to tcl_helper.c to make stubify easier
+ *
+ * Revision 1.56  2009/09/22 13:51:14  gtkwave
+ * warnings fixes
+ *
+ * Revision 1.55  2009/09/15 06:21:07  gtkwave
+ * simpod-style tcl command reintegration
+ *
+ * Revision 1.54  2009/09/14 03:00:08  gtkwave
+ * bluespec code integration
+ *
+ * Revision 1.53  2009/06/08 06:03:47  gtkwave
+ * add fst to dnd filetypes
+ *
+ * Revision 1.52  2009/03/31 18:49:49  gtkwave
+ * removal of warnings under cygwin compile
+ *
+ * Revision 1.51  2009/03/27 04:38:05  gtkwave
+ * working on ergonomics of drag and drop into an empty gui
+ *
+ * Revision 1.50  2009/03/26 23:53:22  gtkwave
+ * added disable_empty_gui rc variable which reverts to old behavior
+ *
+ * Revision 1.49  2009/03/26 20:57:42  gtkwave
+ * added MISSING_FILE support for bringing up gtkwave without a dumpfile
+ *
+ * Revision 1.48  2009/03/24 20:51:53  gtkwave
+ * add static to const qualifier for some declarations to avoid stack push
+ *
  * Revision 1.47  2009/02/16 20:55:10  gtkwave
  * added extload to dnd filetypes.  set window title on tab close
  *
