@@ -23,6 +23,7 @@
 #include "hierpack.h"
 #include "tcl_helper.h"
 
+WAVE_NODEVARTYPE_STR
 
 enum { VIEW_DRAG_INACTIVE, TREE_TO_VIEW_DRAG_ACTIVE, SEARCH_TO_VIEW_DRAG_ACTIVE };
 
@@ -40,11 +41,11 @@ enum { VIEW_DRAG_INACTIVE, TREE_TO_VIEW_DRAG_ACTIVE, SEARCH_TO_VIEW_DRAG_ACTIVE
 /* The signal area is based on a tree view which requires a store model.
    This store model contains the list of signals to be displayed.
 */
-enum { NAME_COLUMN, TREE_COLUMN, N_COLUMNS };
+enum { NAME_COLUMN, TREE_COLUMN, TYPE_COLUMN, N_COLUMNS };
 
 /* list of autocoalesced (synthesized) filter names that need to be freed at some point) */
 
-static void free_afl(void)
+void free_afl(void)
 {
 struct autocoalesce_free_list *at;
 
@@ -76,7 +77,7 @@ return(lastmatch ? lastmatch : nam);
 
 
 /* Fill the store model using current SIG_ROOT and FILTER_STR.  */
-static void
+void
 fill_sig_store (void)
 {
   struct tree *t;
@@ -89,9 +90,16 @@ fill_sig_store (void)
 	{
 	int i = t->which;
 	char *s, *tmp2;
+	int vartype;
 
 	if(i == -1) continue;
 
+	vartype = GLOBALS->facs[i]->n->vartype;
+	if((vartype < 0) || (vartype > ND_VARTYPE_MAX))
+		{
+		vartype = 0;
+		}
+
         if(!GLOBALS->facs[i]->vec_root)
 		{
 		s = t->name;
@@ -127,6 +135,7 @@ fill_sig_store (void)
 			gtk_list_store_set (GLOBALS->sig_store_treesearch_gtk2_c_1, &iter,
 				    NAME_COLUMN, t->name,
 				    TREE_COLUMN, t,
+				    TYPE_COLUMN, vartype_strings[vartype],
 				    -1);
 			}
 			else
@@ -139,6 +148,7 @@ fill_sig_store (void)
 			gtk_list_store_set (GLOBALS->sig_store_treesearch_gtk2_c_1, &iter,
 				    NAME_COLUMN, s,
 				    TREE_COLUMN, t,
+				    TYPE_COLUMN, vartype_strings[vartype],
 				    -1);
 			}
       		}
@@ -152,117 +162,97 @@ fill_sig_store (void)
 	}
 }
 
-
 /*
  * tree open/close handling
  */
-void force_open_tree_node(char *name)
-{
-GtkCTree *ctree = GLOBALS->ctree_main;
-
-if(ctree)
-	{
-	int namlen = strlen(name);
-	char *namecache = wave_alloca(namlen+1);
-	char *name_end = name + namlen - 1;
-	char *zap = name;
-	GtkCTreeNode *node = GLOBALS->any_tree_node;
-	GtkCTreeRow *gctr = GTK_CTREE_ROW(node);
-	int depth = 1;
-
-	strcpy(namecache, name);
-
-	while(gctr->parent)
-		{
-		node = gctr->parent;
-		gctr = GTK_CTREE_ROW(node);
-		} 
-
-	for(;;)
-		{
-		struct tree *t = gctr->row.data;
-
-		while(*zap)
-			{
-			if(*zap != GLOBALS->hier_delimeter)
-				{
-				zap++;
-				}
-				else
-				{
-				*zap = 0;
-				break;
-				}
-			}
-
-		if(!strcmp(t->name, name))
-			{
-			if(zap == name_end)
-				{
-				GtkCTreeNode **nodehist = wave_alloca(depth * sizeof(GtkCTreeNode *));
-				int *exp1 = wave_alloca(depth * sizeof(int));
-				int i = depth-1;
-
-				nodehist[i] = node;
-				exp1[i--] = 1;
-				/* now work backwards up to parent getting the node open/close history*/
-				gctr = GTK_CTREE_ROW(node);
-				while(gctr->parent)
-					{        
-					node = gctr->parent;
-				        gctr = GTK_CTREE_ROW(node);
-					nodehist[i] = node;
-					exp1[i--] = gctr->expanded;
-				        }        
-
-				gtk_clist_freeze(GTK_CLIST(ctree));
-
-				/* fully expand down */
-				for(i=0;i<depth;i++)
-					{
-					gtk_ctree_expand(ctree, nodehist[i]);
-					}
-
-				/* work backwards and close up nodes that were originally closed */
-				for(i=depth-1;i>=0;i--)
-					{
-					if(exp1[i])
-						{
-						gtk_ctree_expand(ctree, nodehist[i]);
-						}
-						else
-						{
-						gtk_ctree_collapse(ctree, nodehist[i]);
-						}
-					}
-
-				gtk_clist_thaw(GTK_CLIST(ctree));
-
-				/* printf("[treeopennode] '%s' ok\n", name); */
-				GLOBALS->open_tree_nodes = xl_insert(namecache, GLOBALS->open_tree_nodes, NULL);
-				return;
-				}
-				else
-				{
-				depth++;
-
-				node = gctr->children;
-				if(!node) break;
-				gctr = GTK_CTREE_ROW(node);
-				if(!gctr) break;
-
-				name = ++zap;
-				continue;
-				}
-			}
-
-		node = gctr->sibling;
-		if(!node) break;
-		gctr = GTK_CTREE_ROW(node);
-		}
-
-	/* printf("[treeopennode] '%s' failed\n", name); */
+int force_open_tree_node(char *name) {
+  GtkCTree *ctree = GLOBALS->ctree_main;
+  int rv = 1 ;			/* can possible open */
+  if(ctree) {
+    int namlen = strlen(name);
+    char *namecache = wave_alloca(namlen+1);
+    char *name_end = name + namlen - 1;
+    char *zap = name;
+    GtkCTreeNode *node = GLOBALS->any_tree_node;
+    GtkCTreeRow *gctr = GTK_CTREE_ROW(node);
+    int depth = 1;
+    
+    strcpy(namecache, name);
+    while(gctr->parent)	{
+      node = gctr->parent;
+      gctr = GTK_CTREE_ROW(node);
+    } 
+    for(;;) {
+      struct tree *t = gctr->row.data;
+      while(*zap) {
+	if(*zap != GLOBALS->hier_delimeter) {
+	  zap++;
 	}
+	else {
+	  *zap = 0;
+	  break;
+	}
+      }
+      if(!strcmp(t->name, name)) {
+	if(zap == name_end) {
+	  GtkCTreeNode **nodehist = wave_alloca(depth * sizeof(GtkCTreeNode *));
+	  int *exp1 = wave_alloca(depth * sizeof(int));
+	  int i = depth-1;
+	  nodehist[i] = node;
+	  exp1[i--] = 1;
+	  /* now work backwards up to parent getting the node open/close history*/
+	  gctr = GTK_CTREE_ROW(node);
+	  while(gctr->parent) {        
+	    node = gctr->parent;
+	    gctr = GTK_CTREE_ROW(node);
+	    nodehist[i] = node;
+	    exp1[i--] = gctr->expanded;
+	  }        
+	  gtk_clist_freeze(GTK_CLIST(ctree));
+	  /* fully expand down */
+	  for(i=0;i<depth;i++) {
+	    gtk_ctree_expand(ctree, nodehist[i]);
+	  }
+	  /* work backwards and close up nodes that were originally closed */
+	  for(i=depth-1;i>=0;i--) {
+	    if(exp1[i]) {
+	      gtk_ctree_expand(ctree, nodehist[i]);
+	    }
+	    else {
+	      gtk_ctree_collapse(ctree, nodehist[i]);
+	    }
+	  }
+	  gtk_clist_thaw(GTK_CLIST(ctree));
+
+	  gtk_ctree_node_moveto(ctree, nodehist[depth-1],
+				depth /*column*/,
+				0.5 /*row_align*/,
+				0.5 /*col_align*/);
+	  /* printf("[treeopennode] '%s' ok\n", name); */
+	  rv = 0 ;		/* opened */
+	  GLOBALS->open_tree_nodes = xl_insert(namecache, GLOBALS->open_tree_nodes, NULL);
+	  return rv;
+	}
+	else {
+	  depth++;
+	  node = gctr->children;
+	  if(!node) break;
+	  gctr = GTK_CTREE_ROW(node);
+	  if(!gctr) break;
+	  name = ++zap;
+	  continue;
+	}
+      }
+      node = gctr->sibling;
+      if(!node) break;
+      gctr = GTK_CTREE_ROW(node);
+    }
+    
+    /* printf("[treeopennode] '%s' failed\n", name); */
+  } else {
+    rv = -1 ;			/* tree does not exist */
+  }
+  return rv ;
 }
 
 void dump_open_tree_nodes(FILE *wave, xl_Tree *t)
@@ -1148,7 +1138,7 @@ do_tooltips:
 
 
     /* Signal names.  */
-    GLOBALS->sig_store_treesearch_gtk2_c_1 = gtk_list_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_POINTER);
+    GLOBALS->sig_store_treesearch_gtk2_c_1 = gtk_list_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_STRING);
     GLOBALS->sig_root_treesearch_gtk2_c_1 = GLOBALS->treeroot;
     fill_sig_store ();
 
@@ -1163,6 +1153,23 @@ do_tooltips:
 	GtkTreeViewColumn *column;
 
 	renderer = gtk_cell_renderer_text_new ();
+
+	switch(GLOBALS->loaded_file_type)
+		{
+		case FST_FILE:
+		case VCD_FILE:
+		case VCD_RECODER_FILE:
+		case DUMPLESS_FILE:
+					column = gtk_tree_view_column_new_with_attributes ("Type",
+							   renderer,
+							   "text", TYPE_COLUMN,
+							   NULL);
+					gtk_tree_view_append_column (GTK_TREE_VIEW (sig_view), column);
+					break;
+		default:
+			 		break;
+		}
+
 	column = gtk_tree_view_column_new_with_attributes ("Signals",
 							   renderer,
 							   "text", NAME_COLUMN,
@@ -1383,7 +1390,7 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
 
 
     /* Signal names.  */
-    GLOBALS->sig_store_treesearch_gtk2_c_1 = gtk_list_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_POINTER);
+    GLOBALS->sig_store_treesearch_gtk2_c_1 = gtk_list_store_new (N_COLUMNS, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_STRING);
     GLOBALS->sig_root_treesearch_gtk2_c_1 = GLOBALS->treeroot;
     fill_sig_store ();
 
@@ -1398,13 +1405,29 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
 	GtkTreeViewColumn *column;
 
 	renderer = gtk_cell_renderer_text_new ();
+
+	switch(GLOBALS->loaded_file_type)
+		{
+		case FST_FILE:
+		case VCD_FILE:
+		case VCD_RECODER_FILE:
+		case DUMPLESS_FILE:
+					column = gtk_tree_view_column_new_with_attributes ("Type",
+							   renderer,
+							   "text", TYPE_COLUMN,
+							   NULL);
+					gtk_tree_view_append_column (GTK_TREE_VIEW (sig_view), column);
+					break;
+		default:
+					break;
+		}
+
 	column = gtk_tree_view_column_new_with_attributes ("Signals",
 							   renderer,
 							   "text", NAME_COLUMN,
 							   NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (sig_view), column);
 
-
 	/* Setup the selection handler */
 	GLOBALS->sig_selection_treesearch_gtk2_c_1 = gtk_tree_view_get_selection (GTK_TREE_VIEW (sig_view));
 	gtk_tree_selection_set_mode (GLOBALS->sig_selection_treesearch_gtk2_c_1, GTK_SELECTION_MULTIPLE);
@@ -2025,8 +2048,26 @@ void dnd_setup(GtkWidget *src, GtkWidget *w, int enable_receive)
 }
 
 /*
- * $Id: treesearch_gtk2.c,v 1.35 2009/01/21 02:24:15 gtkwave Exp $
+ * $Id: treesearch_gtk2.c,v 1.41 2009/09/28 05:58:05 gtkwave Exp $
  * $Log: treesearch_gtk2.c,v $
+ * Revision 1.41  2009/09/28 05:58:05  gtkwave
+ * changes to support signal_change_list
+ *
+ * Revision 1.40  2009/09/20 21:45:50  gtkwave
+ * tree force open node handling changed for tcl
+ *
+ * Revision 1.39  2009/07/23 20:00:55  gtkwave
+ * added type info to signal window mouseover
+ *
+ * Revision 1.38  2009/07/06 21:41:36  gtkwave
+ * evcd support issues
+ *
+ * Revision 1.37  2009/06/29 18:16:23  gtkwave
+ * adding framework for module type annotation on inner tree nodes
+ *
+ * Revision 1.36  2009/06/27 23:10:32  gtkwave
+ * added display of type info for variables in tree view
+ *
  * Revision 1.35  2009/01/21 02:24:15  gtkwave
  * gtk1 compile fixes, ensure ctree_main is available for force_open_tree_node
  *
