@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2008.
+ * Copyright (c) Tony Bybell 1999-2009.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -50,6 +50,17 @@ static void evcd_strcpy(char *dst, char *src);
 
 /******************************************************************/
 
+static void malform_eof_fix(void)
+{
+if(feof(GLOBALS->vcd_handle_vcd_c_1))
+        {
+        memset(GLOBALS->vcdbuf_vcd_c_1, ' ', VCD_BSIZ);
+        GLOBALS->vst_vcd_c_1=GLOBALS->vend_vcd_c_1;
+        }
+}
+
+/**/
+
 void strcpy_vcdalt(char *too, char *from, char delim)
 {
 char ch;
@@ -334,13 +345,24 @@ if(GLOBALS->vcd_fsiz_vcd_c_1)
 	splash_sync(GLOBALS->vcdbyteno_vcd_c_1, GLOBALS->vcd_fsiz_vcd_c_1); /* gnome 2.18 seems to set errno so splash moved here... */
 	}
 
-return((int)(*(GLOBALS->vst_vcd_c_1++)));
+return((int)(*GLOBALS->vst_vcd_c_1));
 }
 
-static signed char getch() {
-  return ((GLOBALS->vst_vcd_c_1!=GLOBALS->vend_vcd_c_1)?((int)(*(GLOBALS->vst_vcd_c_1++))):(getch_fetch()));
+
+static signed char getch(void) {
+  signed char ch = ((GLOBALS->vst_vcd_c_1!=GLOBALS->vend_vcd_c_1)?((int)(*GLOBALS->vst_vcd_c_1)):(getch_fetch()));
+  GLOBALS->vst_vcd_c_1++;
+  return(ch);
 }
 
+static signed char getch_peek(void) {
+  signed char ch = ((GLOBALS->vst_vcd_c_1!=GLOBALS->vend_vcd_c_1)?((int)(*GLOBALS->vst_vcd_c_1)):(getch_fetch()));
+  /* no increment */
+  return(ch);
+}
+
+
+
 static int getch_patched(void)
 {
 char ch;
@@ -524,7 +546,20 @@ for(GLOBALS->yytext_vcd_c_1[len++]=ch;;GLOBALS->yytext_vcd_c_1[len++]=ch)
 		{
 		GLOBALS->yytext_vcd_c_1=(char *)realloc_2(GLOBALS->yytext_vcd_c_1, (GLOBALS->T_MAX_STR_vcd_c_1=GLOBALS->T_MAX_STR_vcd_c_1*2)+1);
 		}
-	ch=getch();
+
+        ch=getch();
+        if(ch==' ')
+                {
+                signed char ch2;
+                if(match_kw) break;
+                if((ch2 = getch_peek()) == '[')
+                        {
+                        ch = getch();
+                        GLOBALS->varsplit_vcd_c_1=GLOBALS->yytext_vcd_c_1+len;  /* keep looping so we get the *last* one */
+                        continue;
+                        }
+                }
+
 	if((ch==' ')||(ch=='\t')||(ch=='\n')||(ch=='\r')||(ch<0)) break;
 	if((ch=='[')&&(GLOBALS->yytext_vcd_c_1[0]!='\\'))
 		{
@@ -707,33 +742,19 @@ switch(GLOBALS->yytext_vcd_c_1[0])
 			if(!v)
 				{
 				fprintf(stderr,"Near byte %d, Unknown VCD identifier: '%s'\n",(int)(GLOBALS->vcdbyteno_vcd_c_1+(GLOBALS->vst_vcd_c_1-GLOBALS->vcdbuf_vcd_c_1)),GLOBALS->yytext_vcd_c_1+1);
+				malform_eof_fix();
 				}
 				else
 				{
-				if(v->vartype!=V_EVENT)
-					{
-					v->value[0]=GLOBALS->yytext_vcd_c_1[0];
-					DEBUG(fprintf(stderr,"%s = '%c'\n",v->name,v->value[0]));
-					add_histent(GLOBALS->current_time_vcd_c_1,v->narray[0],v->value[0],1, NULL);
-					}
-					else
-					{
-					v->value[0]=(GLOBALS->dumping_off_vcd_c_1)?'x':'1'; /* only '1' is relevant */
-					if(GLOBALS->current_time_vcd_c_1!=(v->ev->last_event_time+1))
-						{
-						/* dump degating event */
-						DEBUG(fprintf(stderr,"#"TTFormat" %s = '%c' (event)\n",v->ev->last_event_time+1,v->name,'0'));
-						add_histent(v->ev->last_event_time+1,v->narray[0],'0',1, NULL);
-						}
-					DEBUG(fprintf(stderr,"%s = '%c' (event)\n",v->name,v->value[0]));
-					add_histent(GLOBALS->current_time_vcd_c_1,v->narray[0],v->value[0],1, NULL);
-					v->ev->last_event_time=GLOBALS->current_time_vcd_c_1;
-					}
+				v->value[0]=GLOBALS->yytext_vcd_c_1[0];
+				DEBUG(fprintf(stderr,"%s = '%c'\n",v->name,v->value[0]));
+				add_histent(GLOBALS->current_time_vcd_c_1,v->narray[0],v->value[0],1, NULL);
 				}
 			}
 			else
 			{
 			fprintf(stderr,"Near byte %d, Malformed VCD identifier\n", (int)(GLOBALS->vcdbyteno_vcd_c_1+(GLOBALS->vst_vcd_c_1-GLOBALS->vcdbuf_vcd_c_1)));
+			malform_eof_fix();
 			}
 		break;
 
@@ -751,6 +772,7 @@ switch(GLOBALS->yytext_vcd_c_1[0])
 			{
 			fprintf(stderr,"Near byte %d, Unknown identifier: '%s'\n",(int)(GLOBALS->vcdbyteno_vcd_c_1+(GLOBALS->vst_vcd_c_1-GLOBALS->vcdbuf_vcd_c_1)), GLOBALS->yytext_vcd_c_1);
 			free_2(vector);
+			malform_eof_fix();
 			}
 			else
 			{
@@ -772,6 +794,7 @@ switch(GLOBALS->yytext_vcd_c_1[0])
 					{
 					fprintf(stderr,"Near byte %d, Unknown identifier: '%s'\n",(int)(GLOBALS->vcdbyteno_vcd_c_1+(GLOBALS->vst_vcd_c_1-GLOBALS->vcdbuf_vcd_c_1)), GLOBALS->yytext_vcd_c_1);
 					free_2(d);
+					malform_eof_fix();
 					}
 					else
 					{
@@ -845,6 +868,7 @@ switch(GLOBALS->yytext_vcd_c_1[0])
 			{
 			fprintf(stderr,"Near byte %d, Unknown identifier: '%s'\n",(int)(GLOBALS->vcdbyteno_vcd_c_1+(GLOBALS->vst_vcd_c_1-GLOBALS->vcdbuf_vcd_c_1)), GLOBALS->yytext_vcd_c_1);
 			free_2(vector);
+			malform_eof_fix();
 			}
 			else
 			{
@@ -866,6 +890,7 @@ switch(GLOBALS->yytext_vcd_c_1[0])
 					{
 					fprintf(stderr,"Near byte %d, Unknown identifier: '%s'\n",(int)(GLOBALS->vcdbyteno_vcd_c_1+(GLOBALS->vst_vcd_c_1-GLOBALS->vcdbuf_vcd_c_1)), GLOBALS->yytext_vcd_c_1);
 					free_2(d);
+					malform_eof_fix();
 					}
 					else
 					{
@@ -938,6 +963,7 @@ switch(GLOBALS->yytext_vcd_c_1[0])
 			{
 			fprintf(stderr,"Near byte %d, Unknown identifier: '%s'\n",(int)(GLOBALS->vcdbyteno_vcd_c_1+(GLOBALS->vst_vcd_c_1-GLOBALS->vcdbuf_vcd_c_1)), GLOBALS->yytext_vcd_c_1);
 			free_2(d);
+			malform_eof_fix();
 			}
 			else
 			{
@@ -962,6 +988,7 @@ switch(GLOBALS->yytext_vcd_c_1[0])
 			{
 			fprintf(stderr,"Near byte %d, Unknown identifier: '%s'\n",(int)(GLOBALS->vcdbyteno_vcd_c_1+(GLOBALS->vst_vcd_c_1-GLOBALS->vcdbuf_vcd_c_1)), GLOBALS->yytext_vcd_c_1);
 			free_2(d);
+			malform_eof_fix();
 			}
 			else
 			{
@@ -978,8 +1005,8 @@ switch(GLOBALS->yytext_vcd_c_1[0])
 
 static void evcd_strcpy(char *dst, char *src)
 {
-static char *evcd="DUNZduLHXTlh01?FAaBbCcf";
-static char  *vcd="01xz0101xz0101xzxxxxxxx";
+static const char *evcd="DUNZduLHXTlh01?FAaBbCcf";
+static const char  *vcd="01xz0101xz0101xzxxxxxxz";
 
 char ch;
 int i;
@@ -1007,6 +1034,7 @@ while((ch=*src))
 static void vcd_parse(void)
 {
 int tok;
+unsigned char ttype;
 
 for(;;)
 	{
@@ -1072,6 +1100,18 @@ for(;;)
 			break;
 		case T_SCOPE:
 			T_GET;
+                                {
+                                switch(GLOBALS->yytext_vcd_c_1[0])
+                                        { 
+                                        case 'm':       ttype = TREE_VCD_ST_MODULE; break;
+                                        case 't':       ttype = TREE_VCD_ST_TASK; break;
+                                        case 'f':       ttype = (GLOBALS->yytext_vcd_c_1[1] == 'u') ? TREE_VCD_ST_FUNCTION : TREE_VCD_ST_FORK; break;
+                                        case 'b':       ttype = TREE_VCD_ST_BEGIN; break;
+                                        default:        ttype = TREE_UNKNOWN;
+                                                        break;
+                                        }
+                                }
+
 			T_GET;
 			if(tok==T_STRING)
 				{
@@ -1080,6 +1120,9 @@ for(;;)
 				s->len=GLOBALS->yylen_vcd_c_1;
 				s->str=(char *)malloc_2(GLOBALS->yylen_vcd_c_1+1);
 				strcpy(s->str, GLOBALS->yytext_vcd_c_1);
+				s->mod_tree_parent = GLOBALS->mod_tree_parent;
+
+				allocate_and_decorate_module_tree_node(ttype, GLOBALS->yytext_vcd_c_1);
 
 				if(GLOBALS->slistcurr)
 					{
@@ -1101,6 +1144,7 @@ for(;;)
 				{
 				struct slist *s;
 
+				GLOBALS->mod_tree_parent = GLOBALS->slistcurr->mod_tree_parent;
 				s=GLOBALS->slistroot;
 				if(!s->next)
 					{
@@ -1124,6 +1168,10 @@ for(;;)
 				build_slisthier();
 				DEBUG(fprintf(stderr, "SCOPE: %s\n",slisthier));
 				}
+				else
+				{
+				GLOBALS->mod_tree_parent = NULL;
+				}
 			sync_end(NULL);
 			break;
 		case T_VAR:
@@ -1154,7 +1202,7 @@ for(;;)
 
 			if(vtok==V_PORT)
 				{
-				vtok=get_vartoken(0);
+				vtok=get_vartoken(1);
 				if(vtok==V_STRING)
 					{
 					v->size=atoi_64(GLOBALS->yytext_vcd_c_1);
@@ -1366,7 +1414,18 @@ for(;;)
 				}
 
 			dumpv:
-                        if(v->size == 0) { v->vartype = V_REAL; } /* MTI fix */
+                        if(v->size == 0)
+                                {
+                                if(v->vartype != V_EVENT)
+                                        {
+                                        v->vartype = V_REAL;
+                                        }
+                                        else
+                                        {
+                                        v->size = 1;
+                                        }
+
+                                } /* MTI fix */
 
 			if((v->vartype==V_REAL)||((GLOBALS->convert_to_reals)&&((v->vartype==V_INTEGER)||(v->vartype==V_PARAMETER))))
 				{
@@ -1430,6 +1489,7 @@ for(;;)
 					v->narray[0]=(struct Node *)calloc_2(1,sizeof(struct Node));
 					v->narray[0]->head.time=-1;
 					v->narray[0]->head.v.h_val=AN_X;
+					set_vcd_vartype(v, v->narray[0]);
 					}
 					else
 					{
@@ -1440,20 +1500,18 @@ for(;;)
 						v->narray[i]=(struct Node *)calloc_2(1,sizeof(struct Node));
 						v->narray[i]->head.time=-1;
 						v->narray[i]->head.v.h_val=AN_X;
+						if(i == 0)
+							{
+							set_vcd_vartype(v, v->narray[0]);
+							}
+							else
+							{
+							v->narray[i]->vartype = v->narray[0]->vartype;
+							}
 						}
 					}
 				}
 
-			if(v->vartype==V_EVENT)
-				{
-				struct queuedevent *q;
-				v->ev=q=(struct queuedevent *)calloc_2(1,sizeof(struct queuedevent));
-				q->sym=v;
-				q->last_event_time=-1;		
-				q->next=GLOBALS->queuedevents_vcd_c_1;
-				GLOBALS->queuedevents_vcd_c_1=q;		
-				}
-
 			if(!GLOBALS->vcdsymroot_vcd_c_1)
 				{
 				GLOBALS->vcdsymroot_vcd_c_1=GLOBALS->vcdsymcurr_vcd_c_1=v;
@@ -1675,8 +1733,8 @@ if(!n->curr)
         if((ch=='w')||(ch=='W')) heval=AN_W; else
         if((ch=='l')||(ch=='L')) heval=AN_L; else
         /* if(ch=='-') */        heval=AN_DASH;		/* default */
-	
-	if((n->curr->v.h_val!=heval)||(tim==GLOBALS->start_time_vcd_c_1)||(GLOBALS->vcd_preserve_glitches)) /* same region == go skip */ 
+
+	if((n->curr->v.h_val!=heval)||(tim==GLOBALS->start_time_vcd_c_1)||(n->vartype==ND_VCD_EVENT)||(GLOBALS->vcd_preserve_glitches)) /* same region == go skip */ 
         	{
 		if(n->curr->time==tim)
 			{
@@ -1878,26 +1936,42 @@ switch(ch)
 }
 
 
+void set_vcd_vartype(struct vcdsymbol *v, nptr n)
+{
+unsigned char nvt;
+
+switch(v->vartype)
+	{
+        case V_EVENT:           nvt = ND_VCD_EVENT; break;
+        case V_PARAMETER:       nvt = ND_VCD_PARAMETER; break;
+        case V_INTEGER:         nvt = ND_VCD_INTEGER; break;
+        case V_REAL:            nvt = ND_VCD_REAL; break;
+        case V_REG:             nvt = ND_VCD_REG; break;
+        case V_SUPPLY0:         nvt = ND_VCD_SUPPLY0; break;
+        case V_SUPPLY1:         nvt = ND_VCD_SUPPLY1; break;
+        case V_TIME:            nvt = ND_VCD_TIME; break;
+        case V_TRI:             nvt = ND_VCD_TRI; break;
+        case V_TRIAND:          nvt = ND_VCD_TRIAND; break;
+        case V_TRIOR:           nvt = ND_VCD_TRIOR; break;
+        case V_TRIREG:          nvt = ND_VCD_TRIREG; break;
+        case V_TRI0:            nvt = ND_VCD_TRI0; break;
+        case V_TRI1:            nvt = ND_VCD_TRI1; break;
+        case V_WAND:            nvt = ND_VCD_WAND; break;
+        case V_WIRE:            nvt = ND_VCD_WIRE; break;
+        case V_WOR:             nvt = ND_VCD_WOR; break;
+        case V_PORT:            nvt = ND_VCD_PORT; break;
+        default:                nvt = ND_UNSPECIFIED_DEFAULT; break;
+	}
+n->vartype = nvt;
+}
+
+
 static void add_tail_histents(void)
 {
 int j;
 struct vcdsymbol *v;
 
-/* dump out any pending events 1st */
-struct queuedevent *q;
-q=GLOBALS->queuedevents_vcd_c_1;
-while(q)
-	{	
-	v=q->sym;
-	if(GLOBALS->current_time_vcd_c_1!=(v->ev->last_event_time+1))
-		{
-		/* dump degating event */
-		DEBUG(fprintf(stderr,"#"TTFormat" %s = '%c' (event)\n",v->ev->last_event_time+1,v->name,'0'));
-		add_histent(v->ev->last_event_time+1,v->narray[0],'0',1, NULL);	
-		}
-	q=q->next;
-	}
-
+/* dump out any pending events 1st (removed) */
 /* then do 'x' trailers */
 
 v=GLOBALS->vcdsymroot_vcd_c_1;
@@ -2261,7 +2335,7 @@ if(GLOBALS->escaped_names_found_vcd_c_1)
                 }
 	}
 }                       
-treegraft(GLOBALS->treeroot);
+treegraft(&GLOBALS->treeroot);
 treesort(GLOBALS->treeroot, NULL);
 
 if(GLOBALS->escaped_names_found_vcd_c_1) 
@@ -2293,7 +2367,6 @@ while(v)
 	if(v->name) free_2(v->name);
 	if(v->id) free_2(v->id);
 	if(v->value) free_2(v->value);
-	if(v->ev) free_2(v->ev);
 	if(v->narray) free_2(v->narray);
 	vt=v;
 	v=v->next;
@@ -2312,15 +2385,16 @@ while(s)
 	}
 
 GLOBALS->slistroot=GLOBALS->slistcurr=NULL; GLOBALS->slisthier_len=0;
-GLOBALS->queuedevents_vcd_c_1=NULL; /* deallocated in the symbol stuff */
 
 if(GLOBALS->vcd_is_compressed_vcd_c_1)
 	{
 	pclose(GLOBALS->vcd_handle_vcd_c_1);
+	GLOBALS->vcd_handle_vcd_c_1 = NULL;
 	}
 	else
 	{
 	fclose(GLOBALS->vcd_handle_vcd_c_1);
+	GLOBALS->vcd_handle_vcd_c_1 = NULL;
 	}
 
 if(GLOBALS->yytext_vcd_c_1)
@@ -2441,12 +2515,6 @@ if(GLOBALS->vcd_is_compressed_vcd_c_1)
 	GLOBALS->vcd_fsiz_vcd_c_1 = 0;
 	}
 
-vcd_build_symbols();
-vcd_sortfacs();
-vcd_cleanup();
-
-getch_free();		/* free membuff for vcd getch buffer */
-
 GLOBALS->min_time=GLOBALS->start_time_vcd_c_1*GLOBALS->time_scale;
 GLOBALS->max_time=GLOBALS->end_time_vcd_c_1*GLOBALS->time_scale;
 
@@ -2456,6 +2524,12 @@ if((GLOBALS->min_time==GLOBALS->max_time)||(GLOBALS->max_time==0))
         vcd_exit(255);
         }
 
+vcd_build_symbols();
+vcd_sortfacs();
+vcd_cleanup();
+
+getch_free();		/* free membuff for vcd getch buffer */
+
 if(GLOBALS->blackout_regions)
         {
         struct blackout_region_t *bt = GLOBALS->blackout_regions;
@@ -2475,8 +2549,38 @@ return(GLOBALS->max_time);
 /*******************************************************************************/
 
 /*
- * $Id: vcd.c,v 1.12 2008/12/25 03:52:32 gtkwave Exp $
+ * $Id: vcd.c,v 1.22 2009/08/28 19:58:42 gtkwave Exp $
  * $Log: vcd.c,v $
+ * Revision 1.22  2009/08/28 19:58:42  gtkwave
+ * added malform_eof_fix
+ *
+ * Revision 1.21  2009/07/07 19:46:03  gtkwave
+ * make evcd->vcd conversion table const
+ *
+ * Revision 1.20  2009/07/07 15:48:37  gtkwave
+ * EVCD "f" value fix (should be z not x)
+ *
+ * Revision 1.19  2009/07/06 21:41:36  gtkwave
+ * evcd support issues
+ *
+ * Revision 1.18  2009/07/02 18:50:47  gtkwave
+ * decorate VCD module trees with type info, add move to front to buildname
+ *
+ * Revision 1.17  2009/07/01 07:39:12  gtkwave
+ * decorating hierarchy tree with module type info
+ *
+ * Revision 1.16  2009/06/25 21:21:12  gtkwave
+ * crash fix for zero bit wide events
+ *
+ * Revision 1.15  2009/06/25 18:31:19  gtkwave
+ * added event types for VCD+FST and impulse arrows on event types
+ *
+ * Revision 1.14  2009/04/30 01:30:53  gtkwave
+ * VCD parser fix for double subscripted nets
+ *
+ * Revision 1.13  2009/03/25 09:20:26  gtkwave
+ * fixing reloader crashes in vcd_build_symbols if times is zero
+ *
  * Revision 1.12  2008/12/25 03:52:32  gtkwave
  * -Wshadow warning fixes
  *
