@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2006.
+ * Copyright (c) Tony Bybell 1999-2009.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -60,6 +60,9 @@ enum VarTypes { V_EVENT, V_PARAMETER,
                 V_END, V_LB, V_COLON, V_RB, V_STRING };
 #endif
 
+/* for vcd_recoder.c */
+enum FastloadState  { VCD_FSL_NONE, VCD_FSL_WRITE, VCD_FSL_READ };
+
 TimeType vcd_main(char *fname);
 TimeType vcd_recoder_main(char *fname);
 
@@ -78,6 +81,8 @@ struct slist
 struct slist *next;
 char *str;
 int len;
+
+struct tree *mod_tree_parent;
 };
 
 
@@ -94,23 +99,12 @@ unsigned char vartype;
 int msi, lsi;
 int size;
 char *value;
-struct queuedevent *ev; /* only if vartype==V_EVENT */
 struct Node **narray;
 hptr         *tr_array;   /* points to synthesized trailers (which can move) */
 hptr         *app_array;   /* points to hptr to append to (which can move) */
 };
 
 
-struct queuedevent
-{
-struct queuedevent *next;
-struct vcdsymbol *sym;
-TimeType last_event_time;    /* make +1 == 0 if there's not an event there too */
-};
-
-
-
-
 char *build_slisthier(void);
 void append_vcd_slisthier(char *str);
 
@@ -118,7 +112,7 @@ struct HistEnt *histent_calloc(void);
 void strcpy_vcdalt(char *too, char *from, char delim);
 int strcpy_delimfix(char *too, char *from);
 void vcd_sortfacs(void);
-
+void set_vcd_vartype(struct vcdsymbol *v, nptr n);
 
 void vcd_import_masked(void);
 void vcd_set_fac_process_mask(nptr np);
@@ -129,8 +123,17 @@ int vcd_keyword_code(const char *s, unsigned int len);
 #endif
 
 /*
- * $Id: vcd.h,v 1.3 2008/07/18 17:27:01 gtkwave Exp $
+ * $Id: vcd.h,v 1.6 2009/07/02 18:50:47 gtkwave Exp $
  * $Log: vcd.h,v $
+ * Revision 1.6  2009/07/02 18:50:47  gtkwave
+ * decorate VCD module trees with type info, add move to front to buildname
+ *
+ * Revision 1.5  2009/06/25 18:31:19  gtkwave
+ * added event types for VCD+FST and impulse arrows on event types
+ *
+ * Revision 1.4  2009/03/05 16:17:56  gtkwave
+ * added fastload option
+ *
  * Revision 1.3  2008/07/18 17:27:01  gtkwave
  * adding hierpack code
  *
