@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2007.
+ * Copyright (c) Tony Bybell 1999-2009.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -41,6 +41,10 @@
 #include <unistd.h>
 #endif
 
+#ifdef __MINGW32__
+#include <windows.h>
+#endif
+
 #undef VCD_BSEARCH_IS_PERFECT		/* bsearch is imperfect under linux, but OK under AIX */
 
 static hptr add_histent_p(TimeType time, struct Node *n, char ch, int regadd, char *vector);
@@ -70,11 +74,11 @@ return((unsigned int)((unsigned char)*p));
 
 unsigned int get_32(char *p)
 {
-unsigned int rc =
-        (get_8(p++) << 24) |
-        (get_8(p++) << 16) |
-        (get_8(p++) <<  8) |
-        (get_8(p)   <<  0) ;
+unsigned int rc;
+rc =    (get_8(p++) << 24) ;
+rc|=    (get_8(p++) << 16) ;
+rc|=    (get_8(p++) <<  8) ;
+rc|=    (get_8(p)   <<  0) ;
 
 return(rc);
 }
@@ -338,11 +342,19 @@ GLOBALS->vend_vcd_partial_c_2=(GLOBALS->vst_vcd_partial_c_2=GLOBALS->vcdbuf_vcd_
 
 if(!rd) return(-1);
 
-return((int)(*(GLOBALS->vst_vcd_partial_c_2++)));
+return((int)(*GLOBALS->vst_vcd_partial_c_2));
 }
 
-static signed char getch() {
-  return ((GLOBALS->vst_vcd_partial_c_2!=GLOBALS->vend_vcd_partial_c_2)?((int)(*(GLOBALS->vst_vcd_partial_c_2++))):(getch_fetch()));
+static signed char getch(void) {
+  signed char ch = ((GLOBALS->vst_vcd_partial_c_2!=GLOBALS->vend_vcd_partial_c_2)?((int)(*GLOBALS->vst_vcd_partial_c_2)):(getch_fetch()));
+  if(ch>=0) { GLOBALS->vst_vcd_partial_c_2++; };
+  return(ch);
+}
+
+static signed char getch_peek(void) {
+  signed char ch = ((GLOBALS->vst_vcd_partial_c_2!=GLOBALS->vend_vcd_partial_c_2)?((int)(*GLOBALS->vst_vcd_partial_c_2)):(getch_fetch()));
+  /* no increment */
+  return(ch);
 }
 
 
@@ -529,7 +541,20 @@ for(GLOBALS->yytext_vcd_partial_c_2[len++]=ch;;GLOBALS->yytext_vcd_partial_c_2[l
 		{
 		GLOBALS->yytext_vcd_partial_c_2=(char *)realloc_2(GLOBALS->yytext_vcd_partial_c_2, (GLOBALS->T_MAX_STR_vcd_partial_c_2=GLOBALS->T_MAX_STR_vcd_partial_c_2*2)+1);
 		}
+
 	ch=getch();
+        if(ch==' ')
+                {
+                signed char ch2;
+                if(match_kw) break;
+                if((ch2 = getch_peek()) == '[')
+                        {
+                        ch = getch();
+                        GLOBALS->varsplit_vcd_partial_c_2=GLOBALS->yytext_vcd_partial_c_2+len; /* keep looping so we get the *last* one */
+                        continue;
+                        }
+                }
+
 	if((ch==' ')||(ch=='\t')||(ch=='\n')||(ch=='\r')||(ch<0)) break;
 	if((ch=='[')&&(GLOBALS->yytext_vcd_partial_c_2[0]!='\\'))
 		{
@@ -651,39 +676,14 @@ switch(GLOBALS->yytext_vcd_partial_c_2[0])
 				}
 				else
 				{
-				if(v->vartype!=V_EVENT)
-					{
-					v->value[0]=GLOBALS->yytext_vcd_partial_c_2[0];
-					DEBUG(fprintf(stderr,"%s = '%c'\n",v->name,v->value[0]));
+				v->value[0]=GLOBALS->yytext_vcd_partial_c_2[0];
+				DEBUG(fprintf(stderr,"%s = '%c'\n",v->name,v->value[0]));
 
-					v->narray[0]->curr = v->app_array[0];
-					hsuf = add_histent_p(GLOBALS->current_time_vcd_partial_c_2,v->narray[0],v->value[0],1, NULL);
-					v->app_array[0] = v->narray[0]->curr;
-					v->narray[0]->curr->next = v->tr_array[0];
-					if(v->narray[0]->harray) { free_2(v->narray[0]->harray); v->narray[0]->harray = NULL; }
-
-					}
-					else
-					{
-					v->value[0]=(GLOBALS->dumping_off_vcd_partial_c_2)?'x':'1'; /* only '1' is relevant */
-					if(GLOBALS->current_time_vcd_partial_c_2!=(v->ev->last_event_time+1))
-						{
-						/* dump degating event */
-						DEBUG(fprintf(stderr,"#"TTFormat" %s = '%c' (event)\n",v->ev->last_event_time+1,v->name,'0'));
-						v->narray[0]->curr = v->app_array[0];
-						add_histent_p(v->ev->last_event_time+1,v->narray[0],'0',1, NULL);
-						v->app_array[0] = v->narray[0]->curr;
-						v->narray[0]->curr->next = v->tr_array[0];
-						}
-					DEBUG(fprintf(stderr,"%s = '%c' (event)\n",v->name,v->value[0]));
-					v->narray[0]->curr = v->app_array[0];
-					add_histent_p(GLOBALS->current_time_vcd_partial_c_2,v->narray[0],v->value[0],1, NULL);
-					v->app_array[0] = v->narray[0]->curr;
-					v->narray[0]->curr->next = v->tr_array[0];
-					if(v->narray[0]->harray) { free_2(v->narray[0]->harray); v->narray[0]->harray = NULL; }
-
-					v->ev->last_event_time=GLOBALS->current_time_vcd_partial_c_2;
-					}
+				v->narray[0]->curr = v->app_array[0];
+				hsuf = add_histent_p(GLOBALS->current_time_vcd_partial_c_2,v->narray[0],v->value[0],1, NULL);
+				v->app_array[0] = v->narray[0]->curr;
+				v->narray[0]->curr->next = v->tr_array[0];
+				if(v->narray[0]->harray) { free_2(v->narray[0]->harray); v->narray[0]->harray = NULL; }
 				}
 			}
 			else
@@ -973,8 +973,8 @@ switch(GLOBALS->yytext_vcd_partial_c_2[0])
 
 static void evcd_strcpy(char *dst, char *src)
 {
-static char *evcd="DUNZduLHXTlh01?FAaBbCcf";
-static char  *vcd="01xz0101xz0101xzxxxxxxx";
+static const char *evcd="DUNZduLHXTlh01?FAaBbCcf";
+static const char  *vcd="01xz0101xz0101xzxxxxxxz";
 
 char ch;
 int i;
@@ -1002,6 +1002,7 @@ while((ch=*src))
 static void vcd_parse(void)
 {
 int tok;
+unsigned char ttype;
 
 for(;;)
 	{
@@ -1067,6 +1068,17 @@ for(;;)
 			break;
 		case T_SCOPE:
 			T_GET;
+                                {   
+                                switch(GLOBALS->yytext_vcd_partial_c_2[0])
+                                        {
+                                        case 'm':       ttype = TREE_VCD_ST_MODULE; break;
+                                        case 't':       ttype = TREE_VCD_ST_TASK; break;
+                                        case 'f':       ttype = (GLOBALS->yytext_vcd_partial_c_2[1] == 'u') ? TREE_VCD_ST_FUNCTION : TREE_VCD_ST_FORK; break;
+                                        case 'b':       ttype = TREE_VCD_ST_BEGIN; break;
+                                        default:        ttype = TREE_UNKNOWN;
+                                                        break;
+                                        }
+                                }
 			T_GET;
 			if(tok==T_STRING)
 				{
@@ -1075,6 +1087,9 @@ for(;;)
 				s->len=GLOBALS->yylen_vcd_partial_c_2;
 				s->str=(char *)malloc_2(GLOBALS->yylen_vcd_partial_c_2+1);
 				strcpy(s->str, GLOBALS->yytext_vcd_partial_c_2);
+				s->mod_tree_parent = GLOBALS->mod_tree_parent;
+
+				allocate_and_decorate_module_tree_node(ttype, GLOBALS->yytext_vcd_partial_c_2);
 
 				if(GLOBALS->slistcurr)
 					{
@@ -1096,6 +1111,7 @@ for(;;)
 				{
 				struct slist *s;
 
+				GLOBALS->mod_tree_parent = GLOBALS->slistcurr->mod_tree_parent;
 				s=GLOBALS->slistroot;
 				if(!s->next)
 					{
@@ -1119,6 +1135,10 @@ for(;;)
 				build_slisthier();
 				DEBUG(fprintf(stderr, "SCOPE: %s\n",slisthier));
 				}
+				else
+				{
+				GLOBALS->mod_tree_parent = NULL;
+				}
 			sync_end(NULL);
 			break;
 		case T_VAR:
@@ -1148,7 +1168,7 @@ for(;;)
 
 			if(vtok==V_PORT)
 				{
-				vtok=get_vartoken(0);
+				vtok=get_vartoken(1);
 				if(vtok==V_STRING)
 					{
 					v->size=atoi_64(GLOBALS->yytext_vcd_partial_c_2);
@@ -1360,7 +1380,18 @@ for(;;)
 				}
 
 			dumpv:
-                        if(v->size == 0) { v->vartype = V_REAL; } /* MTI fix */
+                        if(v->size == 0)
+                                {
+                                if(v->vartype != V_EVENT)
+                                        {
+                                        v->vartype = V_REAL;
+                                        }
+                                        else
+                                        {
+                                        v->size = 1;
+                                        }
+
+                                } /* MTI fix */
 
 			if((v->vartype==V_REAL)||((GLOBALS->convert_to_reals)&&((v->vartype==V_INTEGER)||(v->vartype==V_PARAMETER))))
 				{
@@ -1440,16 +1471,6 @@ for(;;)
 					}
 				}
 
-			if(v->vartype==V_EVENT)
-				{
-				struct queuedevent *q;
-				v->ev=q=(struct queuedevent *)calloc_2(1,sizeof(struct queuedevent));
-				q->sym=v;
-				q->last_event_time=-1;		
-				q->next=GLOBALS->queuedevents_vcd_partial_c_2;
-				GLOBALS->queuedevents_vcd_partial_c_2=q;		
-				}
-
 			if(!GLOBALS->vcdsymroot_vcd_partial_c_2)
 				{
 				GLOBALS->vcdsymroot_vcd_partial_c_2=GLOBALS->vcdsymcurr_vcd_partial_c_2=v;
@@ -1615,7 +1636,7 @@ if(!(rc=n->curr))
         if((ch=='l')||(ch=='L')) heval=AN_L; else
         /* if(ch=='-') */        heval=AN_DASH;		/* default */
 	
-	if((n->curr->v.h_val!=heval)||(tim==GLOBALS->start_time_vcd_partial_c_2)||(GLOBALS->vcd_preserve_glitches)) /* same region == go skip */ 
+	if((n->curr->v.h_val!=heval)||(tim==GLOBALS->start_time_vcd_partial_c_2)||(n->vartype==ND_VCD_EVENT)||(GLOBALS->vcd_preserve_glitches)) /* same region == go skip */ 
         	{
 		if(n->curr->time==tim)
 			{
@@ -1836,6 +1857,7 @@ while(v)
 		d=malloc_2(sizeof(double));
 		*d=1.0;
 		rc = add_histent_p(MAX_HISTENT_TIME-1, v->narray[0], 'g', 0, (char *)d);
+		set_vcd_vartype(v, v->narray[0]);
 		v->app_array[0] = rc;
 		v->tr_array[0] = v->narray[0]->curr;
 		}
@@ -1844,12 +1866,14 @@ while(v)
 	for(j=0;j<v->size;j++)
 		{
 		rc = add_histent_p(MAX_HISTENT_TIME-1, v->narray[j], 'x', 0, NULL);
+		set_vcd_vartype(v, v->narray[j]);
 		v->app_array[j] = rc;
 		v->tr_array[j] = v->narray[j]->curr;
 		}
 	else
 		{
 		rc = add_histent_p(MAX_HISTENT_TIME-1, v->narray[0], 'x', 0, (char *)calloc_2(1,sizeof(char)));
+		set_vcd_vartype(v, v->narray[0]);
 		v->app_array[0] = rc;
 		v->tr_array[0] = v->narray[0]->curr;
 		}
@@ -2157,7 +2181,27 @@ if(!strcmp(fname, "-vcd"))
 	sscanf(fname, "%x", &shmid);	/* passed as a filename */
 	}
 
-#if !defined _MSC_VER && !defined __MINGW32__
+#if !defined _MSC_VER
+#ifdef __MINGW32__
+{
+HANDLE hMapFile;
+char mapName[257];
+
+sprintf(mapName, "shmidcat%d", shmid);
+hMapFile = OpenFileMapping(FILE_MAP_ALL_ACCESS, FALSE, mapName);
+if(hMapFile == NULL)
+	{
+	fprintf(stderr, "Could not attach shared memory map name '%s', exiting.\n", mapName);
+	exit(255);
+	}
+GLOBALS->consume_ptr_vcd_partial_c_1 = GLOBALS->buf_vcd_partial_c_2 = MapViewOfFile(hMapFile, FILE_MAP_ALL_ACCESS, 0, 0, WAVE_PARTIAL_VCD_RING_BUFFER_SIZE);
+if(GLOBALS->consume_ptr_vcd_partial_c_1 == NULL)
+	{
+	fprintf(stderr, "Could not map view of file '%s', exiting.\n", mapName);
+	exit(255);
+	}
+}
+#else
 errno = 0;
 GLOBALS->consume_ptr_vcd_partial_c_1 = GLOBALS->buf_vcd_partial_c_2 = shmat(shmid, NULL, 0);
 if(errno)
@@ -2166,6 +2210,7 @@ if(errno)
 	perror("Why");
 	exit(255);
 	}
+#endif
 #else
 fprintf(stderr, "Interactive VCD mode does not work with Windows, exiting.\n");
 exit(255);
@@ -2334,15 +2379,19 @@ else if(t->interactive_vector_needs_regeneration)
 
 void kick_partial_vcd(void)
 {
-#if !defined _MSC_VER && !defined __MINGW32__
+#if !defined _MSC_VER
 
 if(GLOBALS->partial_vcd)
 	{
+#ifdef __MINGW32__
+	Sleep(10);
+#else
 	struct timeval tv;
 
 	tv.tv_sec = 0; 
 	tv.tv_usec = 1000000 / 100;
 	select(0, NULL, NULL, NULL, &tv);
+#endif
 
 	while(*GLOBALS->consume_ptr_vcd_partial_c_1)
 		{
@@ -2407,8 +2456,35 @@ gtkwave_gtk_main_iteration();
 }
 
 /*
- * $Id: vcd_partial.c,v 1.13 2009/01/12 18:46:00 gtkwave Exp $
+ * $Id: vcd_partial.c,v 1.22 2009/12/22 20:00:41 gtkwave Exp $
  * $Log: vcd_partial.c,v $
+ * Revision 1.22  2009/12/22 20:00:41  gtkwave
+ * warnings fixes
+ *
+ * Revision 1.21  2009/07/07 19:46:03  gtkwave
+ * make evcd->vcd conversion table const
+ *
+ * Revision 1.20  2009/07/07 15:48:37  gtkwave
+ * EVCD "f" value fix (should be z not x)
+ *
+ * Revision 1.19  2009/07/06 21:41:36  gtkwave
+ * evcd support issues
+ *
+ * Revision 1.18  2009/07/02 18:50:47  gtkwave
+ * decorate VCD module trees with type info, add move to front to buildname
+ *
+ * Revision 1.17  2009/06/25 21:21:12  gtkwave
+ * crash fix for zero bit wide events
+ *
+ * Revision 1.16  2009/06/25 18:31:19  gtkwave
+ * added event types for VCD+FST and impulse arrows on event types
+ *
+ * Revision 1.15  2009/04/30 01:30:53  gtkwave
+ * VCD parser fix for double subscripted nets
+ *
+ * Revision 1.14  2009/04/23 04:57:38  gtkwave
+ * ported shmidcat and partial vcd loader function to mingw
+ *
  * Revision 1.13  2009/01/12 18:46:00  gtkwave
  * added marker nail-down during partial vcd w dynamic zoom
  *
