@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2008.
+ * Copyright (c) Tony Bybell 1999-2009.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -30,6 +30,7 @@
  * use gperf for port vartypes  19feb07ajb
  * MTI SV implicit-var fix      05apr07ajb
  * MTI SV len=0 is real var     05apr07ajb
+ * VCD fastloading		05mar09ajb
  */
 #include <config.h>
 #include "globals.h"
@@ -40,6 +41,45 @@
 
 /**/
 
+static void malform_eof_fix(void)
+{
+if(feof(GLOBALS->vcd_handle_vcd_recoder_c_2))
+	{
+        memset(GLOBALS->vcdbuf_vcd_recoder_c_3, ' ', VCD_BSIZ);
+        GLOBALS->vst_vcd_recoder_c_3=GLOBALS->vend_vcd_recoder_c_3;
+        }
+}
+
+/**/
+
+static void vlist_packer_emit_uv64(struct vlist_packer_t **vl, guint64 v)
+{
+guint64 nxt;
+         
+while((nxt = v>>7))
+        {
+	vlist_packer_alloc(*vl, v&0x7f);
+        v = nxt;
+        }
+
+vlist_packer_alloc(*vl, (v&0x7f) | 0x80);
+} 
+
+
+static void vlist_packer_emit_utt(struct vlist_packer_t **vl, UTimeType v)
+{
+UTimeType nxt;
+         
+while((nxt = v>>7))
+        {
+	vlist_packer_alloc(*vl, v&0x7f);
+        v = nxt;
+        }
+
+vlist_packer_alloc(*vl, (v&0x7f) | 0x80);
+} 
+
+
 static void vlist_packer_emit_uv32(struct vlist_packer_t **vl, unsigned int v)
 {
 unsigned int nxt;
@@ -119,7 +159,7 @@ static void vlist_emit_uv32(struct vlist_t **vl, unsigned int v)
 unsigned int nxt;
 char *pnt;
 
-if(GLOBALS->vlist_prepack) { return(vlist_packer_emit_uv32((struct vlist_packer_t **)vl, v)); }
+if(GLOBALS->vlist_prepack) { vlist_packer_emit_uv32((struct vlist_packer_t **)vl, v); return; }
          
 while((nxt = v>>7))
         {
@@ -137,7 +177,7 @@ static void vlist_emit_string(struct vlist_t **vl, char *s)
 {
 char *pnt;
 
-if(GLOBALS->vlist_prepack) { return(vlist_packer_emit_string((struct vlist_packer_t **)vl, s)); }
+if(GLOBALS->vlist_prepack) { vlist_packer_emit_string((struct vlist_packer_t **)vl, s); return; }
 
 while(*s)
 	{
@@ -156,7 +196,7 @@ unsigned int recoded_bit;
 unsigned char which;
 unsigned char accum;
 
-if(GLOBALS->vlist_prepack) { return(vlist_packer_emit_mvl9_string((struct vlist_packer_t **)vl, s)); }
+if(GLOBALS->vlist_prepack) { vlist_packer_emit_mvl9_string((struct vlist_packer_t **)vl, s); return; }
 
 which = accum = 0;
 
@@ -204,6 +244,280 @@ pnt = vlist_alloc(vl, 1);
 *pnt = accum;
 }
 
+/**/
+
+static void write_fastload_time_section(void)
+{
+struct vlist_t *vlist;
+struct vlist_packer_t *vlist_p;
+
+/* emit blackout regions */
+if(GLOBALS->blackout_regions)
+	{
+	struct blackout_region_t *bt = GLOBALS->blackout_regions;
+	unsigned int bcnt = 0;
+	while(bt)
+		{
+		bcnt++;
+		bt = bt->next;
+		}
+
+	vlist_packer_emit_uv32((struct vlist_packer_t **)(void *)&GLOBALS->time_vlist_vcd_recoder_write, bcnt);
+
+	bt = GLOBALS->blackout_regions;
+	while(bt)
+		{
+		vlist_packer_emit_utt((struct vlist_packer_t **)(void *)&GLOBALS->time_vlist_vcd_recoder_write, bt->bstart);
+		vlist_packer_emit_utt((struct vlist_packer_t **)(void *)&GLOBALS->time_vlist_vcd_recoder_write, bt->bend);
+		bt = bt->next;
+		}
+	}
+	else
+	{
+	vlist_packer_emit_uv32((struct vlist_packer_t **)(void *)&GLOBALS->time_vlist_vcd_recoder_write, 0);
+	}
+
+vlist_p = (struct vlist_packer_t *)GLOBALS->time_vlist_vcd_recoder_write;
+vlist_packer_finalize(vlist_p);
+vlist = vlist_p->v;
+free_2(vlist_p);
+GLOBALS->time_vlist_vcd_recoder_write = vlist;
+vlist_freeze(&GLOBALS->time_vlist_vcd_recoder_write);
+}
+
+
+static void write_fastload_header(struct stat *mystat, unsigned int finalize_cnt)
+{
+/* 
+write out the trailer information for vcd fastload...
+
+vcd file size
+vcd last modification time
+number of finalize values
+number of variable-length integer values in the time table (GLOBALS->time_vlist_count_vcd_recoder_c_1)
+GLOBALS->time_vlist_vcd_recoder_write value
+deltas from GLOBALS->time_vlist_vcd_recoder_write and on though stepping through list generated by vlist_emit_finalize()
+*/
+
+struct vlist_packer_t *vlist_p;
+struct vlist_t * vlist_summary_index = ((struct vlist_t *)vlist_packer_create());
+struct vcdsymbol *v = GLOBALS->vcdsymroot_vcd_recoder_c_3;
+guint64 val = (guint64)(unsigned long)GLOBALS->time_vlist_vcd_recoder_write;
+guint64 nval;
+char buf[33];
+char *pnt;
+
+vlist_packer_emit_uv64((struct vlist_packer_t **)(void *)&vlist_summary_index, (guint64)mystat->st_size);
+vlist_packer_emit_uv64((struct vlist_packer_t **)(void *)&vlist_summary_index, (guint64)mystat->st_mtime);
+
+vlist_packer_emit_uv32((struct vlist_packer_t **)(void *)&vlist_summary_index, finalize_cnt);
+vlist_packer_emit_uv64((struct vlist_packer_t **)(void *)&vlist_summary_index, GLOBALS->time_vlist_count_vcd_recoder_c_1);
+
+vlist_packer_emit_uv64((struct vlist_packer_t **)(void *)&vlist_summary_index, val);
+val = 0;
+while(v)
+	{
+	nptr n = v->narray[0];
+	nval = (guint64)(unsigned long)n->mv.mvlfac_vlist;
+
+	vlist_packer_emit_uv64((struct vlist_packer_t **)(void *)&vlist_summary_index, nval - val);
+	val = nval;
+
+	v = v->next;
+	}
+
+vlist_p = (struct vlist_packer_t *)vlist_summary_index;
+vlist_packer_finalize(vlist_p);
+vlist_summary_index = vlist_p->v;
+free_2(vlist_p);
+GLOBALS->time_vlist_vcd_recoder_write = vlist_summary_index;
+vlist_freeze(&vlist_summary_index);
+
+pnt = buf;
+val = (guint64)(unsigned long)vlist_summary_index;
+while((nval = val>>7))
+	{
+	*(pnt++) = (val&0x7f);
+	val = nval;
+	}
+*(pnt++) = ((val&0x7f) | 0x80);
+do
+	{
+	pnt--;
+	fputc((unsigned char)*pnt, GLOBALS->vlist_handle);
+	} while(pnt != buf);
+
+fflush(GLOBALS->vlist_handle);
+}
+
+
+static int read_fastload_body(void)
+{
+char *depacked = GLOBALS->fastload_depacked;
+char *pnt = GLOBALS->fastload_current;
+int rc = 0;
+guint64 v = 0, vprev = 0;
+int shamt = 0;
+unsigned int num_finalize;
+unsigned int num_in_time_table, num_blackout_regions;
+guint64 time_vlist_vcd_recoder_write;
+struct vcdsymbol *vs;
+struct vlist_t *vl;
+unsigned int list_size;
+unsigned int i;
+struct blackout_region_t *bt_head = NULL, *bt_curr = NULL;
+
+v = 0; shamt = 0; do { v |= ((guint64)(*pnt & 0x7f)) << shamt; shamt += 7; } while(!(*(pnt++) & 0x80));
+num_finalize = v;
+
+v = 0; shamt = 0; do { v |= ((guint64)(*pnt & 0x7f)) << shamt; shamt += 7; } while(!(*(pnt++) & 0x80));
+GLOBALS->time_vlist_count_vcd_recoder_c_1 = num_in_time_table = v;
+
+v = 0; shamt = 0; do { v |= ((guint64)(*pnt & 0x7f)) << shamt; shamt += 7; } while(!(*(pnt++) & 0x80));
+time_vlist_vcd_recoder_write = v;
+
+vs=GLOBALS->vcdsymroot_vcd_recoder_c_3;
+while(vs) 
+        {
+        nptr n = vs->narray[0];
+
+	v = 0; shamt = 0; do { v |= ((guint64)(*pnt & 0x7f)) << shamt; shamt += 7; } while(!(*(pnt++) & 0x80));
+	v += vprev;
+	vprev = v;
+
+        n->mv.mvlfac_vlist = (struct vlist_t *)(long)(v);
+	vs = vs->next;
+	}
+
+vlist_packer_decompress_destroy((char *)depacked);
+GLOBALS->fastload_depacked = NULL;
+GLOBALS->fastload_current = NULL;
+
+/* now create the time table */
+vl = (struct vlist_t *)(long)time_vlist_vcd_recoder_write;
+vlist_uncompress(&vl);
+depacked = pnt = (char *)vlist_packer_decompress(vl, &list_size);
+vlist_destroy(vl);
+
+vprev = 0;
+for(i=0;i<num_in_time_table;i++)
+	{
+	TimeType tim;
+	TimeType *tt;
+
+	v = 0; shamt = 0; do { v |= ((guint64)(*pnt & 0x7f)) << shamt; shamt += 7; } while(!(*(pnt++) & 0x80));
+
+	v += vprev;
+	vprev = v;
+
+	tt = vlist_alloc(&GLOBALS->time_vlist_vcd_recoder_c_1, 0);
+        *tt = tim = (TimeType)v;
+
+	if(!i) 
+		{
+		GLOBALS->start_time_vcd_recoder_c_3=tim;
+		}
+
+	GLOBALS->current_time_vcd_recoder_c_3=GLOBALS->end_time_vcd_recoder_c_3=tim;
+	}
+
+/* now process blackout regions */
+v = 0; shamt = 0; do { v |= ((guint64)(*pnt & 0x7f)) << shamt; shamt += 7; } while(!(*(pnt++) & 0x80));
+num_blackout_regions = v;
+
+if(num_blackout_regions)
+	{
+	for(i=0;i<num_blackout_regions;i++)
+		{
+		struct blackout_region_t *bt = calloc_2(1, sizeof(struct blackout_region_t));
+		TimeType tim;
+
+		if(!bt_head)
+			{
+			bt_head = bt_curr = bt;
+			}
+			else
+			{
+			bt_curr->next = bt;
+			bt_curr = bt;
+			}			
+	
+		v = 0; shamt = 0; do { v |= ((guint64)(*pnt & 0x7f)) << shamt; shamt += 7; } while(!(*(pnt++) & 0x80));
+		tim = v;
+		bt->bstart = tim;
+	
+		v = 0; shamt = 0; do { v |= ((guint64)(*pnt & 0x7f)) << shamt; shamt += 7; } while(!(*(pnt++) & 0x80));
+		tim = v;
+		bt->bend = tim;
+		}
+
+	GLOBALS->blackout_regions = bt_head;
+	}
+
+vlist_packer_decompress_destroy((char *)depacked);
+
+return(rc);
+}
+
+static int read_fastload_header(struct stat *st)
+{
+int rc = 0;
+int fs_rc = fseeko(GLOBALS->vlist_handle, 0, SEEK_END);
+off_t ftlen = ftello(GLOBALS->vlist_handle);
+guint64 v = 0;
+int ch;
+int shamt = 0;
+unsigned char *depacked = NULL;
+struct vlist_t *vl;
+unsigned int list_size;
+unsigned char *pnt;
+struct stat mystat;
+int stat_rc = stat(GLOBALS->loaded_file_name, &mystat);
+
+if((fs_rc<0)||(!ftlen))
+	{
+	goto bail;
+	}
+
+do	{
+	ftlen--;
+	fseeko(GLOBALS->vlist_handle, ftlen, SEEK_SET);
+	ch = fgetc(GLOBALS->vlist_handle);
+	if(ch == EOF) { errno = 0; goto bail; }
+	v |= ((guint64)(ch & 0x7f)) << shamt;
+	shamt += 7;
+	} while(!(ch & 0x80));
+
+vl = (struct vlist_t *)(long)v;
+vlist_uncompress(&vl);
+depacked = vlist_packer_decompress(vl, &list_size);
+vlist_destroy(vl);
+
+pnt = depacked;
+v = 0; shamt = 0; do { v |= ((guint64)(*pnt & 0x7f)) << shamt; shamt += 7; } while(!(*(pnt++) & 0x80));
+
+if((stat_rc)||(v != (guint64)mystat.st_size))
+	{
+	goto bail;
+	}
+
+v = 0; shamt = 0; do { v |= ((guint64)(*pnt & 0x7f)) << shamt; shamt += 7; } while(!(*(pnt++) & 0x80));
+
+if(v != (guint64)st->st_mtime)
+	{
+	goto bail;
+	}
+
+rc = 1;
+GLOBALS->fastload_depacked = (char *)depacked;
+GLOBALS->fastload_current = (char *)pnt;
+
+bail:
+if(!rc) vlist_packer_decompress_destroy((char *)depacked);
+return(rc);
+}
+
+/**/
 
 #undef VCD_BSEARCH_IS_PERFECT		/* bsearch is imperfect under linux, but OK under AIX */
 
@@ -395,17 +709,20 @@ if(GLOBALS->numsyms_vcd_recoder_c_3)
 
 /******************************************************************/
 
-static void vlist_emit_finalize(void)
+static unsigned int vlist_emit_finalize(void)
 {
 struct vcdsymbol *v, *vprime;
 struct vlist_t *vlist;
 char vlist_prepack = GLOBALS->vlist_prepack;
+int cnt = 0;
 
 v=GLOBALS->vcdsymroot_vcd_recoder_c_3;
 while(v)
 	{
 	nptr n = v->narray[0];
 
+	set_vcd_vartype(v, n);
+
 	if(n->mv.mvlfac_vlist) 
 		{
 		if(vlist_prepack)
@@ -478,7 +795,10 @@ while(v)
 			}
 		}
 	v=v->next;
+	cnt++;
 	}
+
+return(cnt);
 }
 
 /******************************************************************/
@@ -517,11 +837,19 @@ if(GLOBALS->vcd_fsiz_vcd_recoder_c_2)
 	splash_sync(GLOBALS->vcdbyteno_vcd_recoder_c_3, GLOBALS->vcd_fsiz_vcd_recoder_c_2); /* gnome 2.18 seems to set errno so splash moved here... */
 	}
 
-return((int)(*(GLOBALS->vst_vcd_recoder_c_3++)));
+return((int)(*GLOBALS->vst_vcd_recoder_c_3));
+}
+        
+static signed char getch(void) {
+  signed char ch = (GLOBALS->vst_vcd_recoder_c_3!=GLOBALS->vend_vcd_recoder_c_3)?((int)(*GLOBALS->vst_vcd_recoder_c_3)):(getch_fetch());
+  GLOBALS->vst_vcd_recoder_c_3++;
+  return(ch);
 }
 
-static signed char getch() {
-  return ((GLOBALS->vst_vcd_recoder_c_3!=GLOBALS->vend_vcd_recoder_c_3)?((int)(*(GLOBALS->vst_vcd_recoder_c_3++))):(getch_fetch()));
+static signed char getch_peek(void) {
+  signed char ch = (GLOBALS->vst_vcd_recoder_c_3!=GLOBALS->vend_vcd_recoder_c_3)?((int)(*GLOBALS->vst_vcd_recoder_c_3)):(getch_fetch());
+  /* no increment */
+  return(ch);
 }
 
 static int getch_patched(void)
@@ -707,7 +1035,20 @@ for(GLOBALS->yytext_vcd_recoder_c_3[len++]=ch;;GLOBALS->yytext_vcd_recoder_c_3[l
 		{
 		GLOBALS->yytext_vcd_recoder_c_3=(char *)realloc_2(GLOBALS->yytext_vcd_recoder_c_3, (GLOBALS->T_MAX_STR_vcd_recoder_c_3=GLOBALS->T_MAX_STR_vcd_recoder_c_3*2)+1);
 		}
+
 	ch=getch();
+	if(ch==' ')
+		{
+		signed char ch2;
+		if(match_kw) break;
+		if((ch2 = getch_peek()) == '[')
+			{
+			ch = getch();
+			GLOBALS->varsplit_vcd_recoder_c_3=GLOBALS->yytext_vcd_recoder_c_3+len;	/* keep looping so we get the *last* one */
+			continue;
+			}
+		}
+
 	if((ch==' ')||(ch=='\t')||(ch=='\n')||(ch=='\r')||(ch<0)) break;
 	if((ch=='[')&&(GLOBALS->yytext_vcd_recoder_c_3[0]!='\\'))
 		{
@@ -720,6 +1061,7 @@ for(GLOBALS->yytext_vcd_recoder_c_3[len++]=ch;;GLOBALS->yytext_vcd_recoder_c_3[l
 		break;
 		}
 	}
+
 GLOBALS->yytext_vcd_recoder_c_3[len]=0;	/* absolute terminator */
 if((GLOBALS->varsplit_vcd_recoder_c_3)&&(GLOBALS->yytext_vcd_recoder_c_3[len-1]==']'))
 	{
@@ -826,6 +1168,7 @@ switch((typ = GLOBALS->yytext_vcd_recoder_c_3[0]))
                         if(!v)
                                 {
                                 fprintf(stderr,"Near byte %d, Unknown VCD identifier: '%s'\n",(int)(GLOBALS->vcdbyteno_vcd_recoder_c_3+(GLOBALS->vst_vcd_recoder_c_3-GLOBALS->vcdbuf_vcd_recoder_c_3)),GLOBALS->yytext_vcd_recoder_c_3+1);
+				malform_eof_fix();
                                 }
                                 else
                                 {
@@ -864,6 +1207,7 @@ switch((typ = GLOBALS->yytext_vcd_recoder_c_3[0]))
                         else
                         {
                         fprintf(stderr,"Near byte %d, Malformed VCD identifier\n", (int)(GLOBALS->vcdbyteno_vcd_recoder_c_3+(GLOBALS->vst_vcd_recoder_c_3-GLOBALS->vcdbuf_vcd_recoder_c_3)));
+			malform_eof_fix();
                         }
                 break;
 
@@ -886,6 +1230,7 @@ process_binary:
                 if(!v)
 			{
                         fprintf(stderr,"Near byte %d, Unknown VCD identifier: '%s'\n",(int)(GLOBALS->vcdbyteno_vcd_recoder_c_3+(GLOBALS->vst_vcd_recoder_c_3-GLOBALS->vcdbuf_vcd_recoder_c_3)),GLOBALS->yytext_vcd_recoder_c_3+1);
+			malform_eof_fix();
                         }
                         else
                         {
@@ -982,8 +1327,8 @@ process_binary:
 
 static void evcd_strcpy(char *dst, char *src)
 {
-static char *evcd="DUNZduLHXTlh01?FAaBbCcf";
-static char  *vcd="01xz0101xz0101xzxxxxxxx";
+static const char *evcd="DUNZduLHXTlh01?FAaBbCcf";
+static const char  *vcd="01xz0101xz0101xzxxxxxxz";
 
 char ch;
 int i;
@@ -1011,6 +1356,7 @@ while((ch=*src))
 static void vcd_parse(void)
 {
 int tok;
+unsigned char ttype;
 
 for(;;)
 	{
@@ -1076,6 +1422,17 @@ for(;;)
 			break;
 		case T_SCOPE:
 			T_GET;
+				{
+				switch(GLOBALS->yytext_vcd_recoder_c_3[0])
+					{
+					case 'm':	ttype = TREE_VCD_ST_MODULE; break;
+					case 't':	ttype = TREE_VCD_ST_TASK; break;
+					case 'f':	ttype = (GLOBALS->yytext_vcd_recoder_c_3[1] == 'u') ? TREE_VCD_ST_FUNCTION : TREE_VCD_ST_FORK; break;
+					case 'b':	ttype = TREE_VCD_ST_BEGIN; break;
+					default:	ttype = TREE_UNKNOWN;
+							break;
+					}
+				}
 			T_GET;
 			if(tok==T_STRING)
 				{
@@ -1084,6 +1441,9 @@ for(;;)
 				s->len=GLOBALS->yylen_vcd_recoder_c_3;
 				s->str=(char *)malloc_2(GLOBALS->yylen_vcd_recoder_c_3+1);
 				strcpy(s->str, GLOBALS->yytext_vcd_recoder_c_3);
+				s->mod_tree_parent = GLOBALS->mod_tree_parent;
+
+				allocate_and_decorate_module_tree_node(ttype, GLOBALS->yytext_vcd_recoder_c_3);
 
 				if(GLOBALS->slistcurr)
 					{
@@ -1105,6 +1465,7 @@ for(;;)
 				{
 				struct slist *s;
 
+				GLOBALS->mod_tree_parent = GLOBALS->slistcurr->mod_tree_parent;
 				s=GLOBALS->slistroot;
 				if(!s->next)
 					{
@@ -1128,6 +1489,10 @@ for(;;)
 				build_slisthier();
 				DEBUG(fprintf(stderr, "SCOPE: %s\n",slisthier));
 				}
+				else
+				{
+				GLOBALS->mod_tree_parent = NULL;
+				}
 			sync_end(NULL);
 			break;
 		case T_VAR:
@@ -1157,7 +1522,7 @@ for(;;)
 
 			if(vtok==V_PORT)
 				{
-				vtok=get_vartoken(0);
+				vtok=get_vartoken(1);
 				if(vtok==V_STRING)
 					{
 					v->size=atoi_64(GLOBALS->yytext_vcd_recoder_c_3);
@@ -1377,7 +1742,18 @@ for(;;)
 				}
 
 			dumpv:
-			if(v->size == 0) { v->vartype = V_REAL; } /* MTI fix */
+			if(v->size == 0) 
+				{ 
+				if(v->vartype != V_EVENT)
+					{
+					v->vartype = V_REAL; 
+					}
+					else
+					{
+					v->size = 1;
+					}					
+
+				} /* MTI fix */
 
 			if(v->vartype==V_REAL)
 				{
@@ -1475,6 +1851,7 @@ for(;;)
 			DEBUG(fprintf(stderr,"VAR %s %d %s %s[%d:%d]\n",
 				vartypes[v->vartype], v->size, v->id, v->name, 
 					v->msi, v->lsi));
+
 			goto bail;
 			err:
 			if(v)
@@ -1519,6 +1896,14 @@ for(;;)
 				fprintf(stderr, "\n%d VCD parse errors encountered, exiting.\n", GLOBALS->error_count_vcd_recoder_c_3);
 				vcd_exit(255);
 				}
+
+			if(GLOBALS->use_fastload == VCD_FSL_READ)
+				{
+				read_fastload_body();
+				fprintf(stderr, "VCDLOAD | Using fastload file.\n");
+				return;
+				}
+
 			break;
 		case T_STRING:
 			if(!GLOBALS->header_over_vcd_recoder_c_3)
@@ -1539,6 +1924,18 @@ for(;;)
 					if(GLOBALS->start_time_vcd_recoder_c_3<0)
 						{
 						GLOBALS->start_time_vcd_recoder_c_3=tim;
+
+						if(GLOBALS->time_vlist_vcd_recoder_write)
+							{					
+							vlist_packer_emit_utt((struct vlist_packer_t **)(void *)&GLOBALS->time_vlist_vcd_recoder_write, tim);
+							}
+						}
+						else
+						{
+						if(GLOBALS->time_vlist_vcd_recoder_write)
+							{					
+							vlist_packer_emit_utt((struct vlist_packer_t **)(void *)&GLOBALS->time_vlist_vcd_recoder_write, tim - GLOBALS->current_time_vcd_recoder_c_3);
+							}
 						}
 
 					GLOBALS->current_time_vcd_recoder_c_3=tim;
@@ -1562,6 +1959,11 @@ for(;;)
 
 						GLOBALS->start_time_vcd_recoder_c_3=GLOBALS->current_time_vcd_recoder_c_3=GLOBALS->end_time_vcd_recoder_c_3=tim;
 
+						if(GLOBALS->time_vlist_vcd_recoder_write)
+							{					
+							vlist_packer_emit_utt((struct vlist_packer_t **)(void *)&GLOBALS->time_vlist_vcd_recoder_write, tim);
+							}
+
 						tt = vlist_alloc(&GLOBALS->time_vlist_vcd_recoder_c_1, 0);
 						*tt = tim;
 						GLOBALS->time_vlist_count_vcd_recoder_c_1=1;
@@ -1656,7 +2058,7 @@ if(!n->curr)
         if((ch=='l')||(ch=='L')) heval=AN_L; else
         /* if(ch=='-') */        heval=AN_DASH;		/* default */
 	
-	if((n->curr->v.h_val!=heval)||(tim==GLOBALS->start_time_vcd_recoder_c_3)||(GLOBALS->vcd_preserve_glitches)) /* same region == go skip */ 
+	if((n->curr->v.h_val!=heval)||(tim==GLOBALS->start_time_vcd_recoder_c_3)||(n->vartype==ND_VCD_EVENT)||(GLOBALS->vcd_preserve_glitches)) /* same region == go skip */ 
         	{
 		if(n->curr->time==tim)
 			{
@@ -2104,7 +2506,6 @@ while(v)
 	{
 	if(v->name) free_2(v->name);
 	if(v->id) free_2(v->id);
-	if(v->ev) free_2(v->ev);
 	if(v->narray) free_2(v->narray);
 	vt=v;
 	v=v->next;
@@ -2127,10 +2528,12 @@ GLOBALS->slistroot=GLOBALS->slistcurr=NULL; GLOBALS->slisthier_len=0;
 if(GLOBALS->vcd_is_compressed_vcd_recoder_c_2)
 	{
 	pclose(GLOBALS->vcd_handle_vcd_recoder_c_2);
+	GLOBALS->vcd_handle_vcd_recoder_c_2 = NULL;
 	}
 	else
 	{
 	fclose(GLOBALS->vcd_handle_vcd_recoder_c_2);
+	GLOBALS->vcd_handle_vcd_recoder_c_2 = NULL;
 	}
 
 if(GLOBALS->yytext_vcd_recoder_c_3)
@@ -2145,10 +2548,39 @@ if(GLOBALS->yytext_vcd_recoder_c_3)
 TimeType vcd_recoder_main(char *fname)
 {
 int flen;
+unsigned int finalize_cnt = 0;
+struct stat mystat;
+int stat_rc = stat(fname, &mystat);
 
 GLOBALS->pv_vcd_recoder_c_3=GLOBALS->rootv_vcd_recoder_c_3=NULL;
 GLOBALS->vcd_hier_delimeter[0]=GLOBALS->hier_delimeter;
 
+if(GLOBALS->use_fastload)
+	{
+        char *ffname = malloc_2(strlen(fname) + 4 + 1);
+        sprintf(ffname, "%s.idx", fname);
+        
+        GLOBALS->vlist_handle = fopen(ffname, "rb");
+	if(GLOBALS->vlist_handle)
+		{
+		GLOBALS->use_fastload = VCD_FSL_READ;
+
+		/* need to do a sanity check looking for time of vcd file vs recoder file, etc. */
+		if( (stat_rc) || (!read_fastload_header(&mystat)) )
+			{
+			GLOBALS->use_fastload = VCD_FSL_WRITE;
+			fclose(GLOBALS->vlist_handle);
+			GLOBALS->vlist_handle = NULL;
+			}
+		}
+		else
+		{
+		GLOBALS->use_fastload = VCD_FSL_WRITE;
+		} 
+
+        free_2(ffname);
+        }
+
 errno=0;	/* reset in case it's set for some reason */
 
 GLOBALS->yytext_vcd_recoder_c_3=(char *)malloc_2(GLOBALS->T_MAX_STR_vcd_recoder_c_3+1);
@@ -2230,7 +2662,12 @@ build_slisthier();
 
 GLOBALS->time_vlist_vcd_recoder_c_1 = vlist_create(sizeof(TimeType));
 
-if(GLOBALS->vlist_spill_to_disk)
+if(GLOBALS->use_fastload == VCD_FSL_WRITE)
+	{
+	GLOBALS->time_vlist_vcd_recoder_write = ((struct vlist_t *)vlist_packer_create());
+	}
+
+if((GLOBALS->vlist_spill_to_disk) && (GLOBALS->use_fastload != VCD_FSL_READ))
 	{
 	vlist_init_spillfile();
 	}
@@ -2254,7 +2691,21 @@ if(GLOBALS->vlist_handle)
 	vlist_freeze(&GLOBALS->time_vlist_vcd_recoder_c_1);
 	}
 
-vlist_emit_finalize();
+if(GLOBALS->time_vlist_vcd_recoder_write)
+	{
+	write_fastload_time_section();
+	}
+
+if(GLOBALS->use_fastload != VCD_FSL_READ)
+	{
+	finalize_cnt = vlist_emit_finalize();
+	}
+
+if(GLOBALS->time_vlist_vcd_recoder_write)
+	{
+	write_fastload_header(&mystat, finalize_cnt);
+	}
+
 
 if((!GLOBALS->sorted_vcd_recoder_c_3)&&(!GLOBALS->indexed_vcd_recoder_c_3))
 	{
@@ -2278,12 +2729,6 @@ if(GLOBALS->vcd_is_compressed_vcd_recoder_c_2)
 	GLOBALS->vcd_fsiz_vcd_recoder_c_2 = 0;
 	}
 
-vcd_build_symbols();
-vcd_sortfacs();
-vcd_cleanup();
-
-getch_free();		/* free membuff for vcd getch buffer */
-
 GLOBALS->min_time=GLOBALS->start_time_vcd_recoder_c_3*GLOBALS->time_scale;
 GLOBALS->max_time=GLOBALS->end_time_vcd_recoder_c_3*GLOBALS->time_scale;
 
@@ -2293,6 +2738,13 @@ if((GLOBALS->min_time==GLOBALS->max_time)||(GLOBALS->max_time==0))
         vcd_exit(255);
         }
 
+vcd_build_symbols();
+vcd_sortfacs();
+vcd_cleanup();
+
+getch_free();		/* free membuff for vcd getch buffer */
+
+
 if(GLOBALS->blackout_regions)
 	{
 	struct blackout_region_t *bt = GLOBALS->blackout_regions;
@@ -2463,23 +2915,7 @@ if(vlist_type == '0') /* single bit */
 			exit(255);
 			}
 
-		if(vartype != V_EVENT)
-			{
-			add_histent(*curtime_pnt,np,ascval,1, NULL);
-			}
-			else
-			{
-			if((ascval == '0') || (ascval == '1'))
-				{
-				TimeType ev = *curtime_pnt;
-				add_histent(ev,  np,'1',1, NULL);
-				add_histent(ev+1,np,'0',1, NULL);
-				}
-				else
-				{
-				add_histent(*curtime_pnt,np,ascval,1, NULL);
-				}
-			}
+		add_histent(*curtime_pnt,np,ascval,1, NULL);
 		}
 
 	add_histent(MAX_HISTENT_TIME-1, np, 'x', 0, NULL);
@@ -2733,8 +3169,50 @@ np->mv.mvlfac_vlist = NULL;
 }
 
 /*
- * $Id: vcd_recoder.c,v 1.19 2008/12/25 03:52:32 gtkwave Exp $
+ * $Id: vcd_recoder.c,v 1.33 2009/12/25 18:12:16 gtkwave Exp $
  * $Log: vcd_recoder.c,v $
+ * Revision 1.33  2009/12/25 18:12:16  gtkwave
+ * more warnings fixes
+ *
+ * Revision 1.32  2009/12/24 20:55:27  gtkwave
+ * warnings cleanups
+ *
+ * Revision 1.31  2009/08/28 19:58:42  gtkwave
+ * added malform_eof_fix
+ *
+ * Revision 1.30  2009/08/06 20:11:03  gtkwave
+ * warnings fixes
+ *
+ * Revision 1.29  2009/07/07 19:46:03  gtkwave
+ * make evcd->vcd conversion table const
+ *
+ * Revision 1.28  2009/07/07 15:48:37  gtkwave
+ * EVCD "f" value fix (should be z not x)
+ *
+ * Revision 1.27  2009/07/06 21:41:36  gtkwave
+ * evcd support issues
+ *
+ * Revision 1.26  2009/07/02 18:50:47  gtkwave
+ * decorate VCD module trees with type info, add move to front to buildname
+ *
+ * Revision 1.25  2009/06/25 21:21:12  gtkwave
+ * crash fix for zero bit wide events
+ *
+ * Revision 1.24  2009/06/25 18:31:19  gtkwave
+ * added event types for VCD+FST and impulse arrows on event types
+ *
+ * Revision 1.23  2009/04/30 01:30:53  gtkwave
+ * VCD parser fix for double subscripted nets
+ *
+ * Revision 1.22  2009/03/31 18:49:49  gtkwave
+ * removal of warnings under cygwin compile
+ *
+ * Revision 1.21  2009/03/25 09:20:26  gtkwave
+ * fixing reloader crashes in vcd_build_symbols if times is zero
+ *
+ * Revision 1.20  2009/03/05 16:17:56  gtkwave
+ * added fastload option
+ *
  * Revision 1.19  2008/12/25 03:52:32  gtkwave
  * -Wshadow warning fixes
  *
