@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 2005-8.
+ * Copyright (c) Tony Bybell 2005-2009.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -25,7 +25,7 @@ if(!strict)
 	{
 	if(ch < AN_COUNT)
 		{
-		return(AN_STR[ch]);
+		return(AN_USTR[ch]);
 		}
 		else
 		{
@@ -36,7 +36,7 @@ else
 	{
 	if(ch < AN_COUNT)
 		{
-		return(AN_STR4ST[ch]);
+		return(AN_USTR4ST[ch]);
 		}
 		else
 		{
@@ -51,17 +51,43 @@ else
  */
 static char *vcdid(int value)
 {
+char *pnt = GLOBALS->buf_vcd_saver_c_3;
+int i, vmod;
+
+value++;
+for(i=0;;i++)
+        {
+        if((vmod = (value % 94)))
+                {
+                *(pnt++) = (char)(vmod + 32);
+                }   
+                else
+                {
+                *(pnt++) = '~'; value -= 94;
+                }
+        value = value / 94;  
+        if(!value) { break; }
+        }
+
+*pnt = 0;   
+return(GLOBALS->buf_vcd_saver_c_3);
+}
+
+/*
+static char *vcdid(int value)
+{
 int i;
                                          
 for(i=0;i<15;i++)
         {
-        GLOBALS->buf_vcd_saver_c_3[i]=(char)((value%94)+33); /* for range 33..126 */
+        GLOBALS->buf_vcd_saver_c_3[i]=(char)((value%94)+33);
         value=value/94;
         if(!value) {GLOBALS->buf_vcd_saver_c_3[i+1]=0; break;}
         }
                     
 return(GLOBALS->buf_vcd_saver_c_3);
 }
+*/
 
 static char *vcd_truncate_bitvec(char *s)
 {
@@ -836,7 +862,6 @@ diff_hier(nh_head, GLOBALS->nhold_vcd_saver_c_1);
 free_hier();
 GLOBALS->nhold_vcd_saver_c_1=nh_head;
 
-if(*nh_curr->name == '\\')
 	{
 	char *mti_sv_patch = strstr(nh_curr->name, "]["); 	/* case is: #implicit-var###VarElem:ram_di[0.0] [63:0] */
 	if(mti_sv_patch)
@@ -850,7 +875,7 @@ if(*nh_curr->name == '\\')
 		nh_curr->name = t;
 		}
 
-	if(nh_curr->name[1] == '#')
+	if((nh_curr->name[0] == '\\') && (nh_curr->name[1] == '#'))
 		{
 		return(nh_curr->name+1);
 		}
@@ -905,7 +930,7 @@ for(i=0;i<numhist;i++)
 	{
 	if(ha[i]->time < tmin)
 		{
-		h_val = invert ? AN_STR_INV[ha[i]->v.h_val] : AN_STR[ha[i]->v.h_val];	
+		h_val = invert ? AN_USTR_INV[ha[i]->v.h_val] : AN_USTR[ha[i]->v.h_val];	
 		}
 	else
 	if(ha[i]->time > tmax)
@@ -920,7 +945,7 @@ for(i=0;i<numhist;i++)
 
 			if(skip_this)
 				{
-				h_val = invert ? AN_STR_INV[ha[i]->v.h_val] : AN_STR[ha[i]->v.h_val];
+				h_val = invert ? AN_USTR_INV[ha[i]->v.h_val] : AN_USTR[ha[i]->v.h_val];
 				}
 
 			fprintf(GLOBALS->f_vcd_saver_c_1,
@@ -945,7 +970,7 @@ for(i=0;i<numhist;i++)
 				}
 			}
 
-		h_val = invert ? AN_STR_INV[ha[i]->v.h_val] : AN_STR[ha[i]->v.h_val];
+		h_val = invert ? AN_USTR_INV[ha[i]->v.h_val] : AN_USTR[ha[i]->v.h_val];
 		fprintf(GLOBALS->f_vcd_saver_c_1, "          Edge:               "TTFormat".0 %c\n", ha[i]->time, h_val);
 		}
 	}		
@@ -1432,8 +1457,17 @@ return(errno ? VCDSAV_FILE_ERROR : VCDSAV_OK);
 }
 
 /*
- * $Id: vcd_saver.c,v 1.8 2008/12/25 03:52:32 gtkwave Exp $
+ * $Id: vcd_saver.c,v 1.11 2009/07/07 20:12:53 gtkwave Exp $
  * $Log: vcd_saver.c,v $
+ * Revision 1.11  2009/07/07 20:12:53  gtkwave
+ * convert hex capitalization to match verilog
+ *
+ * Revision 1.10  2009/04/30 19:18:41  gtkwave
+ * added space before final brackets in VCD writers
+ *
+ * Revision 1.9  2009/04/15 21:39:50  gtkwave
+ * use XL-style identifier sequencing for VCD identifiers
+ *
  * Revision 1.8  2008/12/25 03:52:32  gtkwave
  * -Wshadow warning fixes
  *
