@@ -7,6 +7,8 @@
  * of the License, or (at your option) any later version.
  */
 
+#include "globals.h"
+
 #ifndef WAVE_VZTRDR_H
 #define WAVE_VZTRDR_H
 
@@ -16,7 +18,6 @@
 
 #include "vcd.h"
 
-extern unsigned char is_lx2;
 
 TimeType 	vzt_main(char *fname, char *skip_start, char *skip_end);
 void 		import_vzt_trace(nptr np);
@@ -26,8 +27,20 @@ void 		vzt_import_masked(void);
 #endif
 
 /*
- * $Id: vzt.h,v 1.2 2007/04/20 02:08:18 gtkwave Exp $
+ * $Id: vzt.h,v 1.2 2007/08/26 21:35:50 gtkwave Exp $
  * $Log: vzt.h,v $
+ * Revision 1.2  2007/08/26 21:35:50  gtkwave
+ * integrated global context management from SystemOfCode2007 branch
+ *
+ * Revision 1.1.1.1.2.2  2007/08/25 19:43:46  gtkwave
+ * header cleanups
+ *
+ * Revision 1.1.1.1.2.1  2007/08/05 02:27:28  kermin
+ * Semi working global struct
+ *
+ * Revision 1.1.1.1  2007/05/30 04:27:50  gtkwave
+ * Imported sources
+ *
  * Revision 1.2  2007/04/20 02:08:18  gtkwave
  * initial release
  *
